'use strict';

/*
Configuration file for ExploreTheData version 1.8 (http://ExploreTheData.com/).

The script may be modified according to the instructions, and then imported to the app.
To import the file, click on the "Import Configuration" button and select the file, or drop the file to the app
(in this case the filename extension must be .js).
In a web browser, the script URL may be added to the URL of the app, e.g.,
  http://explorethedata.com/app/index.html?etd-config=http://my-domain/config-script.js.
Here http://any-domain.com/the-script.js is the URL of the configuration script.

The following features can be modified with this script:

(a), the list of data files selectable from the drop down menu (in 'Import and Export');
(b), the list of style files selectable from the drop down menu (in 'Style');
(c), the list and implementation of table operations (e.g., sum, mean);
(d), a few settings.


Selectable data files (CONFIG.data)
==========================================

CONFIG.data.items - A list of data files selectable from the drop down menu in 'Import and Export'.
  Format of the objects in the list:
    { url: 'url-of-the-data-file', label: 'label-displayed-in-the-drop-down-menu' }.


Selectable style files (CONFIG.style)
============================================

CONFIG.style.items - A list of style files selectable from the drop down menu in 'Style'.
  Format of the objects in the list:
    { url: 'url-of-the-style-file', label: 'label-displayed-in-the-drop-down-menu' }.


Operations with data (CONFIG.operations)
===============================================

For each table operation selectable from the drop down menu in the lower left corner of the table,
the object 'CONFIG.operations.items' includes an object with the operation id and the label.
The item with id 'ro_sel' (label 'Selection') is handled by the library. If this is selected in the
drop down menu, the last selected table row is displayed. The other items correspond to operations which
are handled in a callback 'CONFIG.operations.calculate()'. The arguments passed to the callback:

..data - Parsed data object.
  indexVector -- If defined, a vector of 0-based indexes of the filtered data (the result of search in the table).
    In the callback, the operation should be applied to the filtered data accessible as
      data[indexVector[i]], where i=0, 1,..., (indexVector.length-1)
    If indexVector is undefined, the operation should be applied to all items in the data set:
      data[i], where i=0, 1,..., (data.length-1).
  operation -- ID of the row operation (e.g., 'ro_sum', 'ro_mean').
  variables -- A map; the keys are the variable names for which the results are requested.
    In addition to these variables, the results may be provided for two special variables: row id ('svgware_row_id')
    and row number ('svgware_row_no').

  The callback returns an object in the form
      { operation_1: { x1: 'result_1', x2: 'result_2', ... }, operation_2: { x1: 'result_3', x2: 'result_4',... }, ... }
    Here, operation_1 and operation_2 are the operation id-s, x1 and x2 are the variable names (received with oVariables), and
    result_1, result_2, etc. are the corresponding results.

    Although a single operation id (sOperation) is passed to the callback, the callback may return results for multiple
    operations. The results are stored in the library and may be used later to save time. In the example below, if the results
    of Sum, Mean or Count are requested, those for all of them are returned. Later, if results of another operation are requested for
    the same data, the earlier returned results are used and the callback is not called at all.


Settings (CONFIG.settings)
=================================

CONFIG.settings.layoutLeft, CONFIG.settings.layoutTop -- Initial layout, i.e., the position of the small draggable
  element for changing the size of the chart and table. The values layoutLeft = 0 and layoutTop = 0 corresond to the upper left corner,
  while the values layoutLeft = 1 and layoutTop = 1 correspond to the lower right corner.

CONFIG.settings.useLocalStorageForStyle -- If set to true and the local storage is available,
  the imported style files are strored in the local storage and they become accessible with the drop down menu in 'Style'.

CONFIG.settings.maxTableRowsSelectedFromChart -- The maximum number of table rows which are selected
  as a result of a click in the chart.

*/

var CONFIG = {

    // selectable data files
    data: {
        items: [
            { url: 'https://chartthedata.com/etd-examples/ex-01-chart.csv', label: 'Example 1', default: true },
            { url: 'https://chartthedata.com/etd-examples/ex-02-chart.csv', label: 'Example 2' },
            { url: 'https://chartthedata.com/etd-examples/ex-03-chart.csv', label: 'Example 3' },
            { url: 'https://chartthedata.com/etd-examples/test-data.txt', label: 'Test data' }
        ]
    },

    // selectable style files
    style: {
        items: [
            { url: 'https://chartthedata.com/etd-examples/style/etd-style-01.html', label: 'Style 1' },
            { url: 'https://chartthedata.com/etd-examples/style/etd-style-02.html', label: 'Style 2' }
        ]
    },

    // settings
    settings: {

        // initial layout;
        // upper left corner: layoutLeft = 0, layoutTop = 0;
        // lower right corner:  layoutLeft = 1, layoutTop = 1;
        layoutLeft: 0,
        layoutTop: 0,

        // if set to true and the local storage is available, the imported style files are strored
        // in the local storage and they become accessible with the drop down menu in the 'Style' folder
        useLocalStorageForStyle: false,

        // the maximum number of table rows which are selected as a result of a click in the chart
        maxTableRowsSelectedFromChart: 3
    },

    // operations with data
    operations: undefined // use the default implementation
};
