﻿'use strict';

var DATA_CACHE_NAME = 'etd-data-cache-190817';
var CACHE_NAME = 'etd-cache-190817';
var prefix = '/app/';
var CACHED_URLS = [
    prefix,
    prefix + 'index.html',
    //prefix + 'help.html',
    prefix + 'home/svgware/svgware_2.8.js',
    prefix + 'home/js/etd-plus.min.js',
    prefix + 'home/custom/etd-config.js',
    prefix + 'home/custom/etd-style.js',
    prefix + 'home/papaparse/papaparse-5.0.1.js',
    //prefix + 'home/papaparse/papaparse-4.3.6.js?papaworker', // request from papaparse script
    prefix + 'home/filesaver/blob-filesaver.js',
    prefix + 'home/js/app.js',
    prefix + 'scripts/jquery-3.4.1.min.js',
    prefix + 'scripts2/jquery-ui-1.12.1.min.js',
    prefix + 'scripts2/jquery.ui.touch-punch.min.js',
    prefix + 'scripts2/jquery-filestyle.js',
    prefix + 'images/icons/explorethedata-16x16.png',
    prefix + 'images/icons/explorethedata-24x24.png',
    prefix + 'images/icons/explorethedata-32x32.png',
    prefix + 'images/icons/explorethedata-48x48.png',
    prefix + 'images/icons/explorethedata-96x96.png',
    prefix + 'images/icons/explorethedata-192x192.png',
    prefix + 'images/icons/explorethedata-512x512.png',
    prefix + 'images/res/layout_16.png',
    prefix + 'images/res/layout_32.png',
    prefix + 'images/res/minus.png',
    prefix + 'images/res/plus.png',
    prefix + 'images/res/search.png',
    prefix + 'images/res/splitter.png',
    prefix + 'images/res/arrow-down.png', // set directly in svgware lib
    prefix + 'images/res/arrow-up.png', // set directly in svgware lib
    prefix + 'images/res/checkbox-0.png', // set directly in svgware lib
    prefix + 'images/res/checkbox-1.png', // set directly in svgware lib
    prefix + 'images/res/handler.png', // set directly in svgware lib
    prefix + 'images/res/insert-here.png', // set directly in svgware lib
    prefix + 'images/icons/explorethedata-152x152.png', // ipad
    prefix + 'images/icons/explorethedata-167x167.png', // ipad-retina
    prefix + 'images/icons/explorethedata-180x180.png' // iphone-retina
];

self.addEventListener('install', function (event) {

    // installation fails if anything fails to cache
    event.waitUntil(
        caches.open(CACHE_NAME).then(function (cache) {
            console.log('[serviceworker] caching app shell');
            return cache.addAll(CACHED_URLS);
        })
    );
});

self.addEventListener('activate', function (event) {

    event.waitUntil(
        caches.keys().then(function (keyList) {
            return Promise.all(
                keyList.map(function (key) {
                    if (key !== CACHE_NAME && key !== DATA_CACHE_NAME) {
                        console.log('[serviceworker] removing old cache: ' + key);
                        return caches.delete(key);
                    }
                })
            );
        })
    );

    // Fixes a corner case in which the app wasn't returning the latest data.
    // You can reproduce the corner case by commenting out the line below and then doing the following steps:
    // 1) load app for first time so that the initial data is shown;
    // 2) press the refresh button on the app;
    // 3) go offline;
    // 4) reload the app.
    // You expect to see the newer data, but you actually see the initial data.
    // This happens because the service worker is not yet activated.The code below essentially lets
    // you activate the service worker faster.
    return self.clients.claim();
});

self.addEventListener('fetch', function (event) {

    var requestURL = new URL(event.request.url),
        regex;

    // index.html - cache, falling back to network with frequent updates pattern
    regex = new RegExp('/(|index.html)$', 'i'); // match 'anything/' and 'anything/index.html'
    if (requestURL.pathname.search(regex) >= 0) {
        event.respondWith(
            caches.open(CACHE_NAME).then(function (cache) {
                return fetch(event.request).then(function (networkResponse) {
                    cache.put(event.request, networkResponse.clone());
                    console.log('[serviceworker] index.html from network');
                    return networkResponse;
                }).catch(function () {
                    console.log('[serviceworker] index.html from cache');
                    return caches.match(event.request);
                });
            }));

        // cache, falling back to network pattern
    } else if (CACHED_URLS.includes(requestURL.href) || CACHED_URLS.includes(requestURL.pathname)) {
        event.respondWith(
            caches.open(CACHE_NAME).then(function (cache) {
                return cache.match(event.request).then(function (response) {
                    return response || fetch(event.request);
                });
            })
        );
    }
});
