﻿'use strict';

(function () {

    var ETD = {
        ABOUT: 'ExploreTheData.com',
        UPP: 10, // 10 units per pixel
        INIT: {
            ZINDEX: {
                layouter: 1000,
                chartcontrolscover: 999
            }
        }
    };
    if (typeof SVGware === 'undefined') {
        window.SVGware = {}; // temporary helper
    }
    if (typeof SVGware.resize === 'undefined') {
        SVGware.resize = function () { };
    }
    if (typeof SVGware.release === 'undefined') {
        SVGware.release = function () { };
    }


ETD.LAYOUTER = {
    layouter: undefined
};

ETD.LAYOUTER.create = function (relLeft /*:float*/, relTop /*:float*/,
    onDragStart, onDrag, onDragStop, isTouchDevice) {

    var layouts = [ // store 2 last layouts as an array of 2 objects { leftR:, topR: }
        { leftR: 0.5, topR: 0.25 },
        { leftR: relLeft, topR: relTop }],
        touchDevStartRelPos = undefined,
        timerID;

    function dragStop() {

        var relPos; /*:object*/

        clearTimeout(timerID);
        relPos = measureLayout();
        setLayout(relPos.leftR, relPos.topR);
        layouts[0] = layouts[1];
        layouts[1] = {
            leftR: relPos.leftR,
            topR: relPos.topR
        };
        if (typeof onDragStop === 'function') {
            onDragStop(relPos.leftR, relPos.topR);
        }
    }

    // init
    relTop = Math.min(relTop, 0.8);
    setTouchFriendlyModeImpl(isTouchDevice);
    $('#idLayouter').prop('title', 'Drag to change layout, click to restore previous layout.');

    // make the layouter draggable;
    // the stop event handler may not be called (chrome on iPad if the layouter is dragged to the upper border);
    // call dragStop() from the drag event handler via setTimeout();
    $('#idLayouter').draggable({
        //axis: 'x'
        containment: 'parent',
        cursor: 'move',
        distance: !isTouchDevice ? 2 : 4, // Distance in pixels after mousedown the mouse must move
        // before dragging should start.
        scroll: false,
        start: function (event, ui) {
            if (typeof onDragStart === 'function') {
                onDragStart();
            }
        },
        drag: function (event, ui) {
            var relPos = measureLayout(),
                isHot = ETD.AFO.touchFriendlyMode;
            setLayout(relPos.leftR, relPos.topR, isHot);
            if (typeof onDrag === 'function') {
                onDrag();
            }
            // call stop event handler
            clearTimeout(timerID);
            timerID = setTimeout(function (event, ui) { // chrome on iPad: drag to the upper border and this event handler is not called
                dragStop(event, ui);
            }, 100);
        },
        stop: function (event, ui) { // the event handler may not be called (chrome on iPad if the layouter is dragged to the upper border);
            // call dragStop() from the drag event handler via setTimeout();
            //dragStop(event, ui);
        }
    }).css({ visibility: 'visible', 'z-index': ETD.INIT.ZINDEX.layouter });

    // click on the layouter: apply previous layout
    $('#idLayouter').click(function () {

        layouts = [layouts[1], layouts[0]];
        setLayouter(layouts[1].leftR, layouts[1].topR);
        setLayout(layouts[1].leftR, layouts[1].topR);

        // call onDragStop handler
        if (typeof onDragStop === 'function') {
            onDragStop(layouts[1].leftR, layouts[1].topR);
        }
    });

    $('#idLayouter').on('touchstart', function () {
        touchDevStartRelPos = measureLayout();
    });

    $('#idLayouter').on('touchend', function () {
        var relPos = measureLayout();
        if (Math.abs(relPos.leftR - touchDevStartRelPos.leftR) < 0.01 &&
            Math.abs(relPos.topR - touchDevStartRelPos.topR) < 0.01) {

            layouts = [layouts[1], layouts[0]];
            setLayouter(layouts[1].leftR, layouts[1].topR);
            setLayout(layouts[1].leftR, layouts[1].topR);
        }
    });

    function resize() {
        setLayouter(layouts[1].leftR, layouts[1].topR);
        setLayout(layouts[1].leftR, layouts[1].topR);
    }

    function set(relLeft, relTop) {

        setLayouter(relLeft, relTop);

        setLayout(relLeft, relTop);
        // store layout
        //layouts[0] = {
        //    leftR: relLeft, topR: relTop
        //};
        layouts[1] = {
            leftR: relLeft, topR: relTop
        };
    }

    function setLayout(relLeft, relTop, isHot) {
        // isHot - set true while dragging in touch device for better performance

        var width, height, contWidth, contHeight, doHideRight /*:boolean*/, height2, correction; /*:int*/

        relLeft = validateRelPos(relLeft, false);
        relTop = validateRelPos(relTop, true);

        width = $('#idLayouter').width();
        height = $('#idLayouter').height();
        contWidth = $('#idLayouter').parent().width();
        contHeight = $('#idLayouter').parent().height();

        // if the top, left or right pane is too short or narrow, hide it
        if (relLeft <= 4 / contWidth) {
            width = 0;
        }
        if (contWidth * (1 - relLeft) <= width + 4) {
            doHideRight = true;
        }
        if (relTop <= 4 / contHeight) {
            height = 0;
        }

        if (!isHot) {

            $('#idPaneTop').css({
                width: '100%',
                height: relTop * contHeight + height
            });
            height2 = (1 - relTop) * contHeight - height;

            $('#idPaneLeft').css({
                left: 0,
                top: Math.round(relTop * contHeight + height),
                width: !doHideRight ? relLeft * contWidth + width / 2 : contWidth,
                height: height2
            });

            correction = 1; // cover the empty line between the left and right panes (chrome, excel on ios)
            $('#idPaneRight').css({
                left: Math.round($('#idPaneLeft').width() - correction),
                top: $('#idPaneLeft').css('top'),
                width: (!doHideRight ? contWidth - $('#idPaneLeft').width() : 0) + correction,
                height: height2
            });
        }

        // hide content of the top pane if the pane is too small
        if (relTop <= 0) {
            $('#idPaneTop').css({ 'visibility': 'hidden' });
        } else {
            $('#idPaneTop').css({ 'visibility': 'visible' });
        }

        // in AfO, make sure the layouter is not hidden behind the corner area
        if (ETD.INIT.isOfficeAddin()) {
            if (contWidth - $('#idLayouter').position().left < 32 && $('#idLayouter').position().top < 46) {
                $('#idLayouter').css({ left: Math.min($('#idLayouter').position().left, contWidth - 32) });
            }
        }
    }

    function setLayouter(relLeft, relTop) {

        var $layouter, contWidth, contHeight;

        relLeft = validateRelPos(relLeft, false);
        relTop = validateRelPos(relTop, true);

        $layouter = $('#idLayouter');
        contWidth = $layouter.parent().width();
        contHeight = $layouter.parent().height();

        $('#idLayouter').css({
            left: Math.min(relLeft * contWidth, contWidth - $layouter.width()),
            top: Math.min(relTop * contHeight, contHeight - $layouter.height())
        });
    }

    function measureLayout() {

        return {
            leftR: validateRelPos(($('#idLayouter').offset().left - $('#idLayouter').parent().offset().left) /
                $('#idLayouter').parent().width(), false),
            topR: validateRelPos(($('#idLayouter').offset().top - $('#idLayouter').parent().offset().top) /
                $('#idLayouter').parent().height(), true)
        };
    }

    function validateRelPos(relPos /*:float*/) {

        relPos = parseFloat(relPos);
        if (isNaN(relPos)) relPos = 0.5;
        relPos = Math.max(relPos, 0);
        relPos = Math.min(relPos, 1);

        return relPos;
    }

    function setTouchFriendlyModeImpl(isTouchDevice) {

        $('#idLayouter').removeClass('cnLayouter').
            removeClass('cnLayouterTouch').css({ 'width': '', 'height': '' });
        if (!isTouchDevice) {
            $('#idLayouter').addClass('cnLayouter');
        } else {
            $('#idLayouter').addClass('cnLayouterTouch');
        }
        // limit the position, otherwise the layouter may be positioned outside the borders partly;
        // the layouter is created with 'containment: parent' option which works while dragging
        // but has no effect here;
        layouts[1].leftR = Math.min(layouts[1].leftR, 0.9);
        layouts[1].topR = Math.min(layouts[1].topR, 0.9);
        // resize
        resize();
    }

    return {
        setLayout: function (relLeft, relTop) {
            set(relLeft, relTop);
        },
        getLayout: function () {
            return { left: layouts[1].leftR, top: layouts[1].topR };
        },
        resize: function () {
            resize();
        },
        setTouchFriendlyMode: function (isTouchDevice) {
            setTouchFriendlyModeImpl(isTouchDevice);
        }
    };
};

// >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

ETD.LAYOUTER.onDragLayouterStart = function () {

    if (!ETD.TABLE.exists()) {
        return;
    }

    $('#idSearchControls').css({ visibility: 'hidden' });
    $('#idTable01C').css({ display: 'none' });
    $('#idContainerRight').css({ display: 'none' });

    $('#idPaneLeft').addClass('cnColors1').css({ 'background-color': ETD.STYLE.general['skin']['backgroundColor'] });
    $('#idPaneRight').addClass('cnColors1').css({ 'background-color': ETD.STYLE.general['skin']['backgroundColor'] });
};

ETD.LAYOUTER.onDragLayouter = function () {
};

ETD.LAYOUTER.onDragLayouterStop = function (relLeft, relTop) {

    // in excel on ios, a 1-2 px line may remain (mainly) on the left side after initialization;
    // a workaround: in css file, the left attribute is set to 1 px for '#idContentMain';
    // in ETD.AFO.init, it is set to its desired value 0 px in all cases except for
    // excel on ios; later it is set to 0 px in excel on ios;
    // additional measure: white border, see class cnAddinBorder;
    if (ETD.INIT.isOfficeAddin() && ETD.INIT.is_iOS()) {
        $('#idContentMain').css({ 'left': '0' });
    }

    // set modified, serialize
    ETD.SER.setModified(1); // end layouter dragging
    ETD.SER.serialize({ save: true });

    if (ETD.TABLE.exists()) {

        $('#idSearchControls').css({ visibility: 'visible' });
        $('#idTable01C').css({ display: 'block' });
        $('#idContainerRight').css({ display: 'block' });

        $('#idPaneLeft').removeClass('cnColors1').css({ 'background-color': 'white' });
        $('#idPaneRight').removeClass('cnColors1').css({ 'background-color': 'white' });

        // resize the search controls above the table
        $('label[for=idCaseSensitive]').text('Case sensitive');
        $('label[for=idWholeWord]').text('Whole word');
        $('#idSearchString').parent().css({ 'width': '66%' });
        if ($('#idPaneLeft').get(0).scrollWidth > $('#idPaneLeft').get(0).clientWidth) { // not enough space for content
            $('#idSearchString').parent().css({ 'width': '20%' });
        }
        if ($('#idPaneLeft').get(0).scrollWidth > $('#idPaneLeft').get(0).clientWidth) { // not enough space for content
            $('label[for=idCaseSensitive]').text('');
            $('label[for=idWholeWord]').text('');
        }
    }

    ETD.AFO.resize();
};


// all file selectors
$(':file').jfilestyle({
    input: false,
    buttonText: 'Select File',
    icon: false,
    theme: ''
});
$('.jquery-filestyle').css({ display: 'none' });

// show/hide input folders ('Import and Export', 'Style', etc.)
ETD.INIT.showHideSection = function ($sectionHeader, state /*:int*/) {
    // state: 1 - open folder; 0 - close folder; any other value - switch the state;

    $($sectionHeader).closest('table').find('tbody').not(':first').each(function (index, element) {

        if (state === 1) {
            $(element).css('display', 'table-row-group');
        } else if (state === 0) {
            $(element).css('display', 'none');
        } else {
            $(element).css('display', $(element).css('display') !== 'none' ? 'none' : 'table-row-group');
        }
    });

    // resize in order to ensure there is space for the button in the upper right corner (office add-in)
    if (ETD.INIT && typeof ETD.INIT.isOfficeAddin === 'function' && ETD.INIT.isOfficeAddin() &&
        ETD.AFO && typeof ETD.AFO.resize === 'function') {

        ETD.AFO.resize();
    }
};

// adjust the style of input folders
(function() {
    var width = $('#idTopLayoutImpExp').width();
    $('.cnInputFldr').width(width);
    $('.headerA')
        .click(function (event) {
            ETD.INIT.showHideSection(event.target);
        })
        .bind('touchstart', function (event) {
            event.preventDefault();
            ETD.INIT.showHideSection(event.target);
        });
})();

// close the input folders
$('.headerA').each(function (index, element) {
    ETD.INIT.showHideSection(element);
});


// helpers

// Return true if in Office add-in (desktop or online), otherwise return false.
ETD.INIT.isOfficeAddin = function () {
    return !!window.Office && typeof window.Office === 'object';
};

// Detect if running in iOS (iPad/iPhone/iPod).
ETD.INIT.is_iOS = function () {
    var isIOS = false;
    if (navigator && typeof navigator.userAgent === 'string') {
        isIOS = !!navigator.userAgent.match(/(iPad|iPhone|iPod)/i);
    }
    return function () {
        return isIOS;
    };
}();

/*
in excel on ios, a 1-2 px line may remain (mainly) on the left side after initialization;
a workaround: in html file, the left attribute is set to 1-2 px for '#idContentMain';
additional measure: white border, see class cnAddinBorder; */
if (!ETD.INIT.isOfficeAddin() || !ETD.INIT.is_iOS()) {
    $('#idContentMain').css({ 'left': 0 });
} else {
    $('#idContentMain').css({ 'left': 2 });
}

// set layout; in office add-in, set layout in ETD.AFO.init(); test in excel on mac;
(function () {
    if (!ETD.INIT.isOfficeAddin()) {

        try { // jquery and draggable plugin may not be ready in principle

            var layoutLeft, layoutTop, topH /*:int*/, isTouchDevice; /*:boolean*/
            if (window.CONFIG && window.CONFIG.settings && ($.isNumeric(window.CONFIG.settings.layoutLeft) || $.isNumeric(window.CONFIG.settings.layoutTop))) {
                // layout set in the configuration file (applied once); -> ETD.VALID.validateConfig ()
                layoutLeft = window.CONFIG.settings.layoutLeft;
                layoutTop = window.CONFIG.settings.layoutTop;
            }
            if (!$.isNumeric(layoutLeft)) {
                layoutLeft = 0.50;
            }
            if (!$.isNumeric(layoutTop)) {
                topH = $('#idDate').offset().top + 24;
                layoutTop = Math.min(topH / $('#idPaneTop').parent().outerHeight(true), 0.8);
            }

            isTouchDevice = 'ontouchstart' in window || // false in firefox 38.0.5 on win 8.1 tablet
                !!window.navigator.msMaxTouchPoints; // ie

            ETD.LAYOUTER.layouter = ETD.LAYOUTER.create(layoutLeft, layoutTop,
                ETD.LAYOUTER.onDragLayouterStart, ETD.LAYOUTER.onDragLayouter, ETD.LAYOUTER.onDragLayouterStop,
                isTouchDevice);
        } catch (oEx) {
            ETD.LAYOUTER.layouter = undefined;
        }
    }
})();


ETD.GEN = {
    ABOUT: 'www.ExploreTheData.com - Helpers for the examples',
    rowNoVar: 'svgware_row_no' // cp. ETD.TABLE.rowNoVar
};

// detect environment ===========================

ETD.GEN.isTouchDevice = function () {

    if (ETD.INIT.isOfficeAddin()) { // office add-in
        if (!ETD.INIT.is_iOS()) { // Office.context.touchEnabled not set in iOS safari?
            if (Office && Office.context) {
                return !!Office.context.touchEnabled; // do not rely on this before Office.initialize() is called
            } else {
                return undefined;
            }
        } else {
            return true;
        }
    } else if (ETD.GEN.isUnivWinPlatApp()) { // win app
        if (typeof Windows === 'object' && Windows) {
            return !!new Windows.Devices.Input.TouchCapabilities().touchPresent;
        } else {
            return undefined;
        }
    } else { // web app
        return 'ontouchstart' in window || // false in firefox 38.0.5 on win 8.1 tablet
            !!window.navigator.msMaxTouchPoints; // ie
    }
};

ETD.GEN.usingIndexedDB = function () {

    if (ETD.INIT.isOfficeAddin()) {
        return false;
    }
    if ('indexedDB' in window) {
        return true;
    } else {
        return false;
    }
};

// Return true if in Excel online, otherwise return false.
ETD.GEN.isOfficeAddinOnline = function () {

    return ETD.INIT.isOfficeAddin() &&
        Office.context && Office.context.document && typeof Office.context.document.url === 'string' &&
        Office.context.document.url.search(/^http/i) === 0; // 'https://...' or 'http://...'
};

ETD.GEN.isOfficeAddinHostExcel = function () {

    var host; /*:string*/
    if (ETD.INIT.isOfficeAddin() && Office.context) {
        host = Office.context.host; // 'Excel', 'PowerPoint'
        if (typeof host === 'string') {
            return host.toLowerCase() === 'excel';
        }
    }
    return false;
};

ETD.GEN.isOfficeAddinHostPowerPoint = function () {

    var host; /*:string*/
    if (ETD.INIT.isOfficeAddin() && Office.context) {
        host = Office.context.host; // 'Excel', 'PowerPoint'
        if (typeof host === 'string') {
            return host.toLowerCase() === 'powerpoint';
        }
    }
    return false;
};

ETD.GEN.isFeatureLimitedVer = function () {

    if (!ETD.GEN.isUnivWinPlatApp()) {
        return $('#idImportConfig').length === 0 || $('#idTopLayoutStyle').length === 0;
    } else {
        return $('#idTopLayoutStyle').css('display') === 'none';
    }
};

// Detect if universal Windows platform app.
ETD.GEN.isUnivWinPlatApp = function () {

    if (typeof explorethedata_uwp_app !== 'undefined' && explorethedata_uwp_app /* &&
        typeof Windows === 'object' && Windows */) {

        return function () {
            return true;
        };
    } else {
        return function () {
            return false;
        };
    }
}();

// Detect if MS Edge.
ETD.GEN.isEdge = function () {

    var isEdge = false;
    if (navigator.userAgent && /Edge\/\d./i.test(navigator.userAgent)) {
        isEdge = true;
    }
    return function () {
        return isEdge;
    };
}();

// Detect if MS Internet Explorer
ETD.GEN.isIE = (function () {

    var isIE = false;
    if (navigator && typeof navigator.userAgent === 'string') {
        if (navigator.userAgent.indexOf('MSIE') >= 0) { // ie 6-10
            isIE = true;
        } else if (navigator.userAgent.match(/Trident/) && !navigator.userAgent.match(/MSIE/)) {
            isIE = true;
        }
    }
    return function () {
        return isIE;
    };
})();


// Detect if the worker threads are supported.
ETD.GEN.isWorkerSupport = (function () {

    var isWorkerSupport;
    if (ETD.GEN.isIE() && window.location.protocol === 'file:') {
        isWorkerSupport = false;
    } else {
        isWorkerSupport = !!window.Worker;
    }
    return function () {
        return isWorkerSupport;
    };
})();

// Detect if running as a progressive web app.
ETD.GEN.isProgressiveWebApp = function () {

    var queryParams /*:object*/ = $.getQueryParameters();

    if (queryParams && queryParams['utm_source'] === 'homescreen') {
        return true;
    } else {
        return false;
    }
};

// Detect if running in iframe.
ETD.GEN.isIframe = function () {
    try {
        return window.self !== window.top;
    } catch (oEx) {
        return true;
    }
};

// Detect an active search.
ETD.GEN.isSearchApplied = function () {

    return $('#idSearchString').val().trim() !== '';
};
// ==============================================


// Pass a configuration object to the plot.
ETD.GEN.setConfig = function (domParent, config /*:object*/) {
    // domParent - the parent div-element of the chart, or the id of the div-element
    // config - the configuration object

    SVGware.draw(domParent, { config: config });
};

// Get an array of objects with info on selected data.
ETD.GEN.getSelectedData = function (domParent, params) {
    // domParent - the parent div-element of the chart, or the id of the div-element;
    // params - an object of parameters, specifies the data selection;
    //   One of the following:
    //      { circle: {cx:, cy:, r:} } - plotted data within the circle with center at (cx, cy) and radius r are returned;
    //      { rectangle: {x:, y:, width:, height:} } - plotted data within the rectangle specified with the top left corner (x, y) and
    //         dimensions (width:, height) are returned;
    //      { variable:, members: } - here 'variable' is a variable name, and 'members' is an object (a map) which maps 1-based member index
    //         (the row index in the input data table) to true (or '1'). If 'variable' is undefined, applies to all variables.
    //         All plotted data with the specified variable name and member index are returned.
    // Returns an array of objects
    //      { variable:, member:, x:, y:, domElement: }
    //   where 'variable' is the variable name, 'member' is the 1-based index of the data member (row index in the data table),
    //   x, y are the coordinates of the data point, and domElement is the SVG element representing the data item.

    return SVGware.get(domParent, 'selectedData', params);
};

// Get the SVG-format string for the chart.
// Options: The result does / does not contain JavaScript code with the data, configuration and style objects.
ETD.GEN.getSVG = function (domParent, withJavaScript /*:boolean*/) {
    // domParent - the parent div-element of the chart, or the id of the div-element;
    // withJavaScript - if false, the result is a static svg-image, otherwise javascript code with data,
    //   configuration and style objects is added;

    if (!ETD.CHART.exists()) {
        return '';
    } else if (!withJavaScript) {
        return SVGware.get(domParent, 'svg');
    } else {
        return SVGware.get(domParent, 'svgWithJavaScript');
    }
};

// Set the zoom and the point of interest for multiple
// charts according to the state of a selected chart.
ETD.GEN.zoomSynchronously = function (event, primaryChartID, chartID /*:array*/) {
    // event - a custom event-object passed to the onDraw callback;
    // primaryChartID - id of the chart whose zoom state is set to the other charts;
    // chartID - array of chart id-s; the zoom state is set for all of them
    //              except for the chart with id primaryChartID;

    var secChartID, values /*:array*/, inx; /*:int*/

    // if the chart with id primaryChartID is ready,
    // the zoom state is set for other charts
    if (event.readyState === 'complete' && event.id === primaryChartID) {

        // find the center of the plot area and
        // convert from the coordinates to the scale values
        values = SVGware.get(event.id, 'convertedValues', [
            { posX: event.plotArea.x + event.plotArea.width / 2 },
            { posY: event.plotArea.y + event.plotArea.height / 2 }
        ]);

        // loop over all charts in chartID;
        for (inx = 0; inx < chartID.length; inx++) {

            secChartID = chartID[inx];

            // skip the chart with id primaryChartID;
            if (secChartID === primaryChartID) {
                continue;
            }

            // set the zoom state
            SVGware.zoom(secChartID, {
                zoomX: event.zoomX, zoomY: event.zoomY,
                x: values[0].x, y1: values[1].y1
            });
        }
    }

    return true;
};

// Delete the plot.
ETD.GEN.release = function (domParent) {
    // domParent (optional) - the parent div-element of the chart;
    //   if undefined, applies to all charts;

    SVGware.release(domParent);
};

// Create an SVG element and set its attributes.
ETD.GEN.createElement = function (tagname /*:string*/, domParent, attributes /*:object*/, domBefore) {
    // tagname - name of the svg element, e.g., 'rect'
    // domParent - the parent div-element of the chart, or the id of the div-element
    // attributes - map of attributes for the svg element, e.g., { x:1000, y:2000, width:10000 }
    // domBefore - a child element of domParent;
    //   if specified, the new element is inserted before domBefore;

    var svgdoc = domParent.ownerDocument,
        nsXml = ETD.GEN.getNamespace(domParent), // 'http://www.w3.org/2000/svg'
        domX,
        key; /*:string*/

    domX = svgdoc.createElementNS(nsXml, tagname);
    for (key in attributes) {
        domX.setAttributeNS(null, key, attributes[key]);
    }

    // in iOS (iPad/iPhone/iPod), event delegation for click events
    // does not work if the handler is missing;
    // set a dummy handler;
    if (ETD.INIT.is_iOS()) {
        domX.setAttribute('onclick', 'void(0)');
    }

    if (!domBefore) {
        return domParent.appendChild(domX);
    } else {
        return domParent.insertBefore(domX, domBefore);
    }
};

// Set attributes for the svg element.
ETD.GEN.setAttributes = function (domElement, attributes /*:object*/) {
    // domElement - svg element
    // attributes - map of attributes for the svg element, e.g., { x:1000, y:2000, width:10000 }

    for (var key in attributes) {
        domElement.setAttributeNS(null, key, attributes[key]);
    }
};

// Remove the elements from the document.
ETD.GEN.removeElements = function (ids /*:array*/, doc) {
    // ids - array of element id-s;
    // svgdoc - the document object;

    var inx, domX;

    for (inx = 0; inx < ids.length; inx++) {
        domX = doc.getElementById(ids[inx]);
        if (domX) {
            domX.parentNode.removeChild(domX);
        }
    }
};

ETD.GEN.getNamespace = function (domElement) {

    var nsURI; /*:string*/

    if (typeof domElement.lookupNamespaceURI === 'function') {
        nsURI = domElement.lookupNamespaceURI(null);
        if (nsURI) { // here if svg document and native support for svg
            return domElement.lookupNamespaceURI(null);
        }
    }

    if (typeof domElement.namespaceURI === 'string') { // here if html document, or internet Explorer 8 + Adobe SVG Viewer
        return domElement.namespaceURI;
    }

    return '';
};

// Return true if the svg element or one of its ancestors has id matching the pattern,
// otherwise return false.
ETD.GEN.isDescendantOf = function (domX, pattern /*:string*/, modifiers /*:string*/) {
    // domX - an svg dom-element;
    // pattern - pattern of the regular expression applied
    //     to the id attribute of the dom-element and its ancestors;
    // modifiers - modifiers of the regular expression;

    var regExp, id;

    // dynamic regular expression
    regExp = new RegExp(pattern, modifiers);

    // check dom-element and its ancestors
    while (domX) {
        if (typeof domX.getAttributeNS !== 'undefined') {
            id = domX.getAttributeNS(null, 'id');
            if (id && id.search(regExp) >= 0) {
                return true;
            }
        }
        domX = domX.parentNode;
    }

    return false;
};

ETD.GEN.addEventListener = function (domX, eventType /*:string*/, handler /*:function*/) {

    eventType = eventType.toLowerCase();
    if (typeof domX.addEventListener !== 'undefined') { // ie9, ff, chrome, opera, safari
        domX.addEventListener(eventType, handler, false);
    } else if (typeof domX.attachEvent !== 'undefined') { // ie8
        domX.attachEvent('on' + eventType, handler);
    }
};

// Set links at the example charts.
ETD.GEN.setButtons = function (ids /*:array*/, idSelected) {

    var selected /*:int*/, domL, inx;

    for (inx = 0; inx < ids.length; inx++) {
        if (ids[inx] === idSelected) {
            selected = inx;
            break;
        }
    }
    if (typeof selected !== 'number') {
        return undefined;
    }

    for (inx = 0; inx < ids.length; inx++) {
        domL = document.getElementById(ids[inx]);
        if (!domL) continue;
        if (ids[inx] !== idSelected) {
            domL.className = 'cnLink';
        } else {
            domL.className = 'cnLinkSel';
            selected = inx;
        }
    }

    return selected;
};

// Display context menu with buttons Zoom In, Zoom Out, and Select.
ETD.GEN.displayContextMenu = function (event /*:object*/, domGCallback, dataSelector /*:object*/, shadow /*:boolean*/) {
    // event - a custom event-object;
    // domGCallback - svg g-element for drawing on the chart;
    // dataSelector - data selector object created by calling ETD.SELECTOR.create() (file 'svgware_selector.js');
    // shadow - if true, apply shadow filters;

    // size of a menu button: 32 pixels and padding
    var UPP = ETD.UPP, // 1 pixel corresponds to 10 units
        btnS /*:int*/ = 32 * UPP,
        padding /*:int*/ = 8 * UPP,
        menuH /*:int*/ = btnS + 2 * padding, menuW /*:int*/,

        doc = domGCallback.ownerDocument,
        touchDevice /*:boolean*/ = ETD.AFO.touchFriendlyMode,
        btnCnt /*:int*/,
        withSelectButton /*:boolean*/,
        domGMenu, button /*:object*/,
        href /*:string*/,
        x /*:int*/, y; /*:int*/

    // add a button to the menu
    function addMenuButton(idCommand, domGParent, buttonInx /*:int*/, last /*:boolean*/, href, title /*:string*/) {
        // idCommand - command id, one of 'idCommandZoomIn', 'idCommandZoomOut', 'idCommandSelect';
        // domGParent - parent g-element for the menu;
        // buttonInx - 0-based index of the button;
        // last - set to true if this is the last button of the menu;
        // href -  'href' attribute, specifies the URL of the image of the button;
        // title - title (tooltip) for the button;

        var UPP = ETD.UPP, // 1 pixel corresponds to 10 units
            nsXmlXLink = 'http://www.w3.org/1999/xlink',
            domG, domRect, domImage;

        domG = ETD.GEN.createElement('g', domGParent);
        ETD.GEN.setTitle(domG, title);

        // create rect-element for the button
        domRect = ETD.GEN.createElement('rect', domG, {
            id: idCommand,
            width: btnS + padding + (buttonInx !== 0 ? 0 : padding / 2) + (!last ? 0 : padding / 2),
            height: menuH,
            x: buttonInx * btnS + (buttonInx + (buttonInx !== 0 ? 0.5 : 0)) * padding,
            y: 0,
            fill: 'white', 'fill-opacity': 0,
            stroke: 'none', 'stroke-opacity': 1, 'stroke-width': UPP,
            'shape-rendering': 'crispEdges'
        });

        // add button image
        domImage = ETD.GEN.createElement('image', domG, {
            id: idCommand + 'Img',
            x: buttonInx * btnS + (buttonInx + 1) * padding,
            y: padding,
            width: btnS,
            height: btnS
        });
        domImage.setAttributeNS(nsXmlXLink, 'href', href);

        return { domG: domG, domRect: domRect, domImage: domImage };
    }


    // if outside the plot area, or the menu is displayed already,
    // or the event target is in the menu,
    // remove the menu and return;
    if (!ETD.GEN.isInRect(event.position, event.plotArea) ||
        doc.getElementById('idMenu')) {

        // remove old menu
        ETD.GEN.removeElements(['idMenu'], doc);

        return;
    }

    // number of menu buttons - 1, 2 or 3;
    btnCnt = 3; // the buttons Zoom In, Zoom Out, Select an Area
    // check if the button Select an Area should be displayed;
    // for this button the data selector object and the menu item handler are required;
    withSelectButton = !!dataSelector;
    if (!withSelectButton) {
        btnCnt -= 1;
    }
    // if the zoom value is 1, exclude the button Zoom Out
    if (event.zoom === 1) {
        btnCnt -= 1;
    }

    // width of the menu (2 or 3 buttons and padding)
    menuW = btnCnt * btnS + (btnCnt + 1) * padding;

    // create the menu with buttons;
    domGMenu = ETD.GEN.createElement('g', domGCallback, { id: 'idMenu' });
    ETD.GEN.createElement('rect', domGMenu, {
        id: 'idMenuRct',
        width: menuW, height: menuH,
        fill: 'white', 'fill-opacity': 0.8,
        stroke: 'black', 'stroke-opacity': 1, 'stroke-width': UPP,
        'shape-rendering': 'crispEdges',
        rx: 40, ry: 40,
        'filter': !shadow ? 'none' : 'url(#dropShadowA)'
    });

    // Zoom In button
    button = addMenuButton('idCommandZoomIn', domGMenu, 0, false, 'img/zoom-in.png', 'Zoom In');
    // Click event and touchstart event handler for the Zoom In button:
    // Call the function
    //   event.handlers.changeZoom ()
    // and pass 1 as the argument.
    if (!touchDevice) {
        ETD.GEN.addEventListener(button.domG, 'click', function () {
            event.handlers.changeZoom(1);
        });
    } else {
        ETD.GEN.addEventListener(button.domG, 'touchstart', function () {
            event.handlers.changeZoom(1);
        });
    }

    // Zoom Out button
    if (event.zoom !== 1) {
        button = addMenuButton('idCommandZoomOut', domGMenu, 1, false, 'img/zoom-out.png', 'Zoom Out');
        // Click event and touchstart event handler for the Zoom Out button:
        // Call the function
        //   event.handlers.changeZoom ()
        // and pass -1 as the argument.
        ETD.GEN.addEventListener(button.domG, 'click', function () {
            event.handlers.changeZoom(-1);
        });
        ETD.GEN.addEventListener(button.domG, 'touchstart', function () {
            event.handlers.changeZoom(-1);
        });
    }

    // Select button
    // select the icon depending on whether it is the first or second click
    // (two clicks are needed to select a rectangle)
    if (withSelectButton) {
        href = 'img/selection-1.png';
        if (dataSelector && dataSelector.getPoint()) {
            href = 'img/selection-2.png';
        }
        button = addMenuButton('idCommandSelect', domGMenu, btnCnt - 1, true, href, 'Select an Area');
    }

    // position the menu
    x = Math.max(event.position.x - menuW / 2, UPP);
    x = Math.min(x, event.chartArea.width - menuW - UPP);
    y = Math.max(event.position.y - menuH, UPP);
    y = Math.min(y, event.chartArea.height - menuH - UPP);
    domGMenu.setAttributeNS(null, 'transform', 'translate(' + x + ',' + y + ')');
};

// Draw an infotip. // possibility to modify infotip style with the style file - siin#
ETD.GEN.drawInfotip = function (event /*:object*/, domGCallback, idGInfotip, labels /*:array*/, dimensions /*:object*/, shadow /*:boolean*/) {
    // event - a custom event-object;
    // domGCallback - svg g-element for drawing on the chart;
    // idGInfotip - id of the infotip container (g-element);
    // labels - an array of objects { label:, color: }, define the text and color
    //   of lines on the infotip;
    // dimensions - an object { width:, height: }, the dimensions of the infotip;
    //   if undefined, the dimensions are measured here before rendering;
    // shadow - if true, apply a built-in shadow filter;


    var doc = domGCallback.ownerDocument,
        UPP = ETD.UPP, // 1 pixel corresponds to 10 units
        domGInfotip, domInfotipRct,
        maxRowCnt /*:int*/, maxLabelL /*:int*/,
        domTxt, domTspn, tspns /*:array*/ = [],
        label /*:string*/, inx /*:int*/,
        boundingBox /*:object*/,
        dl /*:number*/,
        lineH = 14 * UPP,
        itW /*:int*/, itH /*:int*/, itX /*:int*/, itY /*:int*/,
        x /*:int*/, y; /*:int*/

    // if outside the plot area or no labels passed, remove the old infotip and return
    if (!ETD.GEN.isInRect(event.position, event.plotArea) || labels.length === 0) {
        ETD.GEN.removeElements([idGInfotip], doc);
        return { domg: null, dimensions: dimensions };
    }

    // create a new infotip
    domGInfotip = ETD.GEN.createElement('g', domGCallback, { id: idGInfotip });
    domInfotipRct = ETD.GEN.createElement('rect', domGInfotip, {
        id: 'idInfotipRct', fill: 'white', 'fill-opacity': 0.9,
        stroke: 'black', 'stroke-opacity': 0.9, 'stroke-width': UPP,
        'shape-rendering': 'crispEdges',
        filter: !shadow ? 'none' : 'url(#dropShadowCA)'
    });

    // check if the infotip size is predefined,
    // and if it is, get the maximum number of rows and
    // the maximum number of characters in a row
    if (dimensions && typeof dimensions.row_count === 'number' && typeof dimensions.char_count === 'number') {
        maxRowCnt = dimensions.row_count;
        maxLabelL = dimensions.char_count;
    } else {
        maxRowCnt = 1000; // a dummy large number
        maxLabelL = 1000; // a dummy large number
    }

    // create text element and tspan element
    domTxt = ETD.GEN.createElement('text', domGInfotip, { id: 'idInfotipTxt' });
    for (inx = 0; inx < Math.min(labels.length, maxRowCnt); inx++) {
        domTspn = ETD.GEN.createElement('tspan', domTxt, {
            'font-family': 'Verdana', 'font-size': 11 * UPP,
            'font-weight': 'bold', // 'font-weight': 'normal',
            'fill': labels[inx].color || 'black',
            'text-rendering': 'optimizeLegibility', x: 0
            //, dy: lineH // dy attribute
        });
        label = labels[inx].label;

        // check if the label is too long
        if (label.length > maxLabelL) {
            label = label.substr(0, maxLabelL - 2) + '...';
        }

        domTspn.appendChild(doc.createTextNode(label));
        tspns.push(domTspn);
    }

    // if dimensions are not defined, get the bounding box
    if (!dimensions) {
        boundingBox = domTxt.getBBox();
        dimensions = { width: Math.round(boundingBox.width), height: Math.round(boundingBox.height) };
        /* debugging: draw text boundingbox
        ETD.GEN.createElement('rect', domGInfotip, {
            x: boundingBox.x, width: boundingBox.width,
            y: boundingBox.y, height: boundingBox.height,
            stroke: 'red', 'stroke-width': UPP, fill: ' none'
        }); */
    }

    // if event object or position is undefined, return from here;
    // this option is used to measure the infotip (usually in draw event handler);
    // later the width and height are used to draw the infotip in mousemove event handler;
    if (!event || !event.position) {
        ETD.GEN.removeElements([idGInfotip], doc);
        return { domg: null, dimensions: dimensions };
    }

    // layout, position of the infotip
    dl = 1.15 * lineH;
    itW = dimensions.width + lineH;
    itH = dimensions.height + // updated below
        lineH + tspns.length * (dl - lineH);
    x = event.position.x;
    itX = Math.max(x - itW - 32 * UPP, UPP);
    if (itX + itW + 8 * UPP > x) {
        itX = Math.min(x + 32 * UPP, event.chartArea.width - itW - UPP);
    }
    y = event.position.y;
    itY = Math.min(y - itH / 2, event.chartArea.height - itH - UPP);
    itY = Math.max(itY, UPP);

    // correct x, y, width, height
    itX = ETD.GEN.correctCoordinate(itX, UPP);
    itY = ETD.GEN.correctCoordinate(itY, UPP);
    itW = ETD.GEN.correctWH(itW);
    itH = ETD.GEN.correctWH(itH);

    // set location of tspan elements
    for (inx = 0; inx < tspns.length; inx++) {
        ETD.GEN.setAttributes(tspns[inx], {
            x: itX + 0.5 * lineH,
            y: itY + inx * dl
        });
    }

    // find new boundingbox
    boundingBox = domTxt.getBBox();
    itH = ETD.GEN.correctWH(boundingBox.height + lineH);

    // set location of the rect
    /* debugging: draw text boundingbox
    ETD.GEN.createElement('rect', domGInfotip, {
        x: boundingBox.x, width: boundingBox.width,
        y: boundingBox.y, height: boundingBox.height,
        stroke: 'red', 'stroke-width': UPP, fill: ' none'
    }); */
    ETD.GEN.setAttributes(domInfotipRct, {
        x: itX,
        y: ETD.GEN.correctCoordinate(boundingBox.y - (itH - boundingBox.height) / 2, UPP),
        width: itW,
        height: itH
    });

    return { domg: domGInfotip, dimensions: dimensions };
};

// Mark a specific location on the plot by drawing a little circle.
ETD.GEN.markPoint = function (domParent, x /*:number*/, y /*:number*/, color) {
    // domParent - parent dom-element;
    // x, y - x- and y-coordinate of the point;
    // color - fill attribute of the new circle;

    var UPP = ETD.UPP, // 1 pixel corresponds to 10 units
        radius; /*:number*/

    // draw a circle
    radius = 1.5 * UPP;
    ETD.GEN.createElement('circle', domParent, {
        cx: x, cy: y, r: radius,
        stroke: 'none', 'stroke-width': UPP, 'stroke-opacity': 1,
        fill: color, 'fill-opacity': 1,
        'shape-rendering': 'geometricPrecision'
    });
};

// Change the fill (color) and fill-opacity attributes of an svg-element (data symbol).
// Store the element and its original attribute values so that it could be restored later.
ETD.GEN.changeElement = function (domElement, fill, opacity, domElems /*:array*/) {
    // domElement - dom-element to be changed;
    // fill - new fill (color) attribute value of the dom-element;
    // opacity - new fill-opacity attribute value of the dom-element;
    // domElems - array of objects of type { domElement:, fill:, fillOpacity: };
    //   the changed dom-element and its original fill and fill-opacity attribute values are stored;

    var oldOpacity;

    if (!domElement) {
        return;
    }

    // get the fill-opacity attribute value; if not set, store the value as null;
    oldOpacity = domElement.getAttributeNS(null, 'fill-opacity');
    if (typeof oldOpacity !== 'string') {
        oldOpacity = null;
    }

    // store the element and the attribute values
    domElems.push({
        domElement: domElement,
        fill: domElement.getAttributeNS(null, 'fill'),
        fillOpacity: oldOpacity
    });

    // set new fill and fill-opacity
    domElement.setAttributeNS(null, 'fill', fill);
    domElement.setAttributeNS(null, 'fill-opacity', opacity);
};

// Restore the fill (color) and fill-opacity attributes
// of the svg-elements (data symbols) stored in the array.
ETD.GEN.restoreElements = function (domElems /*:array*/) {
    // domElems - array of objects of type { domElement:, fill:, fillOpacity: };
    //   the changed dom-element and its original fill and fill-opacity attribute values are stored;

    var opacity, item /*:object*/, inx;

    // create the array if not yet created
    if (!domElems) {
        domElems = [];
    }

    // loop over the array and restore the fill (color) and fill-opacity attributes of the elements
    // (data symbols);
    // special processing for use tags; check
    //if (item.domElement.tagName === 'use');
    for (inx = 0; inx < domElems.length; inx++) {
        item = domElems[inx];
        if (item.fill) { // fill may be set in the parent g-element
            item.domElement.setAttributeNS(null, 'fill', item.fill);
        } else {
            item.domElement.removeAttributeNS(null, 'fill');
        }
        opacity = parseFloat(item.fillOpacity);
        if (!isNaN(opacity)) { // fill-opacity may be set in the parent g-element
            item.domElement.setAttributeNS(null, 'fill-opacity', item.fillOpacity);
        } else {
            item.domElement.removeAttributeNS(null, 'fill-opacity');
        }
    }

    // reset the array
    domElems = [];

    return domElems;
};

// Return true if the point is inside the rectangle, otherwise return false.
ETD.GEN.isInRect = function (point /*:object*/, rect /*:object*/) {
    // point - a point object { x:, y: };
    // rect - a rectangle object { x:, width:, y:, height: };

    if (!point || !rect) {
        return false;
    }
    if (isNaN(point.x) || isNaN(point.y)) {
        return false;
    }
    if (isNaN(rect.x) || isNaN(rect.width) || isNaN(rect.y) || isNaN(rect.height)) {
        return false;
    }

    return point.x >= rect.x && point.x <= rect.x + rect.width && point.y >= rect.y && point.y <= rect.y + rect.height;
};

// Set title for an SVG element.
ETD.GEN.setTitle = function (domElement, title /*:string*/) {
    // domElement - an SVG element;
    // title - title (string) for the SVG element;

    var doc = domElement.ownerDocument,
        nsXml = ETD.GEN.getNamespace(domElement), // 'http://www.w3.org/2000/svg'
        domTitle,
        domTxtN;

    domTitle = doc.createElementNS(nsXml, 'title');
    domTxtN = doc.createTextNode(title);
    domTitle.appendChild(domTxtN);
    domElement.appendChild(domTitle);
};

// Search in the array of objects.
// This function is called for table search.
ETD.GEN.searchTable = function (getDataItem /*:function*/, datasetSize /*:int*/, settings /*:object*/) {
    // getDataItem - a function,
    //   function(iRowID, iRowNo) { },
    //   where
    //   iRowID - row id (0-based), and
    //   iRowNo - current row number, depends on data filtering and sorting (0-based);
    // datasetSize - dataset size;
    // settings.string - search string or regular expression;
    // settings.mode - 'string'/'regex'/'javascript';
    //   if settings.mode is 'regex', settings.string is a regular expression;
    //   if settings.mode is 'javascript', settings.string is a javascript expression, e.g.,
    //   y = x>250;
    //   where x is the cell value (numeric) and y is set to true if the value matches;
    // settings.casesensitive - if true, the search is case sensitive;
    // settings.wholeword - if true, march whole words only;
    //   does not apply for regular expression search;
    // settings.incolumn - if set to '_all_columns', search in all members (table columns);
    //   otherwise search in the specified member (table column) only;

    var matchingRowsCells /*:array*/,
        stringS /*:string*/,
        convertToStrLC /*:function*/,
        idx /*:int*/, item /*:object*/,
        match, key /*:string*/, value /*:string*/,
        maxCodeL /*:int*/, testItem; /*:function*/

    // >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
    function isMatchingWholeWord(string /*:string*/, substring /*:string*/, matchInx /*:int*/) {

        var charX; /*:string*/
        if (matchInx > 0) {
            charX = string[matchInx - 1];
            if (charX !== ' ') {
                return false;
            }
        }
        if (string.length > matchInx + substring.length) {
            charX = string[matchInx + substring.length];
            if (charX !== ' ') {
                return false;
            }
        }
        return true;
    }

    function stringSearch(string /*:string*/, substring /*:string*/, wholeWord /*:boolean*/, rowInx /*:int*/, variable /*:string*/, match) {

        var start /*:int*/ = 0, matchInx; /*:int*/
        while (true) {
            matchInx = string.indexOf(substring, start);
            if (matchInx >= 0) {
                if (!wholeWord || isMatchingWholeWord(string, substring, matchInx)) {
                    if (!match) {
                        match = { rowID: rowInx, cells: {} };
                    }
                    if (!match.cells[variable]) {
                        match.cells[variable] = '';
                    } else {
                        match.cells[variable] += ',';
                    }
                    match.cells[variable] += matchInx + ',' + (matchInx + substring.length);
                }
                start = matchInx + substring.length;
            } else {
                break;
            }
        }
        return match;
    }

    function regexSearch(string /*:string*/, regExp, rowInx /*:int*/, variable /*:string*/, match) {

        var result; /*:object*/
        while ((result = regExp.exec(string)) !== null) {
            if (!match) {
                match = { rowID: rowInx, cells: {} };
            }
            if (!match.cells[variable]) {
                match.cells[variable] = '';
            } else {
                match.cells[variable] += ',';
            }
            match.cells[variable] += result.index + ',' + (result.index + result[0].length);
        }

        return match;
    }

    // find numbers that match a javascript condition;
    // example: y = x>250
    // set mode_javascript to true:
    settings.mode_javascript = true;
    function javascriptSearch(testItem /*:function*/, value /*:string*/, rowInx /*:int*/, variable /*:string*/, match) {

        if (testItem(value)) {
            if (!match) {
                match = { rowID: rowInx, cells: {} };
            }
            if (!match.cells[variable]) {
                match.cells[variable] = '';
            } else {
                match.cells[variable] += ',';
            }
            match.cells[variable] += '0,' + value.toString().length;
        }
        return match;
    }

    // <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

    matchingRowsCells = [];

    // skip if the search string is empty;
    if (settings.string === '') {
        return matchingRowsCells;
    }

    // the search mode
    settings.mode = settings.mode || 'string'; // string/regex/javascript

    // search in the data array;
    if (settings.mode === 'string') { // string search

        stringS = settings.string.toString();
        if (!settings.casesensitive) { // case insensitive search
            stringS = stringS.toLowerCase();
            convertToStrLC = function (string) {
                return string.toString().toLowerCase();
            };
        } else { // case sensitive search
            convertToStrLC = function (string) {
                return string.toString();
            };
        }

        // find indexes of matching rows, and indexes of matches in the cell(s)
        if (settings.incolumn === '_all_columns') { // search in all columns
            // loop over dataset members (table rows)
            for (idx = 0; idx < datasetSize; idx++) {
                match = null;
                item = getDataItem(idx, matchingRowsCells.length);
                // loop over variables (table columns)
                for (key in item) {
                    if (key === ETD.GEN.rowNoVar) continue;
                    value = convertToStrLC(item[key]);
                    match = stringSearch(value, stringS, settings.wholeword, idx, key, match);
                }
                if (match) {
                    matchingRowsCells[matchingRowsCells.length] = match;
                }
            }
        } else { // search in a specified column (settings.incolumn)
            // loop over dataset members (table rows)

            for (idx = 0; idx < datasetSize; idx++) {
                match = null;
                item = getDataItem(idx, matchingRowsCells.length, settings.incolumn);
                if (settings.incolumn in item) {
                    value = convertToStrLC(item[settings.incolumn]);
                    match = stringSearch(value, stringS, settings.wholeword,
                        idx, settings.incolumn, match);
                    if (match) {
                        matchingRowsCells[matchingRowsCells.length] = match;
                    }
                }
            }
        }
    } else if (settings.mode === 'regex') { // regular expression search

        regExp = new RegExp(settings.string, !settings.casesensitive ? 'gi' : 'g'); // dynamic regular expression

        // find indexes of matching rows, and indexes of matches in the cell(s)
        if (settings.incolumn === '_all_columns') { // search in all columns
            // loop over dataset members (table rows)
            for (idx = 0; idx < datasetSize; idx++) {
                match = null;
                item = getDataItem(idx, matchingRowsCells.length);
                // loop over variables (table columns)
                for (key in item) {
                    if (key === ETD.GEN.rowNoVar) continue;
                    value = item[key];
                    match = regexSearch(value, regExp, idx, key, match);
                }
                if (match) {
                    matchingRowsCells[matchingRowsCells.length] = match;
                }
            }
        } else { // search in a specified column (settings.incolumn)
            // loop over dataset members (table rows)
            for (idx = 0; idx < datasetSize; idx++) {
                match = null;
                item = getDataItem(idx, matchingRowsCells.length, settings.incolumn);
                if (settings.incolumn in item) {
                    value = item[settings.incolumn];
                    match = regexSearch(value, regExp, idx, settings.incolumn, match);
                    if (match) {
                        matchingRowsCells[matchingRowsCells.length] = match;
                    }
                }
            }
        }
    } else if (settings.mode === 'javascript') { // javascript search

        stringS = settings.string.toString();

        // security check of the search code
        maxCodeL = 100;
        if (stringS.length > maxCodeL) {
            throw { message: 'Error: The search code is too long (maximum length is ' + maxCodeL + ').' };
        }
        if (stringS.indexOf('Windows') >= 0) {
            throw { message: 'Error: The search code is illegal.' };
        }

        // function for finding matching items
        testItem = new Function('x', 'var y; ' + stringS + '; return y;');

        if (settings.incolumn === '_all_columns') { // search in all columns

            // loop over dataset members (table rows)
            for (idx = 0; idx < datasetSize; idx++) {
                match = null;
                item = getDataItem(idx, matchingRowsCells.length);
                // loop over variables (table columns)
                for (key in item) {
                    if (key === ETD.GEN.rowNoVar) continue;
                    value = item[key];
                    match = javascriptSearch(testItem, value, idx, key, match);
                }
                if (match) {
                    matchingRowsCells[matchingRowsCells.length] = match;
                }
            }
        } else { // search in a specified column (settings.incolumn)
            // loop over dataset members (table rows)

            for (idx = 0; idx < datasetSize; idx++) {
                match = null;
                item = getDataItem(idx, matchingRowsCells.length, settings.incolumn);
                if (settings.incolumn in item) {
                    value = item[settings.incolumn];
                    match = javascriptSearch(testItem, value, idx, settings.incolumn, match);
                    if (match) {
                        matchingRowsCells[matchingRowsCells.length] = match;
                    }
                }
            }
        }
    }

    return matchingRowsCells;
};

ETD.GEN.papaparse = function (contents /*:array*/, contIndex /*:int*/, processLine /*:function*/, onReady /*:function*/) {

    ETD.AFO.message('Parsing text...', 'info', true);

    // parse csv;
    // http://papaparse.com/
    // worker thread is used if processing line by line (callback step());
    // returns:
    //   parse.data
    //   parse.errors
    //   parse.meta
    Papa.parse(contents[contIndex], {
        delimiter: ',',  // blank: auto-detect
        newline: '', // blank: auto-detect
        quoteChar: '"',
        escapeChar: '"',
        header: false,
        transformHeader: undefined,
        dynamicTyping: false, // if true, numeric and boolean data
        // will be converted to their type instead of remaining strings;
        preview: 0,
        encoding: '', // the encoding to use when opening files locally
        worker: ETD.GEN.isWorkerSupport(), // even if true, internally may be set to false,
        // see modification around line 150 in 'papaparse-4.3.6.js'
        comments: '#', // specify a comment character (like '#')
        step: processLine, // a callback function to receive results row-by-row
        complete: contIndex + 1 < contents.length ? // a callback to execute when parsing is complete
            function () {
                ETD.GEN.papaparse(contents, ++contIndex, processLine, onReady);
            } : onReady,
        error: function (error, file) { // not called?
            ETD.AFO.release();
            if (typeof error.message === 'string') {
                ETD.AFO.message('Error: File import failed.', 'error', true);
            } else {
                ETD.AFO.message('Error: File import failed (' + error.message + ').', 'error', true);
            }
        },
        download: false,
        downloadRequestHeaders: undefined,
        //keepEmptyRows: false,
        skipEmptyLines: true,
        chunk: undefined,
        fastMode: undefined,
        beforeFirstChunk: undefined,
        withCredentials: undefined,
        transform: undefined
        //,delimitersToGuess: [',', '\t', '|', ';', Papa.RECORD_SEP, Papa.UNIT_SEP]
    });
};

// Parse url query string and find parameters.
// from https://css-tricks.com/snippets/jquery/get-query-params-object/
$.extend({
    getQueryParameters: function (str) {
        return (str || document.location.search).
            replace(/(^\?)/, '').
            split('&').
            map(function (sNameValue) {
                var aX = sNameValue.split('=');
                this[aX[0]] = aX[1];
                return this;
            }.bind({})
            )[0];
    }
});

// Calculate distance between two points.
ETD.GEN.findDistance = function (point1 /*:object*/, point2 /*:object*/) {
    // point1 - a point object of type { x:, y: };
    // point2 - a point object of type { x:, y: };

    var dist; /*:number*/

    if (!point1 || !point2) return undefined;

    dist = Math.sqrt((point1.x - point2.x) * (point1.x - point2.x) +
        (point1.y - point2.y) * (point1.y - point2.y));

    return dist;
};

ETD.GEN.correctCoordinate = function (x /*:number*/, strokeW /*:number*/) {
    // find a corrected coordinate of a vertical or horizontal line;
    // this is a workaround for ie as it does not support crispEdges mode for shape-rendering;

    var UPP = ETD.UPP,
        x1 /*:number*/, x2; /*:number*/

    strokeW = parseInt(strokeW);
    x1 = UPP * Math.round(x / UPP) - strokeW / 2;
    x2 = x1 + UPP;
    if (Math.abs(x1 - x) < Math.abs(x2 - x)) {
        return x1;
    } else {
        return x2;
    }
};

ETD.GEN.correctWH = function (widthHeight /*:number*/) {

    return ETD.UPP * Math.round(widthHeight / ETD.UPP);
};

ETD.GEN.limitTextLength = function (text /*:string*/, softLim /*:int*/, hardLim/*:int*/) {

    var suffix = '...', textS /*:string*/, inx;

    if (typeof text !== 'string') {
        return;
    }

    textS = text.trim();

    softLim = parseInt(softLim);
    hardLim = parseInt(hardLim);
    if (isNaN(softLim) || isNaN(hardLim) || softLim + 6 >= hardLim) {
        return textS;
    }

    inx = textS.indexOf(' ', softLim - 1);
    if (inx < 0 || inx > hardLim - suffix.length) {
        inx = hardLim - suffix.length;
    }
    if (inx > textS.length) {
        return textS;
    } else {
        return textS.substring(0, inx) + suffix;
    }
};

ETD.GEN.getValueNoCase = function (object /*:object*/, member /*:string*/) {

    var memberLC /*:string*/, key; /*:string*/

    if (!object || typeof object !== 'object' || typeof member !== 'string') {
        return undefined;
    }

    memberLC = member.toLowerCase();
    for (key in object) {
        if (key.toLowerCase() === memberLC) {
            return object[key];
        }
    }
    return undefined;
};

ETD.GEN.saveAsIE9 = function (contents /*:string*/, filename /*:string*/) {

    var saveTxtWindow, doc, retValue;

    saveTxtWindow = window.frames.saveTxtWindow;
    if (!saveTxtWindow) {
        saveTxtWindow = document.createElement('iframe');
        saveTxtWindow.id = 'saveTxtWindow';
        saveTxtWindow.style.display = 'none';
        document.body.insertBefore(saveTxtWindow, null);
        saveTxtWindow = window.frames.saveTxtWindow;
        if (!saveTxtWindow) {
            saveTxtWindow = window.open('', '_temp', 'width=100,height=100');
            if (!saveTxtWindow) {
                // error
                return false;
            }
        }
    }

    doc = saveTxtWindow.document;
    doc.open('text/html', 'replace');
    doc.charset = 'utf-8';
    doc.write(contents);
    doc.close();

    retValue = doc.execCommand('SaveAs', null, filename);
    saveTxtWindow.close();
    return retValue;
};

ETD.GEN.serializeToString = function (xmlNode) {

    if (!xmlNode) {
        return '';
    }
    try {
        if (typeof XMLSerializer !== 'undefined') {
            return (new XMLSerializer()).serializeToString(xmlNode);
        } else if (xmlNode.xml) { // ie8
            return xmlNode.xml;
        }
    } catch (oEx) {
        // empty
    }
    return '';
};

ETD.GEN.storageAvailable = function (type) {

    try {
        var storage = window[type],
            x = '__storage_test__';
        storage.setItem(x, x);
        storage.removeItem(x);
        return true;
    }
    catch (ex) {
        return false;
    }
};


(function () {

    if (typeof Office === 'object' && Office) {
        // The initialize function must be run each time a new page is loaded
        Office.initialize = function (reason) { // running as AfO
            $(document).ready(function () {

                //app.initialize();
                ETD.IMPORT.loadConfigJsAndInit();
            });
        };
    } else { // running as a regular web app
        $(document).ready(function () {

            ETD.IMPORT.loadConfigJsAndInit();
        });
    }
})();


ETD.AFO = {
    VERSION: '1.8.0.0',
    TIMESTAMP: '190817-1258',
    VERS: ['1.4.0.0', '1.7.0.0', '1.7.1.0', '1.8.0.0'],
    touchFriendlyMode /*:boolean*/: undefined,
    chartCntrlsVisible /*:boolean*/: undefined,
    plotRangeInx: 1,
    defaultStyleTitle: 'Default style',
    msgBxInit /*:boolean*/: undefined,
    dgbMsgs /*:array*/: undefined, // -> ETD.AFO.dbgMsg ()
    noTitleBar: false
};

ETD.AFO.resize = function () {

    // reset horizontal scroll position of the top pane
    $('#idPaneTop').scrollLeft(0);

    var $msgbx, $msgbxPH,
        domFrame, width /*:int*/, height; /*:int*/

    // reserve space for the button in the upper right corner (office add-in)
    if (ETD.INIT.isOfficeAddin()) {
        $('.cnTopLine').width($('body').width() - 20);
    }

    // resize the messagebox and messagebox placeholder; the latter is used to make space for the message
    // by moving the folders (e.g., 'Import and Export') downward or upward;
    if (ETD.INIT.isOfficeAddin()) {
        $msgbx = $('.cnMessageBox');
        $msgbxPH = $('.cnMessagePH').parent();
        if (!ETD.AFO.msgBxInit) { // only for initialization
            $msgbx.css({
                left: $msgbxPH.offset().left + 1, top: $msgbxPH.offset().top,
                'border-top': 'solid white 1px' // hide scrolling elements on the top
            });
            ETD.AFO.msgBxInit = true;
        }
        $msgbx.outerWidth($('#idMsgEnd').offset().left - 4);
        $msgbxPH.outerHeight($('.cnMessageBox').outerHeight()); // cp. ETD.AFO.message ()
    } else {
        ETD.AFO.makeSpaceForMsgBx();
    }

    // in the inline editing mode of the table, skip resizing in touch devices;
    // the resize events occur when the keyboard is displayed;
    if (ETD.AFO.touchFriendlyMode) {
        domFrame = $('#' + ETD.TABLE.id).find('iframe').get(0);
        if ($(domFrame).contents().find('input[type^="text"]').length > 0) {
            return;
        }
    }

    // reset the layout
    if (ETD.LAYOUTER.layouter && typeof ETD.LAYOUTER.layouter.resize === 'function') {
        ETD.LAYOUTER.layouter.resize();
    }

    // below the comparison with clientHeight is added because of safari (e.g., safari 5.1 on win 7);

    // resize containers: the left side
    $('#idContainerLeftA').height($('#idSearchControls').outerHeight());

    // issue in ie9: $('#idPaneLeft').get(0) is undefined sometimes
    if (!$('#idPaneLeft').get(0)) {
        setTimeout(ETD.AFO.resize, 500);
        return;
    }

    $('#idContainerLeftB').height(
        Math.min($('#idContainerLeft').height(), $('#idPaneLeft').get(0).clientHeight) -
        $('#idContainerLeftA').height() -
        parseInt($('#idContainerLeftB').css('top')) -
        4); // space below idContainerLeftB

    // resize containers: the right side
    // chart controls visible or hidden;
    if (ETD.AFO.chartCntrlsVisible) {

        // display the right container, see also ETD.TABLE.create ()
        $('#idContainerRight').css({ display: 'block' });

        // buttons show/hide chart controls
        $('#idShowChartUI').css({ display: 'none' });
        $('#idHideChartUI').css({ display: 'block' });

        $('#idContainerRightA').css({ display: 'block' }).height($('#idChartControls').outerHeight());
        $('#idContainerRightB').width($('#idChartControls').outerWidth()).height(
            Math.min($('#idContainerRight').height(), $('#idPaneRight').get(0).clientHeight) -
            $('#idContainerRightA').height() -
            parseInt($('#idContainerRightB').css('top')) -
            4); // space below idContainerLeftB
    } else {
        // buttons show/hide chart controls
        $('#idShowChartUI').css({ display: 'block' });
        $('#idHideChartUI').css({ display: 'none' });

        $('#idContainerRightA').css({ display: 'none' });
        $('#idContainerRightB').width($('#idContainerRight').width() - 6);
        $('#idContainerRightA').height(0).css({ display: 'none' });
        $('#idContainerRightB').height(
            Math.min($('#idContainerRight').height(), $('#idPaneRight').get(0).clientHeight) -
            parseInt($('#idContainerRightB').css('top')) -
            4); // space below idContainerLeftB
    }

    // resize the table and chart
    $('#idPaneLeft').find('iframe').height($('#idTable01C').height());
    $('#idPaneRight').find('iframe').height($('#idChart01C').height());
    if (ETD.TABLE.exists()) {
        SVGware.resize('idTable01', {
            width: $('#idContainerLeftB').width(),
            height: $('#idContainerLeftB').height()
        });
    }
    if (ETD.CHART.exists()) {
        if ($.isNumeric(ETD.STYLE.general.chartWidth)) {
            width = ETD.STYLE.general.chartWidth;
        } else {
            width = $('#idContainerRightB').width();
        }
        if ($.isNumeric(ETD.STYLE.general.chartHeight)) {
            height = ETD.STYLE.general.chartHeight;
        } else {
            height = $('#idContainerRightB').height();
        }
        SVGware.resize('idChart01', { width: width, height: height });
    }
};

window.addEventListener('orientationchange', function (event) { // event.orientation: landscape/portrait
    ETD.AFO.resize();
    setTimeout(ETD.AFO.resize, 200); // test in firefox (on iOS)
});

$(window).resize(function () {
    ETD.AFO.resize();
    setTimeout(ETD.AFO.resize, 200); // test in chrome (on iOS)
});

ETD.AFO.init = function () {

    ETD.AFO.message('timestamp: ' + ETD.AFO.TIMESTAMP, 'info', false);

    // 1) in excel on ios, hide export buttons;
    // 2) in other case, a workaround to a layout problem;
    if (ETD.INIT.isOfficeAddin() && ETD.INIT.is_iOS()) {
        $('#idExportCSV').closest('tr').remove();
        $('#idExportSVG').closest('tr').remove();
    }

    // if office add-in in excel or powerpoint, adjust some elements
    if (ETD.GEN.isOfficeAddinHostPowerPoint()) {
        $('#idInstrExcel').remove();
        $('#idExcelDataExchange').remove();
        $('#idOtherMethodsTitle').remove();
        $('#idHideChartUIImg').attr('src', 'images/res/minus-p.png');
        $('#idShowChartUIImg').attr('src', 'images/res/plus-p.png');
    } else {
        $('#idInstrPowerPoint').remove();
    }

    // in progressive web app running in iOS, the links do not work; in this case, do not show the message;
    if (!(ETD.GEN.isProgressiveWebApp() && ETD.INIT.is_iOS())) {
        $('#idTopLinks').css({ visibility: 'visible' });
        $('#idLeftFooter').css({ visibility: 'visible' });
        $('#idInitMsg').css({ visibility: 'visible' });
    }

    // in office add-in, due to redirection with the base tag, need to use a base url in order to
    // access images for the table;
    if (typeof ETD.baseHref !== 'string') {
        ETD.baseHref = '';
    }

    // empty placeholders, real functions defined in win 10 app
    if (!ETD.GEN.isUnivWinPlatApp()) {
        ETD.UWP = {
            files: []
        };
        ETD.UWP.putItem = function () { };
        ETD.UWP.getItem = function () { };
        ETD.UWP.getFiles = function () { };
        ETD.UWP.deleteItem = function () { };
        ETD.UWP.collectCarbage = function () { };
        ETD.UWP.serSettings = function () { };
        ETD.UWP.deserSettings = function () { };
        ETD.UWP.detectInternetConnection = function () { };
        ETD.UWP.setFeatureLimited = function () { };
        ETD.UWP.getAddonIDMap = function () { };
        ETD.UWP.getAddonLicenseInfo = function () { };
        ETD.UWP.purchaseAddOn = function () { };
        ETD.UWP.exportTextFile = function () { };
        ETD.UWP.createCurChartThumbnail = function () { };
        ETD.UWP.showCurChartThumbnail = function () { };
        ETD.UWP.showChartThumbnails = function () { };
        ETD.UWP.createChartThumbnails = function () { };
        ETD.UWP.sortThumbnails = function () { };
        ETD.UWP.getChartThumbnailMarkup = function () { };
        ETD.UWP.initStyleEditor = function () { };
        ETD.UWP.showSvgDefs = function () { };
        ETD.UWP.showStyleEditor = function () { };
        ETD.UWP.isStyleEditorOpen = function () { };
        ETD.UWP.resetStyleEditor = function () { };
    }

    // display message about the feature limited version
    $('#idFeatureLimited').click(function (event) {
        ETD.AFO.message('This is a feature-limited version. Full functionality is available with paid license and free trial license.', 'info', true);
    });

    // clear message with clicks
    $('.cnMessageBox').click(function (event) {
        ETD.AFO.message('', 'info', true, 'm-07');
    });

    // 'Read Data' button
    ETD.EVT.addReadDataEventHandler();

    // 'Write Data' button
    ETD.EVT.addWriteDataEventHandler();

    // 'Import Data' button
    ETD.EVT.addImportDataEventHandler();

    // 'Export CSV' button
    ETD.EVT.addExportCSVEventHandler();

    // 'Export Chart' button
    ETD.EVT.addExportChartEventHandler();

    // data selected in the drop down menu
    ETD.EVT.addSelectDataEventHandler();

    // 'Import Configuration' button
    ETD.EVT.addImportConfigEventHandler();

    // style selected in the drop down menu
    ETD.EVT.addSelectStyleEventHandler();

    // remove style checkbox
    ETD.EVT.addRemoveStyleEventHandler();

    // 'Import Style' button
    ETD.EVT.addImportStyleEventHandler();

    // the table of 'Axis Titles and Scales':
    // set change- event handler for all controls, and
    // set keydown-event handler
    ETD.EVT.addAxesFolderEventHandlers();

    // hide/show chart controls
    ETD.EVT.addHideShowChartControlsEventHandlers();

    // a range of plots selected in the drop down menu
    ETD.EVT.addChangePlotRangeEventHandler();

    // drop-event for the container
    ETD.EVT.addDropEventHandler();

    // change search mode
    $('#idSearchMode').keydown(function (event) {
        ETD.TABLE.onChangeSearchMode();
    });

    // keydown on the search string (process enter key)
    $('#idSearchString').keydown(function (event) {
        ETD.TABLE.onKeyDownSearch(event);
    });

    // add search event handlers
    ETD.EVT.addSearchEventHandlers();

    // change touch-friendly mode
    $('#idTouchFriendlyMode').change(function (event) {
        ETD.AFO.touchFriendlyMode = this.value === '1';
        ETD.AFO.setTouchMode(ETD.AFO.touchFriendlyMode);
    });

    // change graphical view mode
    $('#idGraphicalView').change(function (event) {
        ETD.UWP.serSettings({ 'idGraphicalView': $(this).val() });
        if (ETD.TABLE.exists()) {
            ETD.TABLE.create(null, { reason: 'settings' }); // #idGraphicalView
        }
    });

    // change event handler for some other drop down menus
    $('#idColumnsInScrolling, #idMaxInfotipItemCount, #idChangeableZOrder').change(function () {

        // update settings
        var settings = {};
        settings[$(event.target).attr('id')] = $(this).val();
        ETD.UWP.serSettings(settings);

        ETD.SER.setModified(1); // columns rendered when scrolling, max infotip size, changeable z-order of plots;
        // new value of #idColumnsInScrolling is used after recreating the table;
    });

    // change-event handler for multiple controls;
    // the event is also bound to child select-elements;
    ETD.EVT.addChartRelatedEventHandlers();

    // apply initial style
    ETD.STYLE.general = { 'skin': ETD.STYLE.getDefaultSkinColors() }; // make sure the skin colors are defined
    ETD.STYLE.processStyleHtml(
        null,
        window.STYLE,
        ETD.GEN.isUnivWinPlatApp() ? ETD.AFO.defaultStyleTitle : /* 'default-style.html' */ ETD.AFO.defaultStyleTitle,
        false, // initial style;
        { table: false, chart: false, styleeditor: true }, // update
        true, // isInitialStyle
        false); // ignoreAddonOffer
    // the functionality of the style editor (uwp app) depends on the default style title;

    // make sure onchange event handler is called for textboxes;
    // it would not be called in ie;
    $('input[type=text]').on('change', function (event) {
        $.data(this, 'value', this.value);
    }).on('keyup', function (event) {
        if (event.which === 13 && this.value !== $.data(this, 'value')) {
            //$(this).change();
            $(this).trigger('blur');
            $(this).focus();
        }
    });

    // set layout; see also init.js;
    (function () {

        if (!ETD.LAYOUTER.layouter) {

            var layoutLeft, layoutTop, topH;

            layoutLeft = 0.50;
            topH = $('#idDate').offset().top + 24;
            layoutTop = Math.min(topH / $('#idPaneTop').parent().outerHeight(true), 0.8);

            ETD.LAYOUTER.layouter = ETD.LAYOUTER.create(layoutLeft, layoutTop, // copied from init file
                ETD.LAYOUTER.onDragLayouterStart, ETD.LAYOUTER.onDragLayouter, ETD.LAYOUTER.onDragLayouterStop,
                ETD.AFO.touchFriendlyMode);
        }
    })();

    // touch-friendly device/mode
    ETD.AFO.touchFriendlyMode = ETD.GEN.isTouchDevice();
    if (ETD.UWP.settings && ETD.UWP.settings.hasOwnProperty('idTouchFriendlyMode')) {
        ETD.AFO.touchFriendlyMode = ETD.UWP.settings['idTouchFriendlyMode'] === 1;
    }
    ETD.AFO.setTouchMode(ETD.AFO.touchFriendlyMode);
    $('#idTouchFriendly').click(function (event) {
        ETD.AFO.setTouchMode(!ETD.AFO.touchFriendlyMode);
    });

    // other settings
    if (ETD.UWP.settings) {
        $('#idGraphicalView').val(ETD.UWP.settings['idGraphicalView']);
        $('#idColumnsInScrolling').val(ETD.UWP.settings['idColumnsInScrolling']);
        $('#idMaxDataSymbolCount').val(ETD.UWP.settings['idMaxDataSymbolCount']);
        $('#idMaxInfotipItemCount').val(ETD.UWP.settings['idMaxInfotipItemCount']);
        $('#idChangeableZOrder').val(ETD.UWP.settings['idChangeableZOrder']);
        $('#idSortChartThumbnails').val(ETD.UWP.settings['idSortChartThumbnails']); // in winapp
    }

    // reset example data drop down menu
    $('#idSelectData :nth-child(1)').prop('selected', true);

    // reset message, init data menu
    ETD.AFO.onNewData(false, false, false, false, true, 'init'); // in ETD.AFO.init (); see also ETD.IMPORT.loadConfigJsAndInit ();

    // deserialize (only office add-in), init win app
    if (ETD.INIT.isOfficeAddin()) {
        ETD.SER.deserialize();

    } else if (ETD.GEN.isUnivWinPlatApp()) { // init win app

        // style editor event handlers
        ETD.EVT.addStyleEditorEventHandlers();

        // deserialize and display last table and chart
        ETD.SERUWP.deserialize(ETD.IDB.getItemID('chart_current'), false, true, true).then( // keepLayout, ignoreErrorMsg, ignoreAddonOffer
            // ignoreAddonOffer - if true, the link for purhasing add-on (in Style folder) is not displayed, eg., the folder remains closed
            function () { }, // current chart loaded
            function (error) { } // current chart not loaded
        );

        // create current chart thumbnail, deserialize and display chart thumbnails (uwp app)
        ETD.UWP.createCurChartThumbnail();
        ETD.UWP.createChartThumbnails();

        // set feature limited
        ETD.UWP.setFeatureLimited();
        //setTimeout(function () {
        //    ETD.UWP.setFeatureLimited(false); // dbg
        //}, 10000);

        // purchase add-on event handler
        $('#idPurchaseAddon').click(function (event) {
            ETD.UWP.purchaseAddOn();
        });

        // check add-on license; if licensed, set full version;
        ETD.UWP.getAddonLicenseInfo().then(
            function (result) { // valid add-on license
                ETD.UWP.setFeatureLimited(false);
            },
            function (error) {
                ETD.AFO.message(error.message, 'error', true);
            });
    }

    // dbg: set feature limited
    /*
    ETD.UWP.setFeatureLimited(true);
    setTimeout(function () {
        ETD.UWP.setFeatureLimited(false);
    }, 10000); */

    // debugging
    if (typeof ETD.TEST === 'object') {
        ETD.TEST.checkTitles();
    }
};

ETD.AFO.setTouchMode = function (touchFriendlyMode /*:boolean*/) {

    if (!ETD.LAYOUTER.layouter) {
        return;
    }

    ETD.AFO.touchFriendlyMode = touchFriendlyMode;

    // update link (button)
    if (ETD.AFO.touchFriendlyMode) {
        $('#idTouchFriendly').css({
            'border-bottom': '1px solid ' + $('#idTouchFriendly').css('color')
        });
    } else {
        $('#idTouchFriendly').css({ 'border-bottom': 'none' });
    }

    // update drop menu (if present)
    $('#idTouchFriendlyMode').val(ETD.AFO.touchFriendlyMode ? '1' : '0'); // onchange event handler not called

    // update layouter
    ETD.LAYOUTER.layouter.setTouchFriendlyMode(ETD.AFO.touchFriendlyMode);

    // resize
    ETD.AFO.resize();

    // update table, chart
    if (ETD.TABLE.exists()) {
        ETD.TABLE.search({ call: { reason: 'touch-mode' } });
    }
    if (ETD.CHART.exists()) {
        ETD.CHART.update(); // in ETD.AFO.setTouchMode
    }

    ETD.UWP.serSettings({ 'idTouchFriendlyMode': ETD.AFO.touchFriendlyMode ? 1 : 0 });
};

ETD.AFO.initDataMenu = function () {

    var idEmptyItem = 'idSelectDataEmptyOption';

    // remove previous items from the select control;
    $('#idSelectData').find('option').remove();

    // add option with empty url
    $('#idSelectData').append($('<option>', { id: idEmptyItem, value: '' }).text('Select Data'));

    // add options
    $.each(ETD.CONFIG.data.items, function (index, oItem) {
        if (typeof oItem.url === 'string' && typeof oItem.label === 'string') {

            oItem.url = oItem.url.trim();
            oItem.label = oItem.label.trim();

            $('#idSelectData')
                .append($('<option>', { value: oItem.url })
                    .text(oItem.label.trim()));

            // if an item with empty url, remove the one added above, no need to have multiple items with empty url
            if (oItem.url === '') {
                $('#idSelectData').find('option[id="' + idEmptyItem + '"]').remove();
            }
        }
    });

    // if only 1 option, this must be the one added above with value set to an empty string;
    // hide the select control in this case;
    // change: do not hide the select control;
    // change (180922): hide the select control if not office add-in;
    if ($('#idSelectData').find('option').length > 1) {
        $('#idSelectData').css({ visibility: 'visible' });
    } else { // the only item has url set to ''
        if (!ETD.INIT.isOfficeAddin()) {
            $('#idSelectData').css({ visibility: 'hidden' });
        }
    }
};

ETD.AFO.initStyleMenu = function (selVal) {

    var idEmptyItem = 'idSelectStyleEmptyOption',
        filename; /*:string*/

    function onEndProc(sVal) {

        // try to restore selection
        $('#idSelectStyle').find('option[value="' + sVal + '"]').attr('selected', 'selected');

        // if only 1 option, this must be the one added above with value set to an empty string;
        // hide the select control in this case;
        // change: do not hide the select control;
        if ($('#idSelectStyle > option').length > 1) {
            $('#idSelectStyle').css({ visibility: 'visible' });
        } else {
            //$('#idSelectStyle').css({ visibility: 'hidden' });
        }
    } // ========

    // current value
    selVal = selVal || $('#idSelectStyle').val();

    // remove previous items from the select control;
    $('#idSelectStyle').find('option').remove();

    // add an option with empty url
    //if (!ETD.GEN.isUnivWinPlatApp()) {
    $('#idSelectStyle').append($('<option>', { id: idEmptyItem, value: '' }).text('Select style'));
    //}

    // add items listed in the config file
    $.each(ETD.CONFIG.style.items, function (index, oItem) {
        if (typeof oItem.url === 'string' && typeof oItem.label === 'string') {

            oItem.url = oItem.url.trim();
            oItem.label = oItem.label.trim();

            $('#idSelectStyle')
                .append($('<option>', { value: oItem.url })
                    .text(oItem.label));

            // if an item with empty url, remove the one added above, no need to have multiple items with empty url
            if (oItem.url === '') {
                $('#idSelectStyle').find('option[id="' + idEmptyItem + '"]').remove();
            }
        }
    });

    // add items from the local storage or from the uwp app dir
    if (ETD.CONFIG.settings.useLocalStorageForStyle) {

        if (!ETD.GEN.isUnivWinPlatApp()) { // not in uwp app

            if (ETD.GEN.storageAvailable('localStorage')) {
                $.each(window['localStorage'], function (key, value) {
                    if (window['localStorage'].hasOwnProperty(key)) {
                        if (key.match(/^style:/)) {
                            filename = key.replace(/^style:/, '').trim();
                            $('#idSelectStyle').
                                append($('<option>', { value: 'localstorage:' + key }).
                                    text(filename));
                        }
                    }
                });
            }
        } else { // uwp app
            $.each(ETD.STYLE.storedStyleItems, function (index, item) {
                if (item.removed !== ETD.STYLE.REMOVED_STATUS_2) {
                    $('#idSelectStyle').append($('<option>', { value: 'appdir:' + item.id }). // uwp app directory or indexed db
                        text(item.title));
                }
            });
        }
    }

    // set value
    onEndProc(selVal);

    // set 'Remove style' checkbox state
    ETD.EVT.setRemoveStyleRecoverStyle();
};

ETD.AFO.resetStyleMenu = function () {

    $('#idSelectStyle').val('').trigger('change');
};

ETD.AFO.onNewData = function (keepDataMenu /*:boolean*/, keepStyleMenu /*:boolean*/, refreshTableChart /*:boolean*/,
    resetDataMenu /*:boolean*/, loadDefaultData /*:boolean*/, reason /*:string*/) {
    // reason - 'new-data', 'init', 'new-config'

    var defltDataURL; /*:string*/

    ETD.AFO.message('', 'info', true, 'm-07');

    // init data menu
    if (!keepDataMenu) {
        ETD.AFO.initDataMenu();
    }

    // init style menu
    if (!keepStyleMenu) {
        ETD.AFO.initStyleMenu();
    }

    // reset data menu
    if (resetDataMenu) {
        $('#idSelectData').val(''); // trigger('change'); ?
    }

    // default data url
    if (loadDefaultData) {
        defltDataURL = ETD.VALID.hasDefaultData();
    }

    // update the table and chart
    if (!ETD.TABLE.exists()) {
        ETD.TABLE.release();
        ETD.CHART.release();
    } else {
        if (refreshTableChart) {
            ETD.AFO.resize();
            if (!defltDataURL) {
                ETD.TABLE.create(null, { reason: reason });
            }
        }
    }

    // if the configuration file contains a data item with the default flag set, load the data
    if (defltDataURL) {
        $('#idSelectData').val(defltDataURL).change();
    }
};

ETD.AFO.updateDataDependentMenus = function () {

    var colValueLabel /*:array*/ = ETD.TABLE.makeColumnsStruct(ETD.STRUCTS.HEADER);

    // initialize the drop-down menu of columns to search in
    ETD.TABLE.initializeSearchInColumnDropDown(colValueLabel);

    // update column menus
    ETD.CHART.initChartVariableSelection(colValueLabel);
};

ETD.AFO.getCurrentPlotRange = function () {

    var plotRangeInx /*:int*/ = $('#idSelectPlots').val(); // 1,2,3,4,5
    if (isNaN(plotRangeInx)) {
        return null;
    }
    return { range: plotRangeInx, firstplot: 3 * (plotRangeInx - 1), count: 3 }; // range - 1,2,3,4,5; first - 0,3,6,9,12;
};

ETD.AFO.applyCharacteristicCols_NOT_IN_USE = function () { // not supported any more

    var plotRng, inx, plotNo /*:int*/, color; /*:string*/

    plotRng = ETD.AFO.getCurrentPlotRange();
    for (inx = 0; inx < plotRng.count; inx++) {
        plotNo = plotRng.firstplot + inx + 1; // 1-based
        color = ETD.STYLE.sDefCol; // default color
        if ($.isArray(ETD.STYLE.general['plotColors']) && ETD.STYLE.general['plotColors'].length >= plotNo) {
            color = ETD.STYLE.general['plotColors'][plotNo - 1];
        }
        $('#idVariable' + (inx + 1)).css({ border: 'solid ' + color + ' 2px' });
    }
};

ETD.AFO.release = function () {

    ETD.TABLE.release();
    ETD.CHART.release();
    ETD.IMPORT.setDataHeader(undefined);
    ETD.TABLE.data = undefined;

    ETD.AFO.updateDataDependentMenus();
};

ETD.AFO.message = function (text /*:string*/, type /*:string*/, show /*:boolean*/, dbg /*:string*/) {
    // type - 'debug', 'debugX', 'info', 'warning', 'error';
    /*
    Some messages:
    System:
    Error: The requested data set is too small.
        Error: The set operation failed because the supplied data object will overwrite or shift data.
            Error: The supplied data object is not compatible with the shape or dimensions of the current selection.
    The set operation failed because there is no data available in the table.
        Custom:
    Error: The requested data set is too small.
    The set operation failed because there is no data available in the table.
    */

    // etd_msg - mark messages

    var dbgX /*:boolean*/ = false;

    /* // debug
    if (typeof dbg === 'string' && dbg !== '') {
        text = dbg;
    } */

    if (dbgX) {
        if (type === 'debugX') {
            if (text === '') {
                $('.cnMessagePH').text('');
                $('.cnMessageBox').html('&nbsp;').css({ visibility: 'hidden' });
            }
            if ($('.cnMessagePH').text().length > 120) {
                $('.cnMessagePH').text('');
            }
            text = $('.cnMessageBox').text() + text;
        } else {
            return;
        }
    } else {
        if (type === 'debugX') {
            return;
        }
    }

    if (typeof text !== 'string') {
        text = '';
    }
    text = $.trim(text);

    type = type || 'debug';

    // log message
    if (text !== '' && window.console) { // ie9: only supports console functions when developer tools are open,
        // otherwise the console object is undefined;
        if (type === 'debug') {
            window.console.debug(text);
        } else if (type === 'info') {
            window.console.info(text);
        } else if (type === 'warning') {
            window.console.warn(text);
        } else if (type === 'error') {
            window.console.error(text);
        }
    }

    // display message
    if (show) {
        // message, cursor
        if (text !== '') {
            $('.cnMessage').html(text);
            $('.cnMessageBox').addClass('cnCursorPointer');
        } else {
            $('.cnMessage').html('&nbsp;');
            $('.cnMessageBox').removeClass('cnCursorPointer');
        }
        // message box visible/hidden
        if (text !== '' || ETD.UWP.isStyleEditorOpen()) { // if style editor is open, the message box displays the button 'Close Style Editor'
            $('.cnMessageBox').css({ 'visibility': 'visible' });
        } else {
            $('.cnMessageBox').css({ 'visibility': 'hidden' });
        }
        // set height for the message box placeholder (this may push the content downwards)
        ETD.AFO.makeSpaceForMsgBx();
    }

    // position the messagebox (if not in office add-in; for office add-in, this is done in ETD.AFO.resize ();)
    if (!ETD.INIT.isOfficeAddin()) {
        $('#idPaneTop').scroll(function () {
            $('.cnMessageBox').css({ top: Math.max($('.cnMessagePH').offset().top - 1, 0) });
        }).on('scrollstop', function () {
        });
    }
};

ETD.AFO.makeSpaceForMsgBx = function () {

    // height of the message box place holder
    if ($('#idTopPaneCntnt2').css('display') === 'none') {
        $('.cnMessagePH').parent().outerHeight($('.cnMessageBox').outerHeight());
    } else { // style editor displayed
        $('.cnMessagePH').parent().outerHeight($('#idTopPaneCntnt2').find('.cnMessageBox').outerHeight());
    }

    // width (in winapp, the vertical scrollbar is covered with the message box)
    $('.cnMessageBox').outerWidth($('#idPaneTop').prop('clientWidth'));
};

ETD.AFO.dbgMsg = function (msg /*:string*/) {

    ETD.AFO.dgbMsgs = ETD.AFO.dgbMsgs || [];
    ETD.AFO.dgbMsgs.push(msg);
};

ETD.AFO.setLayouter = function (relLeft /*:number*/, relTop /*:number*/) {

    if (ETD.LAYOUTER.layouter) {
        ETD.LAYOUTER.layouter.setLayout(relLeft, relTop);
    }
};

ETD.AFO.openStyleFolderOnly = function () {

    // close all input folders except for Style where the add-on can be purchased
    $('.headerA').each(function (index, element) {

        // check if in the Style folder; note that in the win app,
        // there are 2 Style folders, one for the limited version and the other one for the full version;
        if ($(element).closest($('#idTopLayoutStyleLimited')).length > 0) {
            ETD.INIT.showHideSection(element, 1); // open Style folder for the feature limited version
        } else {
            ETD.INIT.showHideSection(element, 0); // close any other input folder
        }
    });
};


ETD.CHART = {
    id: 'idChart01',
    idLegend: 'idLegend01',
    MAX_ZOOM: 100,
    MAX_ZOOM_TD: 100, // for touch devices
    selector /*:object*/: undefined, // data selector object
    xVariable: undefined,
    chartId2SelElems: {}, // a map, the chart id is mapped to an array of selected svg-elements (data points)
    // whose attributes are changed;
    withInfotip: true, // if true, display a infotip;
    withShadow: false, // if true, shadow effects are shown (in the infotip)
    var2Txt: undefined,
    hotRadius: 8, // radius (in pixels); data points within this radius are marked;
    hotRadiusTouch: 16, // radius (in pixels); data points within this radius are marked in touch devices;
    plotArea: undefined,
    domGCallback: undefined,
    plotOrder: undefined,
    zoom: undefined, // { zoomX:, zoomY: },
    maxNumberOfPlots: 15
};

ETD.CHART.create = function (oParams, oCall) {

    var inx, maxDataSymbolCount, style;

    oCall = oCall || {};

    // oParams.data.plots
    // oParams.data.scales
    // oParams.data.dataset

    // check if at least one plot is defined and store x-variable
    ETD.CHART.xVariable = undefined;
    for (inx = 0; inx < oParams.data.plots.length; inx++) {
        if (typeof oParams.data.plots[inx].x === 'string') {
            ETD.CHART.xVariable = oParams.data.plots[inx].x;
            break;
        }
    }

    // the maximum number of data symbols shown on each curve (plot)
    maxDataSymbolCount = parseInt($('#idMaxDataSymbolCount').val());
    if (isNaN(maxDataSymbolCount)) {
        maxDataSymbolCount = oParams.data.dataset.length; // no limit
    }

    // style object
    style = ETD.STYLE.chart(oParams.data.plots),

        // draw the chart
        SVGware.draw(ETD.CHART.id, {

            data: oParams.data,

            // set style items
            style: style,

            // as an example, set a callback
            config: {
                width: ETD.STYLE.general.chartWidth,
                height: ETD.STYLE.general.chartHeight,
                maxDataSymbolCount: maxDataSymbolCount,
                zoomAxes: 'xy', // 'xy' (default), 'x', or 'y';
                zoomValuesX: '1, 5, 10, 50, 100, 500',
                zoomValuesY: '1, 5, 10, 50, 100, 500',
                searchableData: 1,
                plotOrderReversed: false, // if true, plots with higher index added below
                plotOrder: ETD.CHART.plotOrder.toString(),

                // callbacks
                onClick: ETD.CHART.onMouseEvent,
                onMouseMove: ETD.CHART.onMouseEvent,
                onMouseOut: ETD.CHART.onMouseEvent,
                onMouseDown: ETD.CHART.onMouseEvent,
                onMouseUp: ETD.CHART.onMouseEvent,
                onTouchStart: ETD.CHART.onMouseEvent,
                onTouchMove: ETD.CHART.onMouseEvent,
                onTouchEnd: ETD.CHART.onMouseEvent,
                onDraw: ETD.CHART.onDraw,
                onDrawScale: ETD.CHART.onDrawScale,
                onDrop: ETD.CHART.onDropFile
            }
        }, oCall);

    // create the data selector;
    // option: allow reverse values on the scales;
    if (ETD.SELECTOR) {
        ETD.CHART.selector = ETD.SELECTOR.create({
            method: ETD.SELECTOR.MODE.dragging, onchange: ETD.CHART.onChangeSelector,
            allow_reverse: true
        });
    }

    // remove background color in ETD.CHART.onDraw ()
};

// Callback for mouse events.
ETD.CHART.onMouseEvent = function (event, domGCallback) {

    // event - a custom event-object;
    // domGCallback - svg g-element for drawing on the chart;

    var doc = domGCallback.ownerDocument,
        selectedData, selTblRows, selRow /*:int*/, rowNoMap,
        plotNo, plotsZOrder,
        inx;

    // in the table, select the row which corresponds to the nearest data point on the chart;
    if (event.type === 'mousedown' || event.type === 'touchstart') {

        // get the data points close to the pointer location
        selectedData = ETD.GEN.getSelectedData(event.id, {
            circle: {
                cx: event.position.x, cy: event.position.y,
                r: ETD.CHART.getHotRadius()
            }
        });

        // select table rows
        selTblRows = [];
        rowNoMap = {};
        for (inx = 0; inx < selectedData.length; inx++) {
            selRow = selectedData[inx].member - 1; // convert from 1-based index to 0-based index
            if (selTblRows.length < ETD.CONFIG.settings.maxTableRowsSelectedFromChart) {
                if (!rowNoMap[selRow]) {
                    selTblRows.push(selRow);
                    rowNoMap[selRow] = true;
                }
            } else {
                break;
            }
        }
        setTimeout(function () { // timeout set due to issues with samsung browser (the touchmove event does not fire)
            ETD.TABLE.setSelected(selTblRows);
        }, 50);

        // change the z-order of plots (bring the plot to foreground);
        // consider: call
        //   ETD.STYLE.isErrorbarPlot ()
        // to find the error bar plots and handle the error bar plot and the next 2 plots as a group;
        if ($('#idChangeableZOrder').val() === '1' && $.isArray(ETD.CHART.plotOrder)) {

            // try to get plot index from event data
            if ($.isArray(event.selectedData) && event.selectedData.length > 0) {
                plotNo = parseInt(event.selectedData[0].plotIndex);
            }

            // if plot index is still undefined, try to get it from the array of selected data
            if (isNaN(plotNo) && selectedData.length > 0) {
                plotNo = parseInt(selectedData[0].plotIndex);
            }

            if (!isNaN(plotNo)) {
                plotNo++; // to 1-based index
                plotsZOrder = [];
                for (inx = 0; inx < ETD.CHART.plotOrder.length; inx++) {
                    if (ETD.CHART.plotOrder[inx] !== plotNo) {
                        plotsZOrder.push(ETD.CHART.plotOrder[inx]);
                    }
                }
                plotsZOrder.push(plotNo);
                ETD.CHART.plotOrder = plotsZOrder;
                SVGware.draw(ETD.CHART.id, { config: { plotOrder: plotsZOrder.toString() } });
            }
        }
    }

    // the mousemove event or the touchstart event:
    // create an infotip;
    if (event.type === 'mousemove' || event.type === 'touchstart') {
        ETD.CHART.markNearestPoints(event, domGCallback);
    }

    // the mouseout event: remove the infotip, marks, and menu, and
    // restore the previously selected elements;
    else if (event.type === 'mouseout') {
        // remove the the infotip and marks
        ETD.GEN.removeElements(['idInfotip', 'idMarks'], doc);
        // restore the elements that were changed before
        ETD.CHART.chartId2SelElems[event.id] =
            ETD.GEN.restoreElements(ETD.CHART.chartId2SelElems[event.id]);
    }

    // data selector mouse event processing
    if (ETD.CHART.selector) {
        ETD.CHART.selector.onMouseEvent(event, domGCallback);
    }
};

// The onDraw callback.
// Store g-element for drawing selection marks.
// Mark the data corresponding to the selected table rows.
ETD.CHART.onDraw = function (event, domGCallback) {

    // event - a custom event-object;
    // domGCallback - svg g-element for drawing on the chart;

    var title;

    // remove background color because some lines
    // of the background may be visible at the bottom of the chart on touch devices;
    $('#' + ETD.CHART.id).removeClass('cnColors2');

    if (event.readyState === 'complete') {

        // store plot area
        ETD.CHART.plotArea = event.plotArea;

        // store g-element for drawing
        ETD.CHART.domGCallback = domGCallback;

        // store the z-order of plots
        ETD.CHART.plotOrder = event.plotOrder; // an array

        // store zoom values
        ETD.CHART.zoom = { zoomX: event.zoomX, zoomY: event.zoomY };

        // mark the selected table rows on the chart
        ETD.TABLE.markSelectedRowsOnChart();

        // if filename is available, store the chart (only in winapp)
        if (event.call && typeof event.call.filename === 'string') {
            title = $('#idChartTitle').val(); // current text in the text box
            $('#idChartTitle').val(event.call.filename.trim());
            $('#idStoreChart').trigger('click');
            $('#idChartTitle').val(title); // restore the text in the box
        }

        // serialize
        ETD.SER.serialize({ save: true }); // ETD.CHART.onDraw ()

        // draw legend
        ETD.CHART.hideLegend(false);
        SVGware.drawLegend(ETD.CHART.idLegend, {
            id: ETD.CHART.id,
            config: {
                onDraw: function (event, domGCallback) {
                    var $legend, $legendP,
                        iW, iH;
                    if (event.readyState === 'layout_complete' && event.requestedChartArea) {
                        $legend = $('#' + event.id);
                        if ($legend.length === 1) {
                            iW = Math.round(event.requestedChartArea.width / ETD.UPP);
                            iH = Math.round(event.requestedChartArea.height / ETD.UPP);
                            $legendP = $legend.parent();
                            if ($legend.width() !== iW || $legend.height() !== iH) {
                                $legendP.width(iW).height(iH);
                                $legend.width(iW).height(iH);
                                return false; // redraw
                            }
                            ETD.CHART.hideLegend(iW <= 0 || iH <= 0);
                        }
                    }

                    // draw current chart thumbnail
                    ETD.UWP.showCurChartThumbnail();

                    return true; // continue drawing
                }
            }
        });
    } // else if (event.readyState === 'layout_complete') { }

    // custom callback
    if (typeof ETD.CONFIG.onDrawChart === 'function') {
        return ETD.CONFIG.onDrawChart(event, domGCallback);
    }

    return true; // must return true
};

// Display an infotip with the list of the nearest data points,
// mark the location of the points, and change the color of the data symbols (svg-elements).
ETD.CHART.markNearestPoints = function (event, domGCallback) {
    // event - a custom event-object;
    // domGCallback - svg g-element for drawing on the chart;

    var doc,
        selData, dataItem,
        fill, fillOpacity,
        maxTipItems, labels, label,
        domGInfo, domGMarks, markedSymbols, markedSmbl,
        length, inx,
        rowID, variables, formatted, infotip;

    doc = domGCallback.ownerDocument;

    // remove the old infotip and data marks
    ETD.GEN.removeElements(['idInfotip', 'idMarks'], doc);

    // restore the dom-elements that were changed last time
    ETD.CHART.chartId2SelElems[event.id] =
        ETD.GEN.restoreElements(ETD.CHART.chartId2SelElems[event.id]);


    // display infotip if,
    // (i), this is selected, and
    // (ii), the context menu is not shown, and
    // (iii), the cursor is in the plot area;
    if (ETD.CHART.withInfotip === 1 &&
        ETD.GEN.isInRect(event.position, event.plotArea)) {
        // get the data points close to the pointer location
        selData = ETD.GEN.getSelectedData(event.id, {
            circle: {
                cx: event.position.x, cy: event.position.y,
                r: ETD.CHART.getHotRadius()
            }
        });
    }
    if (!$.isArray(selData)) {
        selData = [];
    }

    // nearest data symbol fill
    if (ETD.STYLE.general.nearestDataFill) {
        fill = ETD.GEN.getValueNoCase(ETD.STYLE.general.nearestDataFill, 'fill');
        fillOpacity = ETD.GEN.getValueNoCase(ETD.STYLE.general.nearestDataFill, 'fill-opacity');
    } else {
        fill = 'none';
        fillOpacity = 0;
    }

    // max number of items on the infotip
    maxTipItems = parseInt($('#idMaxInfotipItemCount').val());
    if (isNaN(maxTipItems)) {
        maxTipItems = 0;
    }

    // collect info for the infotip, mark the data points close to the pointer
    labels = [];
    markedSymbols = [];
    length = 8; // the maximum number of characters in a infotip row (will be found below)
    for (inx = 0; inx < selData.length; inx++) {

        dataItem = selData[inx];

        // check if the point is inside plotArea
        if (!ETD.GEN.isInRect(dataItem, event.plotArea)) {
            continue;
        }

        // test the number of items
        if (labels.length >= maxTipItems) {
            break;
        }

        // store info to be displayed on the infotip

        // calculate the distance (in pixels) between the data point and pointer
        //iDstnc = (event.position.x - dataItem.x) * (event.position.x - dataItem.x) +
        //    (event.position.y - dataItem.y) * (event.position.y - dataItem.y);
        //iDstnc = Math.round(Math.sqrt(iDstnc) / UPP);

        // get formatted value; the formatted value is not
        // directly available in the chart;
        rowID = dataItem.memberObject[ETD.TABLE.rowIDVar] - 1; // row id, 0-based
        variables = {};
        variables[dataItem['variable']] = true;
        formatted = {};
        ETD.TABLE.getDataItem(rowID, -1001, variables, formatted); // row no set to an arbitrary value
        // here:
        //   dataItem.memberObject[dataItem['variable']] == formatted[dataItem['variable']]

        label =
            ETD.GEN.limitTextLength(ETD.CHART.var2Txt[ETD.CHART.xVariable], 16, 24) + ': ' +
            dataItem.memberObject[ETD.CHART.xVariable] + ', ' +
            ETD.GEN.limitTextLength(ETD.CHART.var2Txt[dataItem.variable], 16, 24) + ': ' +
            formatted[dataItem['variable']];
        labels.push({
            label: label,
            color: ETD.STYLE.general.plotColors[dataItem.plotIndex],
            plotindex: dataItem.plotIndex
        });
        length = Math.max(length, label.length);

        // change fill attribute for the data points;
        // this does not apply for unresolved data points;
        if (!ETD.CHART.chartId2SelElems[event.id]) {
            ETD.CHART.chartId2SelElems[event.id] = [];
        }
        if (fill !== 'none') {
            ETD.GEN.changeElement(dataItem.domElement, fill, fillOpacity,
                ETD.CHART.chartId2SelElems[event.id]);
        }

        // store the position and color;
        // this is used for marking the location;
        //markedSymbols.push({ x: dataItem.x, y: dataItem.y, color: col });
    }

    // draw infotip;
    infotip = ETD.GEN.drawInfotip(event, domGCallback, 'idInfotip', labels, null, ETD.CHART.withShadow);
    domGInfo = infotip ? infotip.domg : null;

    // draw little circles to mark the data points
    domGMarks = ETD.GEN.createElement('g', domGCallback, { id: 'idMarks' }, domGInfo);
    if (markedSymbols.length > 0) {
        for (inx = markedSymbols.length - 1; inx >= 0; inx--) {
            markedSmbl = markedSymbols[inx];
            ETD.GEN.markPoint(domGMarks, markedSmbl.x, markedSmbl.y, markedSmbl.color);
        }
    }
};

ETD.CHART.onChangeSelector = function () {

    var smallWH = 4 * ETD.UPP,
        rctTracker,
        x1, x2, y1, y2,
        selData, values,
        yVar/*:string*/, // y1, y2, y3
        maxZoom /*:int*/, zoom /*:object*/,
        i;

    // get coordinates of the selected rectangle
    rctTracker = ETD.CHART.selector.getRect();
    if (!rctTracker) {
        return;
    }

    // return if the rect is too small
    if (Math.abs(rctTracker.width) <= smallWH && Math.abs(rctTracker.height) <= smallWH) {
        return;
    }

    // the left, right, bottom and top coordinates of the rectangle
    x1 = parseInt(rctTracker.x);
    x2 = parseInt(rctTracker.x) + parseInt(rctTracker.width);
    y1 = parseInt(rctTracker.y) + parseInt(rctTracker.height);
    y2 = parseInt(rctTracker.y);

    // check if there are data points inside the selector;
    // if there is none, reset the zoom;
    selData = ETD.GEN.getSelectedData(ETD.CHART.id, {
        rectangle: {
            x: Math.min(x1, x2),
            y: Math.min(y1, y2),
            width: Math.abs(x1 - x2),
            height: Math.abs(y1 - y2)
        }
    });
    if (selData.length === 0) {
        SVGware.zoom(ETD.CHART.id, {
            zoomX: 1,
            zoomY: 1
        });
        return;
    }

    // convert the selector's rect from user coordinates to scale values
    values = SVGware.get(ETD.CHART.id, 'convertedValues', [
        { posX: x1 },
        { posX: x2 },
        { posY: y1 },
        { posY: y2 }
    ]);

    // find a valid y-axis;
    // consider: for y1-axis, a non-numeric variable is selected;
    yVar = undefined;
    for (i = 1; i <= 10; i++) {
        if (typeof values[2]['y' + i] !== 'undefined') {
            yVar = 'y' + i;
            break;
        }
    }
    if (typeof yVar === 'undefined') {
        return;
    }

    // limit the zoom value
    maxZoom = !ETD.AFO.touchFriendlyMode ? ETD.CHART.MAX_ZOOM : ETD.CHART.MAX_ZOOM_TD;

    // zoom in
    zoom = {
        zoomX: Math.min(Math.abs(ETD.CHART.zoom.zoomX * (ETD.CHART.plotArea.width / rctTracker.width)), maxZoom), // limit the zoom value
        zoomY: Math.min(Math.abs(ETD.CHART.zoom.zoomY * (ETD.CHART.plotArea.height / rctTracker.height)), maxZoom),
        x: (values[0].x + values[1].x) / 2
    };
    zoom[yVar] = (values[2][yVar] + values[3][yVar]) / 2;
    SVGware.zoom(ETD.CHART.id, zoom);
};

// ETD.CHART.onDrawScale ()
// onDrawScale callback for customizing gridlines and tickmarks.
// Called for each scale, returns an array of objects
//   { value:, label:, label_mutable:, category:, priority: }, where
//   value - numeric value on the scale; 
//   label - string, may be an empty string;
//   label_mutable - boolean, if true, the label may be changed before rendering;
//     e.g., '100000000' may be replaced with '1.0e+8';
//   category - 1 (default), 2 or 3; for the gridlines and tickmarks,
//     the style items with 2 (or 3) at the end apply if the category is 2 (or 3);
//   priority - an integer, labels with higher priority are rendered first;
ETD.CHART.onDrawScale = function (event) {
    // event - a custom event-object;

    // a helper for adding items to the scale
    function addScaleValues(items, value /*:number*/, step /*:number*/, coefMin, coefMax,
        category /*:int*/, hasLabel /*:boolean*/, priority /*:int*/) {

        // items - an array of objects { value:, label:, category:, priority: };
        //   new items are added to this array;
        // value - base value, new scale items are calculated from this:
        //   newVal = value + step * iCoef,
        //   where iCoef runs from iCoefMin to iCoefMax;
        // category - category of the new item;
        //    the category determines the style of gridlines and tickmarks;
        // hasLabel - if true, the label is set to the new item, otherwise the label is an empty string;
        // priority - priority of the new item; labels with higher priority are rendered first;

        var newVal, c;

        for (c = coefMin; c <= coefMax; c++) {

            newVal = value + c * step;
            if (inArray(items, newVal)) continue;

            items.push({
                value: newVal,
                label: hasLabel ? newVal.toString() : '',
                label_mutable: hasLabel ? true : false,
                category: category,
                priority: priority
            });
        }
    }

    // a helper for checking if a value is already in the array of scale items
    function inArray(items, newVal) {
        var i;
        for (i = 0; i < items.length; i++) {
            if (Math.abs((items[i].value - newVal) / newVal) < 1e-6) {
                return true;
            }
        }
        return false;
    }

    // a helper for finding all integer powers of 10 in the range
    function findPowersOf10(limit1, limit2) {

        var result = [],
            n /*:int*/, nCur /*:int*/,
            val;

        if (limit1 < 0 || limit1 > limit2) return;

        n = Math.floor(Math.log(limit1) / Math.LN10);
        for (nCur = n; ; nCur++) {
            val = Math.pow(10, nCur);
            // check if the value is within limits; if it is, add to the results;
            if (limit1.toPrecision(12) <= val && val <= limit2.toPrecision(12)) {
                result.push(val);
            }
            if (val > limit2) break;
        }
        return result;
    }


    var scaleItems = [], // array of objects of type { value:, label:, category:, priority: }
        // returned from this function below;
        mainValues = event.scale.items, // automatically generated scale values,
        // will be modified / overridden here
        size = mainValues.length,
        step2 /*:number*/, step10 /*:number*/,
        value /*:number*/,
        priority /*:int*/,
        s /*:int*/, c /*:int*/,
        coefs, coef /*:number*/,
        moreLabels /*:boolean*/,
        powers10 /*:array*/, step /*:number*/,
        category /*:int*/,
        hasLabel; /*:boolean*/

    // check if vertical/horizontal minor grid is selected
    if (event.scale.id === 'x') { // x-scale
        if (!$('#idMoreTicksGridV').prop('checked')) {
            return null;
        }
    } else { // y-scale
        if (!$('#idMoreTicksGridH').prop('checked')) {
            return null;
        }
    }

    // add the scale items
    //   event.scale.items
    // with category 1;
    // the following style items apply:
    //   gridlinesVertical, gridlinesHorizontal, ticksBottom, ticksTop, ticksLeft, ticksRight;
    for (s = 0; s < size; s++) { // loop over automatically generated scale values
        value = mainValues[s].value;
        scaleItems.push({
            value: value,
            label: value.toString(),
            label_mutable: true,
            category: 1,
            priority: undefined
        });
    }

    if (event.scale.type === 'linear') {

        // add more gridlines and tickmarks;
        // the values outside the range
        //   [event.scale.range.firstValue, event.scale.range.lastValue]
        // are discarded automatically;

        // add gridlines and tickmarks of category 2; the step is 1/2 of the main step;
        // add tickmarks of category 3; the step is 1/10 of the main step;
        for (s = 0; s < size - 1; s++) {

            step2 = (mainValues[s + 1].value - mainValues[s].value) / 2;
            step10 = (mainValues[s + 1].value - mainValues[s].value) / 10;

            addScaleValues(scaleItems, mainValues[s].value, step2, 1, 1, 2);
            addScaleValues(scaleItems, mainValues[s].value, step10, 1, 4, 3);
            addScaleValues(scaleItems, mainValues[s].value, step10, 6, 9, 3);

            if (s === 0) {
                addScaleValues(scaleItems, mainValues[0].value, step2, -1, -1, 2);
            }
            if (s === size - 2) {
                addScaleValues(scaleItems, mainValues[size - 1].value, step2, 1, 1, 2);
            }
        }
    } else { // logarithmic scale

        // new scale items are added by calling
        // the helper findPowersOf10() and finding values 0.1, 1, 10,...,
        // then values 0.5, 5, 50,..., then values 0.2, 2, 20,..., etc.
        // the label, category and priority attributes are found for the new scale items
        // with a simple algorithm;

        moreLabels = undefined;
        coefs = [1, 0.5, 0.2, 0.4, 0.6, 0.8, 0.3, 0.7, 0.9];
        for (c = 0; c < coefs.length; c++) {

            coef = coefs[c];

            // if coef is 1, items 0.1, 1, 10,... are added;
            // if coef is 0.5, items 0.5, 5, 50,... are added;
            // if coef is 0.2, items 0.2, 2, 20,... are added;

            powers10 = findPowersOf10(event.scale.range.firstValue / coef,
                event.scale.range.lastValue / coef);

            if (c === 0) {
                category = 1;
                hasLabel = true;
                priority = 3;
            } else if (c === 1) {
                category = 2;
                hasLabel = true;
                priority = 2;
            } else if (c === 2 || c === 3 || c === 4 || c === 5) {
                category = event.zoomX === 1 ? 3 : 2;
                hasLabel = true;
                priority = 1;
            } else {
                hasLabel = false;
                if (typeof moreLabels === 'undefined' && scaleItems.length < 20) {
                    moreLabels = true;
                }
                hasLabel = moreLabels;
                category = event.zoomX === 1 ? 3 : 2;
                priority = 0;
            }

            for (s = 0; s < powers10.length; s++) {
                step = coef * powers10[s];
                step = parseFloat(step.toPrecision(1));
                addScaleValues(scaleItems, 0, step, 1, 1, category, hasLabel, priority);
            }
        }
    }

    return scaleItems;
};

ETD.CHART.onDropFile = function (event) {
    event.table = {
        contents: event.contents,
        filename: event.filename
    };
    ETD.IMPORT.onDropDataCsvDataJsConfigJsStyleHtml(event);
};

ETD.CHART.exists = function () {
    return $('#idPaneRight').find('iframe').length !== 0;
};

ETD.CHART.update = function (call /*:object*/) {

    if (!ETD.CHART.collectInfoAndCreate(call)) { // otherwise serialize in ETD.CHART.onDraw ()
        ETD.SER.serialize({ save: true });
    }
};

// Initialize drop down menus for selecting variables of the chart.
ETD.CHART.initChartVariableSelection = function (colValueLabel /*:array*/) {

    var selectCntrlIDs, $select, $options,
        value /*:string*/, text /*:string*/,
        variable /*:string*/, header /*:string*/,
        i, j;

    selectCntrlIDs = ['#idVariable0', '#idVariable1', '#idVariable2', '#idVariable3'];

    for (i = 0; i < selectCntrlIDs.length; i++) {

        // get the select control and the current selection, remove all options;
        // add empty option;
        $select = $(selectCntrlIDs[i]);
        value = $select.val();
        $options = $select.find('option');
        text = $options.filter(':selected').text();
        $select.find('option').remove();
        $select.append($('<option />').attr('value', '').text(''));

        // add options
        if ($.isArray(colValueLabel) && colValueLabel.length > 0) {
            // add Row No and Row ID to the drop down menu
            $select.append($('<option />').attr('value', ETD.TABLE.rowNoVar).text(ETD.TABLE.rowNoTxt));

            // do not add row id; if row id would be selected for x-axis and rows are filtered with search,
            // the row id should be serialized; in this case, after deserializing, there would be 2 variables of row id (old and new);
            // this would cause confusing situations;
            //$select.append($('<option />').attr('value', ETD.TABLE.rowIDVar).text(ETD.TABLE.rowIDTxt));

            // add regular variables to the drop down menu
            for (j = 0; j < colValueLabel.length; j++) {
                variable = colValueLabel[j].variable;
                header = colValueLabel[j].text;
                $select.append($('<option />').attr('value', variable).text(header));
            }
        }

        // try to set selection by value:
        //   $select.find('option[value="' + value + '"]').attr('selected', 'selected');
        // better to use the option text rather than the option value to restore the selection if possible;
        // try to select the option with text text
        $select.find('option').filter(function () {
            return $(this).text().trim() === text.trim();
        }).attr('selected', 'selected');

        // if only the default option with value '', remove it
        if ($select.find('option').length === 1) {
            $select.find('option').remove();
        }
    }
};

ETD.CHART.collectInfoAndCreate = function (options /*:object*/) {

    var logX /*:boolean*/, logY /*:boolean*/,
        sN, sT, inx,
        plots /*:array*/, plot /*:object*/, aDP, oDP, // aDP - 'data.plots' array which is passed to SVGware.draw ()
        maxPlotIndx /*:int*/,
        allVars /*:object*/, variables /*:object*/, var2Txt /*:object*/, labels /*:object*/,
        isXDefined /*:boolean*/, isYDefined /*:boolean*/,
        scaleID /*:string*/, axesCur /*:objectt*/,
        chartData /*:array*/, // 'data.dataset' array which is passed to SVGware.draw ()
        scales; /*:array*/ // 'data.scales' array which is passed to SVGware.draw ()


    function isVariable(sVarName, sVarTxt) {
        return typeof allVars[sVarName] === 'string' && allVars[sVarName] === sVarTxt;
    }

    function getCustomScaleItems(scaleID, bLog) {
        var custScale /*:string*/, custScaleSplit /*:array*/,
            inx, value /*:number*/, scale; /*:array*/
        custScale = $('#idAxisScale-' + scaleID).val();
        if (typeof custScale !== 'string') {
            return undefined;
        }
        custScaleSplit = custScale.split(',');
        scale = [];
        for (inx = 0; inx < custScaleSplit.length; inx++) {
            value = parseFloat(custScaleSplit[inx]);
            if (!isNaN(value) && isFinite(value)) {
                if (!bLog || value > 0) {
                    scale.push(value);
                }
            }
        }
        if (scale.length < 2) {
            return undefined;
        }
        return scale;
    }


    options = options || {};

    // check data and header
    if (!$.isArray(ETD.TABLE.data) || !$.isArray(ETD.STRUCTS.HEADER)) {
        ETD.CHART.release();
        return;
    }

    // map of all available variables
    allVars = {};
    for (inx = 0; inx < ETD.STRUCTS.HEADER.length; inx++) {
        sN = ETD.STRUCTS.HEADER[inx].variable;
        sT = ETD.STRUCTS.HEADER[inx].text;
        if (typeof sN === 'string' && sN !== '' && typeof sT === 'string' && sT !== '') {
            allVars[ETD.STRUCTS.HEADER[inx].variable] = ETD.STRUCTS.HEADER[inx].text;
        }
    }
    // add row id, row no which are generated on the fly and always available
    allVars[ETD.TABLE.rowIDVar] = ETD.TABLE.rowIDTxt;
    allVars[ETD.TABLE.rowNoVar] = ETD.TABLE.rowNoTxt;

    // update plot info
    $('#idSelectPlots').change();

    // linear of logarithmic scales
    logX = $('#idLogX').prop('checked');
    logY = $('#idLogY').prop('checked');

    // x-variable
    if (isVariable(ETD.STRUCTS.PLOTS.xvar, ETD.STRUCTS.PLOTS.xtxt)) {
        isXDefined = true;
    }

    // map of all variables which are necessary for the chart
    variables = {};
    variables[ETD.TABLE.rowIDVar] = true;
    variables[ETD.STRUCTS.PLOTS.xvar] = true; // variable name on the x-axis

    // map 'variable name' to 'variable text (table column header text)'
    var2Txt = {};
    var2Txt[ETD.STRUCTS.PLOTS.xvar] = ETD.STRUCTS.PLOTS.xtxt;

    // labels
    labels = { x: ETD.STRUCTS.PLOTS.xtxt };

    // iterate over plot info array, prepare objects for creating the chart
    plots = ETD.STRUCTS.PLOTS.plots;
    aDP = [];
    maxPlotIndx = 0;
    for (inx = 0; inx < plots.length; inx++) {

        plot = plots[inx];
        if (!plot) {
            plots[inx] = null;
            aDP[aDP.length] = {}; // add an empty plot object to ensure that the correct style object is used for the plots
            continue;
        }

        // x-variable, y-scale, y-variable
        oDP = { x: ETD.STRUCTS.PLOTS.xvar };
        if (!logY) {
            oDP[plot.yscale] = plot.yvar;
        } else { // if logarithmic y-scale, only one y-scale (y1) is supported
            oDP['y1'] = plot.yvar;
        }
        if (isVariable(plot.yvar, plot.ytxt)) {
            isYDefined = true;
        } else {
            plots[inx] = null;
            aDP[aDP.length] = {}; // add an empty plot object to ensure that the correct style object is used for the plots
            continue;
        }
        variables[plot.yvar] = true;

        // store map 'variable name' to 'variable text (table column header text)'
        var2Txt[plot.yvar] = plot.ytxt;

        // axis title
        if (typeof labels[plot.yscale] !== 'string') {
            labels[plot.yscale] = '';
        } else {
            labels[plot.yscale] += ', ';
        }
        labels[plot.yscale] += plot.ytxt;

        // add the plot info object
        aDP[aDP.length] = oDP;
        maxPlotIndx = inx;
    }

    // remove unnecessary plot info objects
    plots.splice(maxPlotIndx + 1, aDP.length);
    aDP.splice(maxPlotIndx + 1, aDP.length);

    // if the chart is not defined correctly, remove the chart (if it exists already) and return
    if (!isXDefined || !isYDefined) {
        ETD.CHART.release();
        ETD.CHART.hideShowChartControls(false);
        ETD.UWP.showCurChartThumbnail();
        return;
    }

    // axis titles
    axesCur = { x: false, y1: false, y2: false, y3: false };
    for (scaleID in labels) { // scaleID - x, y1, y2, or y3
        if (labels.hasOwnProperty(scaleID)) {
            if ($('#idAxisTitleAuto-' + scaleID).prop('checked')) { // automatic axis title
                $('#idAxisTitle-' + scaleID).val(labels[scaleID]);
            } else { // non-automatic axis title
                labels[scaleID] = $('#idAxisTitle-' + scaleID).val();
            }
            axesCur[scaleID] = true;
        }
    }
    // reset titles which are automatic and not in use in the current chart
    scaleID = undefined;
    for (scaleID in axesCur) {
        if (!axesCur[scaleID]) {
            if ($('#idAxisTitleAuto-' + scaleID).prop('checked')) {
                $('#idAxisTitle-' + scaleID).val('');
            }
        }
    }

    // prepare the data object for the chart
    chartData = ETD.CHART.prepareChartData(variables);

    // prepare 'data.scales' array
    scales = [
        { scale: 'x', title: labels['x'], logarithmic: logX, items: getCustomScaleItems('x', logX) },
        { scale: 'y1', title: labels['y1'], logarithmic: logY, items: getCustomScaleItems('y1', logY) }
    ];
    if (typeof labels['y2'] === 'string') {
        scales.push({ scale: 'y2', title: labels['y2'], items: getCustomScaleItems('y2') });
    }
    if (typeof labels['y3'] === 'string') {
        scales.push({ scale: 'y3', title: labels['y3'], items: getCustomScaleItems('y3') });
    }

    // store map 'variable to text'
    ETD.CHART.var2Txt = var2Txt;

    // create the chart
    ETD.CHART.create({
        data: {
            dataset: chartData,
            plots: aDP,
            scales: scales,
            var2text: var2Txt
        }
    }, {
            filename: options.filename,
            reason: options.reason
        });

    return true;
};

// Prepare chart data according to the current state of the table.
ETD.CHART.prepareChartData = function (variables /*:object*/) {

    var chartData, cdi /*:object*/, dataItem /*:object*/,
        tblSize /*:int*/,
        varName /*:string*/,
        row; /*:int*/

    chartData = [];

    // loop over table rows and variables
    tblSize = ETD.TABLE.getSize();
    varName = undefined;
    for (row = 0; row < tblSize; row++) {
        dataItem = ETD.TABLE.getDataItem(ETD.TABLE.getRowID(row), row, variables);
        cdi = {};
        for (varName in variables) {
            if (dataItem[varName] !== '' && !isNaN(dataItem[varName])) { // pass only numbers to the chart;
                // Number('') -> 0;
                cdi[varName] = Number(dataItem[varName]);
            }
        }
        chartData[chartData.length] = cdi;
    }

    return chartData;
};

ETD.CHART.getHotRadius = function () {
    return (!ETD.AFO.touchFriendlyMode ? ETD.CHART.hotRadius : ETD.CHART.hotRadiusTouch) * ETD.UPP;
};

ETD.CHART.release = function () {

    SVGware.release(ETD.CHART.id);

    // reset background which is removed in ETD.CHART.create ()
    $('#' + ETD.CHART.id).addClass('cnColors2').css({ 'background-color': ETD.STYLE.general['skin']['backgroundColor2'] });

    ETD.CHART.hideLegend(true);
};

ETD.CHART.hideShowChartControls = function (hide /*:boolean*/) {

    var $paneRight, offset /*:object*/, width, height, $controls;

    if (typeof hide === 'undefined') {
        hide = !ETD.AFO.chartCntrlsVisible;
    }

    hide = !!hide;
    $controls = $('#idChartControls');
    if (ETD.AFO.chartCntrlsVisible === !hide) {
        return; // sync problem if returning here
    }

    // create a temporary cover for the right pane
    $paneRight = $('#idPaneRight');
    offset = $paneRight.offset();
    width = $paneRight.width();
    height = $paneRight.height();

    $('#idCover').remove();
    $('body').append('<div id="idCover" class="cnColors2" \
        style="position:absolute; \
        background-color:' + ETD.STYLE.general['skin']['backgroundColor2'] + '; \
        left:' + (offset.left + 2) + 'px; top:' + (offset.top + 8 + 1) + 'px; \
        width:' + (width - 2 - 4) + 'px; height:' + (height - 8 - 1 - 4) + 'px; \
        visibility: visible; z-index:' + ETD.INIT.ZINDEX.chartcontrolscover + ';"></div>');

    if (!hide) {
        $controls.css({ visibility: 'hidden' }); // changed to visible below (after delay)
    }

    ETD.AFO.chartCntrlsVisible = !hide;

    // resize
    ETD.AFO.resize();

    // remove cover
    setTimeout(function () {
        $('#idCover').remove();
        $controls.css({ visibility: 'visible' });
    }, 500);

    // plus sign icon may be hidden, make it visible;
    // note that the display attribute is set to none or block in ETD.AFO.resize ();
    $('#idShowChartUI').css({ visibility: 'visible' });
};

ETD.CHART.hideLegend = function (hide /*:boolean*/) {

    var $legendP = $('#' + ETD.CHART.idLegend).parent();

    if (hide) {
        $legendP.css({ 'display': 'none' });
    } else {
        if ($legendP.css('display') === 'none') {
            $legendP.css({ 'visibility': 'hidden', 'display': 'block' });
            setTimeout(function () {
                $legendP.css({ 'visibility': 'visible' });
            }, 100);
        } else {
            $legendP.css({ 'visibility': 'visible', 'display': 'block' });
        }
    }
};


ETD.TABLE = {

    id: 'idTable01',

    data /*:array*/: undefined, // the data array

    showRowNo: true, // if true, the Row No column is added to the table
    showRowID: true, // if true, the Row ID column is added to the table

    rowNoVar: 'svgware_row_no',
    rowNoTxt: 'Row No', // header text for row number

    rowIDVar: 'svgware_row_id',
    rowIDTxt: 'Row ID', // header text for row number

    // the array of filtered/ordered row ID-s (0-based) stored in the onDraw() callback
    // and used for exporting to CSV file;
    // for example, if
    //   aFilteredRows=[5, 0, 3],
    // the table displays the rows
    //   aData[5], aData[0], aData[3],
    // all other rows are filtered out;
    // aFilteredRows is undefined if there is no ordering/filtering
    // (corresponds to [0, 1, 2,..., (datasetSize-1)]);
    filteredRows: undefined,

    searchApplied: undefined,

    visibleColsLimit: 20, // maximum number of initially visible columns

    // the array of columns stored in the onDraw() callback
    // and used for exporting to CSV file;
    columns: undefined,

    sortedByVariable: undefined,
    sortedInIncreasingOrder: undefined,

    curMode: undefined, // the current mode, 'text' or 'graphics'
    colSelectionWidth: 100 * ETD.UPP,
    selectedRowID: undefined, // array of selected row id-s (0-based indexes)

    initd: false, // set to true once the table is drawn for the first time

    // reasons for update
    updateReason: {
        // svgware built-in msgs
        'resize': 'resize',
        'layout': 'layout',
        'sort': 'sort',
        'select-column': 'select-column',
        // app msgs
        'init': 'init', // not in use
        'new-data': 'new-data',
        'deserialize-csv': 'deserialize-csv',
        'deserialize-excel': 'deserialize-excel', // only for excel doc
        'deserialize-search': 'deserialize-search',
        'search': 'search',
        'settings': 'settings',
        'new-config': 'new-config',
        'new-style': 'new-style',
        'new-table-style': 'new-table-style',
        'touch-mode': 'touch-mode'
    }
};

ETD.STRUCTS = {

    // array of objects
    //   { variable, text };
    // before ETD.TABLE.aHeader2;
    HEADER: undefined,

    // array of column objects
    //   { variable, headertext, show, parent, rect, cells },
    // stored in ETD.TABLE.onDraw () callback;
    // before ETD.TABLE.columns;
    COLS: undefined,

    // object
    //   { xtxt, xvar, plots: [{ yvar, ytxt, yscale, symbol, line, area },...] };
    PLOTS: { xvar: undefined, xtxt: undefined, plots: [] }

    // see also
    //   ETD.CHART.plotOrder
    //   ETD.CHART.zoom
};

// Create or update the table.
ETD.TABLE.create = function (options /*:object*/, call /*:object*/) {

    // highlights - optional array, specifies highlighted characters in the table cells;
    //   the elements of the array are objects of type
    //     { rowID:, cells:{}};
    //   for example,
    //     { rowID: row_id, cells: { variable_name_1: '0,2,4,6', variable_name_2: ... } }
    //   specifies that letters with indexes 0, 1, 4, and 5 are highlighted
    //   (in row with id row_id, and column with variable name variable_name_1);
    //   here all row and cell indexes are 0-based;
    // partialUpdate - set to true for a partial update of the table;
    //   the partial update is faster and retains some table settings, e.g.,
    //   column width and displayed columns;
    //   partial update is sufficient after table search and after some other actions;

    var UPP = ETD.UPP, // 1 pixel corresponds to 10 units
        idTable = ETD.TABLE.id,
        order /*:map*/,
        columns /*:array*/, colSelW /*:int*/,
        highlights /*:array*/,
        onDraw,
        partialUpdate /*:boolean*/,
        noData /*:boolean*/, filteredRows /*:array*/,
        idx,
        data /*:map*/, config /*:map*/, style /*:map*/,
        colRowID /*:map*/, colRowNo /*:map*/, colData /*:map*/,
        visColCnt /*:int*/,
        mode /*:string*/, initialMode /*:string*/,
        maxColsInScrolling; /*:int*/

    options = options || {};
    order = options.order;
    columns = options.columns; // column info (after deserialization)
    colSelW = options.columnSelectionWidth; // column selection width (after deserialization)
    highlights = options.highlights;
    onDraw = typeof options.ondraw === 'function' ? options.ondraw : ETD.TABLE.onDraw;

    // validate call
    call = call || {};
    if (typeof call.reason === 'string' && typeof ETD.TABLE.updateReason[call.reason] === 'string') {
        call.reason = ETD.TABLE.updateReason[call.reason];
    }
    partialUpdate = call.reason === 'search' || call.reason === 'deserialize-search' || call.reason === 'settings'
        || call.reason === 'touch-mode';

    // if necessary, update data dependent menus and reset the chart
    if (call.reason === 'new-data' || call.reason === 'deserialize-csv' || call.reason === 'deserialize-excel') {
        if (call.reason === 'new-data') {
            ETD.AFO.updateDataDependentMenus();
        }
        ETD.CHART.release();
    }

    // hide initial cover
    $('#idInitCoverL').css({ display: 'none' });

    // show temporary cover
    $('#idTblTmpCover').css({ display: 'block' });

    // style changes on the left side
    $('#idSearchControls').css({ display: 'table' });

    // style changes on the right side
    $('#idContainerRight').css({ display: 'block' });
    $('#idPaneRight').removeClass('cnColors1').css({ 'background-color': 'white' });

    // remove background color in ETD.TABLE.onDraw ()


    // check if data are present
    noData = !($.isArray(ETD.TABLE.data) && $.isArray(ETD.STRUCTS.HEADER));
    if (noData || ETD.TABLE.data.length === 0) {
        if (noData) {
            ETD.IMPORT.setDataHeader(undefined);
            ETD.TABLE.data = undefined;
        }
        ETD.TABLE.release();
        ETD.CHART.release();
        return;
    }

    /* // debug: load explorethedata release candidate
    if (ETD.STRUCTS.HEADER.length > 0 && ETD.STRUCTS.HEADER[0].text === 'load-explorethedata-release-candidate') {
        window.location.href = '17/';
        return;
    } */

    // the array of filtered rows
    filteredRows = undefined;
    if ($.isArray(highlights)) {
        filteredRows = [];
        for (idx = 0; idx < highlights.length; idx++) {
            filteredRows[idx] = highlights[idx].rowID;
        }
    }

    // the flag is serialized and used in deserialization
    ETD.TABLE.searchApplied = !!filteredRows;

    // data object
    data = {

        rawdata: ETD.TABLE.data, // the data array, reference added for the table operations only

        // instead of passing the data array directly, pass a callback;
        // in this way, it is possible to modify data on the fly,
        // see ETD.TABLE.getDataItem () below;
        // datasetSize - size of the dataset; not in use if filteredRows (below) is defined;
        dataset: ETD.TABLE.getDataItem,
        datasetSize: ETD.TABLE.data.length,

        // optional array of data item indexes (0-based);
        // if specified, only these items are displayed in the table;
        // the array also defines the order of items;
        // if the array is, e.g.,
        //   [2, 0],
        // only the 3rd and 1st row is displayed;
        filteredRows: filteredRows,

        selectedRows: undefined, // optional, an array of 0-based indexes, e.g. [6, 7]

        highlightedCharacters: highlights,

        focusedRow: undefined,

        // columns (optional);
        // if the list is passed, only these variables that appear in the list
        // can be selected later in gui;
        columns: undefined, // initialized below

        // ordering
        order: order // { variable: 'variable_name', increasing: bool }
    };
    if (!partialUpdate) {
        data.columns = ETD.TABLE.makeColumnsStruct(ETD.STRUCTS.HEADER);
    } else {
        data.dataset = undefined;
    }

    // prepare column for row id
    if (ETD.TABLE.showRowID && data.columns) {
        colRowID = { variable: ETD.TABLE.rowIDVar, text: ETD.TABLE.rowIDTxt, hide: true };
    }

    // prepare column for row number (1-based); make the column unsortable;
    if (ETD.TABLE.showRowNo && data.columns) {
        colRowNo = {
            variable: ETD.TABLE.rowNoVar,
            text: ETD.TABLE.rowNoTxt,
            width: 60 * UPP,
            hide: false,
            unsortable: true
        };
    }

    // limit the number of visible columns
    visColCnt = 0;
    if (data.columns) {
        for (idx = 0; idx < data.columns.length; idx++) {
            if (data.columns[idx].variable === ETD.TABLE.rowIDVar) {
                data.columns[idx].hide = true;
            }
            if (!data.columns[idx].hide) {
                visColCnt++;
            }
            if (visColCnt > ETD.TABLE.visibleColsLimit) {
                data.columns[idx].hide = true;
            }
        }
    }

    // after deserialization, overwrite the column info with that read out from the document
    if ($.isArray(columns)) {

        data.columns = []; // { variable:, text:, hide:, width:, unsortable: }
        for (idx = 0; idx < columns.length; idx++) {
            colData = columns[idx];
            data.columns.push({
                variable: colData.variable,
                text: colData.headertext,
                hide: !colData.show,
                width: colData.rect && typeof colData.rect === 'object' ? colData.rect.width : undefined,
                unsortable: colData.variable !== ETD.TABLE.rowNoVar ? false : true
            });
            if (colData.variable === ETD.TABLE.rowIDVar) {
                colRowID = null; // make sure the variable is added not more than 1 times
            }
            if (colData.variable === ETD.TABLE.rowNoVar) {
                colRowNo = null; // make sure the variable is added not more than 1 times
            }
        }
    }

    // add columns for row id and row no
    if (colRowID) {
        data.columns.unshift(colRowID);
    }
    if (colRowNo) {
        data.columns.unshift(colRowNo);
    }


    // configuration

    // mode, initial mode: value from the checkbox
    mode = 'text';
    initialMode = 'text';
    if ($('#idGraphicalView').val() === '1') {
        mode = 'graphics'; // 'text-graphics'
        initialMode = 'graphics';
    }

    // max columns in scrolling
    maxColsInScrolling = parseInt($('#idColumnsInScrolling').val());
    if (isNaN(maxColsInScrolling)) {
        maxColsInScrolling = 1000; // unlimited
    }

    // width of the table of column selection
    if (typeof colSelW !== 'number') {
        colSelW = ETD.TABLE.colSelectionWidth;
    }

    config = {
        mode: mode, // 'text' (default), 'text-graphics', 'graphics'
        initialMode: initialMode, // 'text' (default), 'graphics'
        roundNumbers: false, // false (default) or true
        infoBar: true, // false (default) or true
        columnSelectionWidth: colSelW, // -1 - column selection is disabled
        selectionTableHeight: 1, // table of selected rows, number of lines
        maxColumnsInScrolling: maxColsInScrolling,

        // the callbacks
        onDraw: onDraw, // ETD.TABLE.onDraw
        onChangeSelection: ETD.TABLE.onChangeSelection,
        onEditStart: ETD.TABLE.onEditStart,
        onEditEnd: ETD.TABLE.onEditEnd,
        onDrop: ETD.IMPORT.onDropDataCsvDataJsConfigJsStyleHtml,
        onSort: undefined,

        operations: ETD.CONFIG.operations,

        // global settings
        global: {
            appForExcel: true,
            pathToResource: ETD.baseHref + 'images/res/',
            version: '2.8'
        }
    };

    // style object
    style = ETD.STYLE.table();

    // draw the table
    SVGware.table.draw(idTable, { data: data, config: config, style: style }, call);
};

// Get a data item (table row). Cp. ETD.TABLE.getDataItemFormatted ().
ETD.TABLE.getDataItem = function (rowID /*:int*/, rowNo /*:int*/, variables /*:map*/, formatted /*:map*/) {
    // rowID - row id (0-based);
    // rowNo - current row number,
    //   depends on data filtering and sorting (0-based);
    // variables - a map mapping a variable to anything (optional);
    //   if defined, only these variables are included in the returned data item;
    // formatted - an empty object for returning formatted strings (optional);

    var dataItem /*:map*/, result /*:map*/, key; /*:string*/

    dataItem = ETD.TABLE.data[rowID];
    result = {};
    key = undefined;
    if (!variables) {
        for (key in dataItem) {
            if (dataItem[key] === '' || isNaN(dataItem[key])) { // not a number
                result[key] = dataItem[key];
            } else { // a number
                result[key] = Number(dataItem[key]); // Number('') -> 0;
                if (formatted) {
                    formatted[key] = dataItem[key];
                }
            }
        }
    } else {
        for (key in variables) {
            if (dataItem[key] === '' || isNaN(dataItem[key])) { // not a number
                result[key] = dataItem[key];
            } else { // a number
                result[key] = Number(dataItem[key]); // Number('') -> 0;
                if (formatted) {
                    formatted[key] = dataItem[key];
                }
            }
        }
    }

    // the following variable, row index, counts the displayed rows (1, 2, 3,...)
    // independent of data filtering and sorting;
    if (ETD.TABLE.showRowNo) {
        result[ETD.TABLE.rowNoVar] = rowNo + 1;
    }

    // the following variable, row id, is the 1-based index of the row in the dataset;
    if (ETD.TABLE.showRowID) {
        result[ETD.TABLE.rowIDVar] = rowID + 1;
    }

    return result;
};

// Get a data item (table row).
// Numbers are in the original format (e.g., '1.000' is not converted to 1).
// Cp. ETD.TABLE.getDataItem ().
ETD.TABLE.getDataItemFormatted = function (rowID /*:int*/, rowNo /*:int*/, variable /*:string*/, variables /*:map*/) {
    // rowID - row id (0-based);
    // rowNo - current row number,
    //   depends on data filtering and sorting (0-based);
    // variable - if defined, other variables are ignored;
    // variables - map of visible columns (variables);

    var dataItem /*:map*/, result /*:map*/,
        key /*:string*/, varX; /*:string*/

    dataItem = ETD.TABLE.data[rowID];
    result = {};

    if (variable) {
        if (variable in dataItem) {
            result[variable] = dataItem[variable];
        }
    } else {
        for (key in variables) {
            if (key in dataItem) {
                result[key] = dataItem[key];
            }
        }
    }

    // the following variable, row index, counts the displayed rows (1, 2, 3,...)
    // independent of data filtering and sorting;
    varX = ETD.TABLE.rowNoVar;
    if (variable === varX || variables[varX]) {
        result[varX] = rowNo + 1;
    }

    // the following variable, row id, is the 1-based index of the row in the dataset;
    varX = ETD.TABLE.rowIDVar;
    if (variable === varX || variables[varX]) {
        result[varX] = rowID + 1;
    }

    return result;
};

// Get row number from row id (both 0-based).
ETD.TABLE.getRowNo = function (rowID /*:int*/) {
    // rowID - row id, 0-based

    // check if
    //   ETD.TABLE.filteredRows
    // is an array or not;
    // if not, all dataset items are currently displayed
    // in the initial order;
    // if ETD.TABLE.filteredRows is an array, it defines
    // the dataset items and their current order;
    // the array is passed to the onDraw() callback;

    if (!$.isArray(ETD.TABLE.filteredRows)) {
        return rowID;
    } else {
        return ETD.TABLE.filteredRows.indexOf(rowID);
    }
};

// Get row id from row number (both 0-based).
ETD.TABLE.getRowID = function (rowNo /*:int*/) {
    // rowNo - row number, 0-based

    // check if
    //   ETD.TABLE.filteredRows
    // is an array or not;
    // if not, all dataset items are currently displayed
    // in the initial order;
    // if ETD.TABLE.filteredRows is an array, it defines
    // the dataset items and their current order;
    // the array is passed to the onDraw() callback;

    if (!$.isArray(ETD.TABLE.filteredRows)) {
        return rowNo;
    } else {
        if (rowNo < 0 || rowNo >= ETD.TABLE.filteredRows.length) {
            return undefined;
        }
        return ETD.TABLE.filteredRows[rowNo];
    }
};

ETD.TABLE.getSize = function () {

    if ($.isArray(ETD.TABLE.data)) {
        if (!$.isArray(ETD.TABLE.filteredRows)) {
            return ETD.TABLE.data.length;
        } else {
            return ETD.TABLE.filteredRows.length;
        }
    } else {
        return 0;
    }
};

// callbacks =============================================================

// The onDraw callback is called immediately after drawing the table.
// Store info on columns and rows (the current state). This is used for exporting to CSV file.
ETD.TABLE.onDraw = function (event, domGCallback) {

    var reason /*:string*/, filename; /*:string*/

    // a flag used to suppress automatic layout changes upon imports
    ETD.TABLE.initd = true;

    // remove background color and temporary cover
    $('#' + ETD.TABLE.id).removeClass('cnColors2').css({ 'background-color': 'white' });
    $('#idTblTmpCover').css({ display: 'none' });

    // store info on rows; optionally display a message;
    ETD.STRUCTS.COLS = event.table.columns;
    if ($.isArray(event.table.filteredRows)) { // need a copy of the array
        // in order to detect changes, see above
        ETD.TABLE.filteredRows = event.table.filteredRows.slice(0);

        if (ETD.TABLE.filteredRows.length < ETD.TABLE.data.length) { // due to this condition,
            // the message is not displayed after sorting

            ETD.AFO.message(ETD.TABLE.filteredRows.length + ' of ' + ETD.TABLE.data.length + ' rows', 'info', true);
        }
    } else {
        ETD.TABLE.filteredRows = undefined;
        ETD.AFO.message('', 'info', true, 'm-15');
    }


    // store the ordering info;
    // this somewhat duplicates event.table.filteredRows;
    // however, the latter is not serialized while the ordering info is serialized and deserialized to restore the state;
    ETD.TABLE.sortedByVariable = event.table.sortedByVariable;
    ETD.TABLE.sortedInIncreasingOrder = event.table.sortedInIncreasingOrder;

    // store the current mode (text/graphics) and
    // the column selection width
    ETD.TABLE.curMode = event.table.mode;
    ETD.TABLE.colSelectionWidth = event.table.columnSelectionWidth;

    // update chart, serialize
    if (event.table.call && typeof event.table.call.reason === 'string') {

        reason = event.table.call.reason;
        filename = event.table.call.filename;

        // svgware built-in msgs
        if (reason === 'resize') {
            // empty
        } else if (reason === 'layout') {
            ETD.SER.setModified(1); // layout
        } else if (reason === 'sort') {
            ETD.SER.setModified(1); // sort
            return ETD.CHART.update(event.table.call); // in ETD.TABLE.onDraw; reason - 'sort';
        } else if (reason === 'select-column') {
            if (!($('#idSearchColumns').val() === '_all_columns' && $('#idSearchString').val() !== '')) {
                ETD.SER.setModified(1); // select-column
                ETD.SER.serialize({ save: true }); // in ETD.TABLE.onDraw (), reason 'select-column'
            } else {
                // column selection changed and 'All columns' are selected in the menu of search columns:
                // search the table because the selection 'All columns' means all visible columns;
                ETD.TABLE.search();
            }

            // app msgs
        } else if (reason === 'init') {
            // not in use
        } else if (reason === 'new-data') {
            ETD.SER.setModified(2); // new data
            ETD.SER.serialize({ data: true });
            return ETD.CHART.update(event.table.call); // in ETD.TABLE.onDraw; reason - 'new-data';
        } else if (reason === 'deserialize-excel' || reason === 'deserialize-csv') {
            // resize to fix an issue on iPad (tested in Chrome): after clicking on the link 'live example' in the help,
            // the table and chart are created, and the height of the chart increases step by step in a loop;
            // the same issue if loading from the indexed db;
            if (ETD.AFO.touchFriendlyMode) {
                ETD.AFO.resize();
            }
            if (reason === 'deserialize-csv') {
                ETD.SER.setModified(2); // in ETD.TABLE.onDraw; reason - 'deserialize-csv';
            }
            ETD.SER.serialize({ data: true });
            if (!event.table.call.searchapplied || $('#idSearchString').val() === '') {
                return ETD.CHART.update(event.table.call); // in ETD.TABLE.onDraw; reason - 'deserialize-search';
            } else {
                ETD.TABLE.search({
                    order: {
                        variable: event.table.sortedByVariable, increasing: event.table.sortedInIncreasingOrder
                    }, call: { reason: 'deserialize-search' }
                });
            }
        } else if (reason === 'deserialize-search') {
            return ETD.CHART.update(event.table.call); // in ETD.TABLE.onDraw; reason - 'deserialize-search';
        } else if (reason === 'search') {
            ETD.SER.setModified(2); // search
            return ETD.CHART.update(event.table.call); // in ETD.TABLE.onDraw; reason - 'search';
        } else if (reason === 'settings') { // #idGraphicalView
            ETD.SER.setModified(2); // settings
            return ETD.CHART.update(event.table.call); // in ETD.TABLE.onDraw; reason - 'settings';
        } else if (reason === 'new-config') {
            ETD.SER.setModified(2);
            return ETD.CHART.update(event.table.call); // in ETD.TABLE.onDraw; reason - 'new-config';
        } else if (reason === 'new-style') {
            ETD.SER.setModified(2);
            ETD.AFO.resize(); // resize as the style may specify the chart dimensions
            return ETD.CHART.update(event.table.call); // in ETD.TABLE.onDraw; reason - 'new-style';
        }
        // else if (reason === 'new-table-style') { }
        // else if (reason === 'touch-mode') {}
    }
};

// The onChangeSelection callback displays ID-s of the selected rows in the box.
// The row ID is 1-based index of the data item in the dataset.
ETD.TABLE.onChangeSelection = function (event) {

    // store selected rows (an array of 0-based row id-s)
    ETD.TABLE.selectedRowID = event.table.selectedData.rows;

    // mark the selected items
    ETD.TABLE.markSelectedRowsOnChart();
};

// The onEditStart callback.
// Mark columns for row no and row id uneditable.
ETD.TABLE.onEditStart = function (event) {

    var domInputTextBox,
        variable /*:string*/, value; /*:string*/

    domInputTextBox = event.table.edit.inputTextBox;
    variable = event.table.edit.variable;

    // some variable values are not editable
    if (variable === ETD.TABLE.rowNoVar || variable === ETD.TABLE.rowIDVar) {

        value = domInputTextBox.value;

        // display text box in read-only mode
        domInputTextBox.setAttribute('readonly', 'readonly');

        // change style of the text box
        domInputTextBox.style.backgroundColor = 'gainsboro';

        // set visibility to visible with the following call:
        domInputTextBox.style.visibility = 'visible';
        // in this case the default function calls
        // (domInputTextBox.setSelectionRange(), domInputTextBox.focus())
        // are skipped after the callback;
        // optionally set selection range, focus:
        domInputTextBox.setSelectionRange(value.length, value.length);
        domInputTextBox.focus();
    }
};

// The onEditEnd callback. Store the new value:
ETD.TABLE.onEditEnd = function (event) {

    // the new value
    var value /*:string*/ = event.table.edit.newValue;

    // store the value
    ETD.TABLE.data[event.table.edit.rowID][event.table.edit.variable] = value;

    // serialize data
    ETD.SER.setModified(2); // new data
    ETD.SER.serialize({ data: true }); // in ETD.TABLE.onEditEnd ()

    // update the chart
    ETD.CHART.update(); // inline editing;
};
// callbacks: end ========================================================

// table search ==========================================================

// Initialize the drop down menu for selecting search columns.
ETD.TABLE.initializeSearchInColumnDropDown = function (optionValueLabel) {
    // optionValueLabel - an array of objects of type {value:, text:};
    //   here 'value' must be the variable name in the dataset, and
    //   'text' is the corresponding column header;

    var select/*:$*/, col; /*:int*/

    select = $('#idSearchColumns');
    if (select.length !== 1) {
        return;
    }

    // remove old options
    select.find('option').remove();

    // return if no option values passed
    if (!$.isArray(optionValueLabel) || optionValueLabel.length === 0) {
        return;
    }

    // add option 'search in all columns'
    select.append($('<option />').attr('value', '_all_columns').text('All columns').attr('selected', 'selected'));

    // add option 'Row ID'
    select.append($('<option />').attr('value', ETD.TABLE.rowIDVar).text(ETD.TABLE.rowIDTxt));

    // add other options
    for (col = 0; col < optionValueLabel.length; col++) {
        select.append($('<option />').attr('value', optionValueLabel[col].value).text(optionValueLabel[col].text));
    }
};

// OnChange event handler for the 'Regular expression' checkbox.
// Disable/enable the 'Whole word' checkbox.
ETD.TABLE.onChangeRegEx = function () {

    var domRegEx,
        domWholeWord;

    domRegEx = document.getElementById('idRegularExpression');
    domWholeWord = document.getElementById('idWholeWord');

    if (!domRegEx || !domWholeWord) return;
    domWholeWord.disabled = domRegEx.checked;
};

// OnChange event handler for the 'Search Mode' menu.
// Disable/enable the 'Case sensitive' and 'Whole word' checkboxes.
ETD.TABLE.onChangeSearchMode = function () {

    function setDisabled(id, bDisabled) {
        var domCheckBox = document.getElementById(id);
        if (!domCheckBox) {
            return;
        }
        domCheckBox.disabled = bDisabled;
    }

    var sSearchMode = $('#idSearchMode').val();
    if (sSearchMode === 'string') {
        setDisabled('idCaseSensitive', false);
        setDisabled('idWholeWord', false);
    } else if (sSearchMode === 'regex') {
        setDisabled('idCaseSensitive', false);
        setDisabled('idWholeWord', true);
    } if (sSearchMode === 'javascript') {
        setDisabled('idCaseSensitive', true);
        setDisabled('idWholeWord', true);
    }
};

// OnKeyDown event handler for the search string input box.
// Enter key triggers search and table update.
ETD.TABLE.onKeyDownSearch = function (event) {

    var keyCode;

    if (!event) {
        return;
    }

    if (typeof event.which !== 'undefined') {
        keyCode = event.which;
    } else { // ie8
        keyCode = event.keyCode;
    }

    if (keyCode === 13) { // enter

        // prevent default;
        // otherwise wrong event handler called in ie9, ie10;
        event.preventDefault();

        // search
        ETD.TABLE.search();
    }
};

// OnClick event handler for the Search button.
// Search the dataset according to the search settings, update the table.
ETD.TABLE.search = function (options /*:map*/) {

    var order /*:map*/, call /*:map*/,
        searchSettings /*:map*/ = {},
        visVars /*:map*/,
        inx /*:int*/,
        highlights; /*:array*/

    options = options || {};
    order = options.order;
    call = options.call || { reason: 'search' };

    // get settings from the GUI
    searchSettings.string = $('#idSearchString').val();
    searchSettings.casesensitive = $('#idCaseSensitive').prop('checked');
    searchSettings.wholeword = $('#idWholeWord').prop('checked');
    searchSettings.mode = $('#idSearchMode').val(); // the search mode: string/regex/javascript
    searchSettings.incolumn = $('#idSearchColumns').val(); // the column to search in

    // visible columns (variables)
    visVars = {};
    for (inx = 0; inx < ETD.STRUCTS.COLS.length; inx++) {
        if (ETD.STRUCTS.COLS[inx].show) {
            visVars[ETD.STRUCTS.COLS[inx].variable] = true;
        }
    }

    // search and store the matches, update the table
    try {

        highlights = ETD.GEN.searchTable(
            function (iRowID, iRowNo, sVariable) {
                return ETD.TABLE.getDataItemFormatted(iRowID, iRowNo, sVariable, visVars);
            },
            ETD.TABLE.data.length, searchSettings);

        // update the table
        ETD.TABLE.create({ // search
            highlights: highlights,
            order: order
        }, call);

    } catch (oEx) {
        ETD.AFO.message(oEx.message, 'error', true);
    }
};
// table search: end =====================================================

// other functions =======================================================

// Export data to excel or csv file.
ETD.TABLE.exportX = function (mode /*:string*/, filteredRowsOnly /*:boolean*/, withChartInfo /*:boolean*/) {

    var separator = ',', sNewLine = '\r\n',
        getRowID, exportData /*:array*/, contents /*:string*/,
        variables /*:map*/,
        size,
        exportLine /*:array*/,
        col /*:int*/, row /*:int*/,
        colData /*:map*/, formatted /*:map*/,
        dataItem /*:map*/, variable /*:string*/,
        line /*:string*/, value; /*:string*/

    if (mode !== ETD.SER.mode['csv-file'] && mode !== ETD.SER.mode['csv-winapp-store'] && mode !== ETD.SER.mode['excel-worksheet']) {
        return null;
    }

    getRowID = (function (iRowNo) {

        if (!filteredRowsOnly) { // all rows

            if (!$.isArray(ETD.TABLE.filteredRows)) { // no sorting nor filtering: export all rows in the initial order

                size = ETD.TABLE.getSize();
                return ETD.TABLE.getRowID;
            } else { // sorting and / or filtering

                if (ETD.TABLE.getSize() === ETD.TABLE.data.length) { // sorting but no filtering applied: export all rows in the current order
                    size = ETD.TABLE.getSize();
                    return ETD.TABLE.getRowID;
                } else { // with filtering and possibly also sorting: export all rows in the initial order
                    size = ETD.TABLE.data.length;
                    return function (iRowNo) {
                        return iRowNo;
                    };
                }
            }
        } else { // filtered rows only (possibly no filtering): export the filtered rows in the current order

            size = ETD.TABLE.getSize();
            return ETD.TABLE.getRowID;
        }
    })();

    function getValue(sVariable, oDataItem, formatted) {
        if (typeof oDataItem[sVariable] !== 'undefined') {
            if (typeof formatted[sVariable] !== 'undefined') {
                return formatted[sVariable];
            } else {
                return oDataItem[sVariable];
            }
        } else {
            return '';
        }
    }

    exportData = [];
    contents = '';
    function returnResult() {
        if (mode === ETD.SER.mode['excel-worksheet']) {
            return exportData;
        } else {
            return contents;
        }
    }

    // check if data set to the table
    if (!$.isArray(ETD.TABLE.data) || !$.isArray(ETD.STRUCTS.COLS)) {
        return returnResult();
    }

    // map of variables (variable-name -> true) which are displayed in the table or in the chart
    variables = ETD.SER.serializeHeaderData(mode).variables;

    if (mode === ETD.SER.mode['excel-worksheet']) {
        // export an array of objects, one for each table line

        // add info on the header
        exportLine = [];
        for (col = 0; col < ETD.STRUCTS.COLS.length; col++) {
            colData = ETD.STRUCTS.COLS[col];
            if (variables[colData.variable]) {
                exportLine[exportLine.length] = colData.headertext;
            }
        }
        exportData[exportData.length] = exportLine;

        // loop over table rows and columns
        for (row = 0; row < size; row++) {
            formatted = {};
            exportLine = [];
            formatted = {};
            dataItem = ETD.TABLE.getDataItem(getRowID(row), row, variables, formatted);
            for (col = 0; col < ETD.STRUCTS.COLS.length; col++) {
                variable = ETD.STRUCTS.COLS[col].variable;
                if (variables[variable]) {
                    exportLine[exportLine.length] = getValue(variable, dataItem, formatted);
                }
            }
            exportData[exportData.length] = exportLine;
        }
    } else if (mode === ETD.SER.mode['csv-file'] || mode === ETD.SER.mode['csv-winapp-store']) {

        // export csv text

        // optionally add a chart data string
        if (withChartInfo) {
            contents += ETD.SER.chartdatabegin + ETD.SER.serializeChartData(mode) + ETD.SER.chartdataend + ' \r\n\r\n';
        }

        // info on the header;
        line = '';
        for (col = 0; col < ETD.STRUCTS.COLS.length; col++) {

            colData = ETD.STRUCTS.COLS[col];
            if (variables[colData.variable]) {

                if (line.length !== 0) {
                    line += separator;
                }
                // if the header cell string contains the separator (comma),
                // surround the text by double-quotes;
                value = colData.headertext;
                // if the text contains the separator (comma),
                // surround it by double-quotes;
                if (value.indexOf(separator) < 0) {
                    line += value;
                } else {
                    line += '"' + value + '"';
                }
            }
        }
        contents += line + sNewLine;

        // loop over table rows and columns
        for (row = 0; row < size; row++) {
            line = '';
            formatted = {};
            dataItem = ETD.TABLE.getDataItem(getRowID(row), row, variables, formatted);
            for (col = 0; col < ETD.STRUCTS.COLS.length; col++) {

                colData = ETD.STRUCTS.COLS[col];
                variable = colData.variable;
                if (variables[variable]) {

                    if (line.length !== 0) {
                        line += separator;
                    }
                    value = getValue(variable, dataItem, formatted).toString();
                    // if the text contains the separator (comma),
                    // surround it by double-quotes;
                    if (value.indexOf(separator) < 0) {
                        line += value;
                    } else {
                        line += '"' + value + '"';
                    }
                }
            }
            contents += line + sNewLine;
        }
    }

    return returnResult();
};

// Mark the selected rows on the chart.
ETD.TABLE.markSelectedRowsOnChart = function () {

    var domGChart, domGSelection,
        selection /*:map*/,
        row /*:int*/, rowIDInx /*:int*/, rowNoInx /*:int*/,
        selected /*:array*/, prop; /*:map*/

    try {

        // g-element on the chart
        domGChart = ETD.CHART.domGCallback;
        if (!domGChart) {
            return;
        }

        // remove previous marks
        ETD.GEN.removeElements(['idTblSelection'], domGChart.ownerDocument);

        // return if no selected rows in the table
        if (!$.isArray(ETD.TABLE.selectedRowID) || ETD.TABLE.selectedRowID.length === 0) {
            return;
        }

        // add g-element to the chart
        domGSelection = ETD.GEN.createElement('g', domGChart, {
            id: 'idTblSelection'
        });

        // make a map: table row number (1-based) mapped to '1'
        selection = {};
        for (row = 0; row < ETD.TABLE.selectedRowID.length; row++) {
            rowIDInx = ETD.TABLE.selectedRowID[row]; // 0-based
            rowNoInx = ETD.TABLE.getRowNo(rowIDInx);
            selection[(rowNoInx + 1).toString()] = 1;
        }

        // request info on the specified data items in the chart
        selected = ETD.GEN.getSelectedData(ETD.CHART.id, {
            variable: undefined,
            members: selection
        });
        if (!selected || selected.length === 0) {
            return;
        }

        // mark the points on the chart
        prop = ETD.STYLE.general.selectedDataCircle;
        if (prop) {
            for (row = 0; row < selected.length; row++) {
                prop.cx = selected[row].x;
                prop.cy = selected[row].y;
                ETD.GEN.createElement('circle', domGSelection, prop);
            }
        }
    } catch (oEx) {
        // empty
    }
};

ETD.TABLE.setSelected = function (rowNo /*:array*/) {
    // rowNo - array of row numbers, 0-based

    var id = ETD.TABLE.id,
        selected /*:array*/,
        inx;

    rowNo = rowNo || [];

    selected = [];
    for (inx = 0; inx < rowNo.length; inx++) {
        selected.push(ETD.TABLE.getRowID(rowNo[inx]));
    }

    // set selected rows, scroll the table
    SVGware.table.draw(id, {
        data: {
            selectedRows: selected, // 0-based
            focusedRow: {
                rowID: selected.length > 0 ? selected[0] : 0,
                position: 1, // 0, 1, or 2 - the row is scrolled
                // to the top, middle, or bottom, respectively;
                setSelected: false // selected rows set with 'selectedRows';
            }
        }
    }, { reason: 'set-selection' });
};

ETD.TABLE.exists = function () {
    return $('#idPaneLeft').find('iframe').length !== 0;
};

ETD.TABLE.release = function () {

    var id = ETD.TABLE.id, bgCol;

    SVGware.release(id);

    // reset background which is removed in ETD.TABLE.create ()
    bgCol = ETD.STYLE.general && ETD.STYLE.general['skin'] ? ETD.STYLE.general['skin']['backgroundColor2'] : 'white';
    $('#' + id).addClass('cnColors2').css({ 'background-color': bgCol });
};

ETD.TABLE.makeColumnsStruct = function (header2) {

    var inx, columns /*:array*/, col; /*:object*/

    columns = [];
    if ($.isArray(header2)) {
        for (inx = 0; inx < header2.length; inx++) {
            col = header2[inx];
            if (col.variable === ETD.TABLE.rowIDVar || col.variable === ETD.TABLE.rowNoVar) {
                continue;
            }
            columns.push({ variable: col.variable, value: col.variable, text: col.text });
        }
    }

    return columns;
};

ETD.TABLE.makeHeader2Struct = function (header1, count) {

    var header2 = [],
        cnt, inx,
        dfltVar; /*:object*/

    if (!$.isArray(header1)) {
        header1 = [];
    }

    count = parseInt(count);
    if (isNaN(count) || count < 0) {
        count = header1.length;
    }
    cnt = Math.max(header1.length, count);

    for (inx = 0; inx < cnt; inx++) {
        dfltVar = ETD.TABLE.getDefaultVarName(inx);
        if (inx < header1.length) {
            header2[inx] = { variable: dfltVar.name, text: header1[inx] };
        } else {
            header2[inx] = { variable: dfltVar.name, text: dfltVar.headertext };
        }
    }

    return header2;
};

ETD.TABLE.getDefaultVarName = function (col /*:int*/) {
    // col - 0-based column index

    return { name: 'x' + (col + 1), headertext: 'X' + (col + 1) };
};

ETD.IDB = {
    NAME: 'etd-db',
    VERSION: 1,
    STORE: 'docs'
};

ETD.IDB.open = function () {

    return new Promise(function (resolve, reject) {

        var request;

        if (!ETD.GEN.usingIndexedDB()) {
            reject({ message: 'IndexedDB not supported or not in use' });
        }

        request = indexedDB.open(ETD.IDB.NAME, ETD.IDB.VERSION); // indexedDB - IDBFactory, request - IDBRequest

        request.onupgradeneeded = function (event) {

            var db, store;

            db = event.target.result;
            ETD.AFO.message('IndexedDB onupgradeneeded: database: ' + db.name + '; requested version: ' + db.version + ';', 'info', false);

            //transaction = event.target.transaction;
            if (!db.objectStoreNames.contains(ETD.IDB.STORE)) {
                store = db.createObjectStore(ETD.IDB.STORE, { keyPath: 'id' });
            } else {
                //store = transaction.objectStore(ETD.IDB.STORE);
            }
        };

        request.onsuccess = function (event) {

            var db = event.target.result;
            //ETD.AFO.message('IndexedDB opened: database: ' + db.name + '; version: ' + db.version + ';', 'info', false);
            resolve(db);
        };

        request.onerror = function (event) {

            ETD.AFO.message('Error: IndexedDB could not be opened (' + event.target.error + ').', 'error', false);
            reject(event.target.error);
        };
    });
};

ETD.IDB.putItem = function (doc /*: string or object */, id) {

    if (typeof id !== 'string' || id === '') {
        return;
    }

    return ETD.IDB.open().then(

        function (db) { // IDBDatabase

            var tx, store, item, request;

            tx = db.transaction(ETD.IDB.STORE, 'readwrite'); // IDBTransaction
            store = tx.objectStore(ETD.IDB.STORE); // IDBObjectStore
            item = {
                id: id,
                doc: doc,
                created: new Date().getTime() // eg., new Date(created).toUTCString()
            };
            request = store.put(item); // IDBRequest
        },
        function (error) { // DOMException
            ETD.AFO.message('Error: Failed to put item to indexedDB. Message: ' + error.message + '. Item id: ' + id + '.', 'error', false);
            return error;
        }
    );
};

ETD.IDB.getItem = function (id) {

    return ETD.IDB.open().then(

        function (db) { // IDBDatabase

            return new Promise(function (resolve, reject) {

                var tx, store, item, request, err;

                tx = db.transaction(ETD.IDB.STORE, 'readonly'); // IDBTransaction
                store = tx.objectStore(ETD.IDB.STORE); // IDBObjectStore
                request = store.get(id); // IDBRequest

                request.onsuccess = function (event) {
                    item = event.target.result;
                    if (item) {
                        resolve(item.doc);
                    } else {
                        err = 'IndexedDB item ' + id + ' not found.';
                        ETD.AFO.message(err, 'info', false);
                        reject(err);
                    }
                };
                request.onerror = function (event) {
                    reject(event);
                };
            });
        },
        function (error) { // DOMException

            ETD.AFO.message('Error: Failed to open indexedDB. Message: ' + error.message + '. Item id: ' + id + '.', 'error', false);
            return error;
        }
    );
};

ETD.IDB.deleteItem = function (id) {

    return ETD.IDB.open().then(

        function (db) { // IDBDatabase

            var tx, store;

            tx = db.transaction(ETD.IDB.STORE, 'readwrite'); // IDBTransaction
            tx.oncomplete = function (event) {
                ETD.AFO.message('Item ' + id + ' deleted from indexedDB.', 'info', false);
            };
            tx.onerror = function (event) {
            };
            store = tx.objectStore(ETD.IDB.STORE); // IDBObjectStore
            store.delete(id); // IDBRequest

        }, function (error) { // DOMException
            ETD.AFO.message('Error: Failed to delete item ' + id + 'from indexedDB. (' + error.message + ')', 'error', false);
            return error;
        });
};

ETD.IDB.collectCarbage = function (pattern /*:string*/, keepfiles /*:map*/) {

    return ETD.IDB.open().then(

        function (db) { // IDBDatabase

            var tx, store, regex;

            tx = db.transaction(ETD.IDB.STORE, 'readwrite'); // IDBTransaction
            tx.oncomplete = function (event) {
            };
            tx.onerror = function (event) {
            };
            store = tx.objectStore(ETD.IDB.STORE); // IDBObjectStore

            regex = new RegExp(pattern, 'i');

            store.openCursor().onsuccess = function (event) {
                var cursor = event.target.result;
                if (cursor) {
                    if (cursor.key.search(regex) >= 0 && !keepfiles[cursor.key]) {
                        store.delete(cursor.key); // IDBRequest
                        ETD.AFO.message('Item ' + cursor.key + ' deleted from indexedDB.', 'info', false);
                    }
                    cursor.continue();
                } else {
                    // done
                }
            };

        }, function (error) { // DOMException
            ETD.AFO.message('Error: Failed to delete outdated items from the database (' + error.message + ').', 'error', false);
            return error;
        });
};

// item id-s in the uwp app directory or indexed db
ETD.IDB.getItemID = function (id) {

    var ext = ETD.SERUWP.mode === 'ser_js' ? 'json' : ETD.SERUWP.mode === 'ser_csv' ? 'csv' : '';

    if (id === 'chart_current') {
        return 'chart_current.' + ext;
    } else if (id === 'chart_new') {
        return 'chart_' + Date.now() + '.' + ext; // (new Date(Date.now())).toUTCString()
    } else if (id === 'chart_index') { // array of chart items
        return 'chart_index.json';

    } else if (id === 'style_new') {
        return 'style_' + Date.now() + '.html'; // (new Date(Date.now())).toUTCString()
    } else if (id === 'style_index') { // array of style items
        return 'style_index.json';
    } else if (id === 'style_editor') {
        return 'style_editor_selections.json';

    } else if (id === 'config') {
        return 'config.json';

    } else {
        return undefined;
    }
};

ETD.IDB.changeIDToDom = function (id) {

    return id.replace(/.json$/, '_json').
        replace(/.csv$/, '_csv').
        replace(/.png$/, '_png');
};

ETD.IDB.changeIDFromDom = function (id) {

    return id.replace(/_json$/, '.json').
        replace(/_csv$/, '.csv').
        replace(/_png$/, '.png');
};


ETD.SERUWP = { // serialization in uwp app
    mode: 'ser_csv'
    // 'ser_js' - serialize to js object, the same format is used in office add-in;
    // 'ser_csv' - serialize to csv string, the same format is used for chart export; the thumbnail for each chart is stored separately;
};

ETD.SERUWP.serialize = function (id, svg /*:string*/) { // cp. ETD.SER.serialize ()
    // svg - used for chart thumbnails

    var ROWS_IN_SER_ITEM = 10000,
        doc = {},
        first /*:int*/, last /*:int*/, idx;

    if (!ETD.GEN.isUnivWinPlatApp()) {
        return Promise.reject('Error: Serialization not supported.');
    }

    // serialize (csv or json)
    if (ETD.SERUWP.mode === 'ser_csv') {

        return ETD.UWP.putItem(id.replace(/.json$/i, '.csv'), ETD.TABLE.exportX(ETD.SER.mode['csv-winapp-store'], false, true), false);
        // args: mode, filteredRowsOnly, withChartInfo; isJSON;

    } else if (ETD.SERUWP.mode === 'ser_js') {

        // version, timestamp
        doc['version'] = ETD.AFO.VERSION;
        doc['timestamp'] = ETD.AFO.TIMESTAMP;

        // header
        if ($.isArray(ETD.STRUCTS.HEADER)) {
            doc['header'] = ETD.STRUCTS.HEADER;
        }

        // data
        if ($.isArray(ETD.TABLE.data)) {
            for (idx = 0; ; idx++) {
                // storing data items with indexes [idx*ROWS_IN_SER_ITEM, ..., (idx+1)*ROWS_IN_SER_ITEM-1]

                first = idx * ROWS_IN_SER_ITEM;
                if (first >= ETD.TABLE.data.length) {
                    break;
                }
                last = Math.min((idx + 1) * ROWS_IN_SER_ITEM - 1, ETD.TABLE.data.length - 1);
                doc[ETD.SER.getPartName(idx)] = ETD.TABLE.data.slice(first, last + 1);
            }
        }

        // other
        doc['chartdata'] = ETD.SER.serializeChartData(ETD.SER.mode['excel-doc']);
        if (typeof svg === 'string') {
            doc['svg'] = svg;
        }

        // store the doc
        return ETD.UWP.putItem(id, doc, true);
    }
};

ETD.SERUWP.deserialize = function (id, keepLayout /*:boolean*/, ignoreErrorMsg /*:boolean*/, ignoreAddonOffer /*:boolean*/) { // cp. ETD.SER.deserialize ()
     // ignoreAddonOffer - if true, the link for purhasing add-on (in Style folder) is not displayed, eg., the folder remains closed

    if (!ETD.GEN.isUnivWinPlatApp()) {
        return Promise.reject('Error: Serialization not supported.');
    }

    // deserialize (csv or json)
    if (ETD.SERUWP.mode === 'ser_csv') {

        return ETD.UWP.getItem(id).then(

            function (doc) {
                ETD.IMPORT.onSelectDataCsvDataJs({
                    table: {
                        contents: doc
                        //,filename: undefined
                    }
                }, ignoreAddonOffer);
            },
            function (error) {
                if (!ignoreErrorMsg) {
                    ETD.AFO.message(error.toString(), 'error', false);
                    ETD.AFO.message('Error: Could not load the chart.', 'error', true);
                }
                return Promise.reject(error);
            }
        );

    } else if (ETD.SERUWP.mode === 'ser_js') {

        return ETD.UWP.getItem(id).then(

            function (doc) {

                var data /*:array*/, dataComp /*:array*/, chartDataStr /*:string*/, chartData /*:object*/,
                    idx;

                if (typeof doc === 'string') {
                    doc = JSON.parse(doc);
                }

                // version, timestamp
                if (doc.version && doc.timestamp) { // eg., version: '1.8.0.0', timestamp: '150712-2106'
                }

                // reset message, table, chart
                ETD.AFO.message('', 'info', true, 'm-14');
                ETD.TABLE.release();
                ETD.CHART.release();

                ETD.IMPORT.setDataHeader(undefined);
                ETD.TABLE.data = undefined;

                // deserialize data
                idx = 0;
                data = [];
                while ((dataComp = doc[ETD.SER.getPartName(idx++)]) === true) {
                    if ($.isArray(dataComp)) {
                        data = data.concat(dataComp);
                    }
                }
                if (data.length > 0) {
                    ETD.TABLE.data = data;
                }

                // chart data
                chartDataStr = doc['chartdata'];
                chartData = JSON.parse(chartDataStr); // cp. ETD.SER.serializeChartData ()
                ETD.SER.deserializeChartData(chartData, undefined, 'excel-doc', keepLayout, false);

                return Promise.resolve();
            },
            function (error) {
                if (!ignoreErrorMsg) {
                    ETD.AFO.message(error.toString(), 'error', false);
                    ETD.AFO.message('Error: Could not load the chart.', 'error', true);
                }
                return Promise.reject(error);
            }
        );
    }
};


ETD.SER = {
    chartdatabegin: '# ExploreTheData-chart-data: ',
    chartdataend: ' # ExploreTheData-chart-data-end',
    modifiedLevel: 0,
    mode: {
        'csv-file': 1,         // ETD.SER.mode['csv-file']
        'csv-winapp-store': 2, // ETD.SER.mode['csv-winapp-store']
        'excel-doc': 3,        // ETD.SER.mode['excel-doc']
        'excel-worksheet': 4   // ETD.SER.mode['excel-worksheet']
    }
};

ETD.SER.serialize = function (options /*:object*/) {

    var ROWS_IN_SER_ITEM = 10000, // the number of table rows stored in a single item;
        // tests with arrays of, say 400000 string elements, each 10 characters long,
        // show that storing a large array may fail;
        // to avoid the problem, the array is stored in multiple items;

        partName /*:string*/, first /*:int*/, last /*:int*/, inx; /*:int*/

    options = options || {};

    if (ETD.GEN.isUnivWinPlatApp()) { // win app serialization
        ETD.SERUWP.serialize(ETD.IDB.getItemID('chart_current')).then(
            function () { }, // current chart serialized
            function (error) { } // current chart not serialized
        );
        return;
    } else if (!ETD.INIT.isOfficeAddin()) {
        return;
    }

    // serialize to office doc

    // test if modified, depending on the ETD.SER.modifiedLevel status and excel version
    if (!(ETD.SER.modifiedLevel === 1 && !ETD.GEN.isOfficeAddinOnline() || ETD.SER.modifiedLevel === 2)) {
        //if (!((ETD.SER.modifiedLevel === 1) || (ETD.SER.modifiedLevel === 2))) { // this causes too much traffic (test in ie 11)
        return;
    }

    // MS example:
    // Note that Project does not support the settings object.
    // Need to check that the settings object is available before setting.
    /*
    if (!Office.context.document.settings) {

        var unsupportedError = {
            name: "Error: Feature not supported",
            message: "The settings object is not supported in this host application."
        };
        throw unsupportedError;
    } */

    // data
    if (options.data) {

        ETD.AFO.message('D', 'debugX', false);

        // remove old data
        inx = 0;
        while (Office.context.document.settings.get(partName = ETD.SER.getPartName(inx++))) {
            Office.context.document.settings.remove(partName);
        }
        // store header - this is not used in deserialization
        if ($.isArray(ETD.STRUCTS.HEADER)) {
            Office.context.document.settings.set('header', ETD.STRUCTS.HEADER);
        }
        // store data
        if ($.isArray(ETD.TABLE.data)) {
            for (inx = 0; ; inx++) {
                // storing data items with indexes [inx*ROWS_IN_SER_ITEM, ..., (inx+1)*ROWS_IN_SER_ITEM-1]

                first = inx * ROWS_IN_SER_ITEM;
                if (first >= ETD.TABLE.data.length) {
                    break;
                }
                last = Math.min((inx + 1) * ROWS_IN_SER_ITEM - 1, ETD.TABLE.data.length - 1);

                Office.context.document.settings.set(ETD.SER.getPartName(inx),
                    ETD.TABLE.data.slice(first, last + 1));
            }
        }
    }

    // other
    Office.context.document.settings.set('chartdata', ETD.SER.serializeChartData(ETD.SER.mode['excel-doc']));

    // save
    if (options.save) {

        ETD.AFO.message('S' + ETD.SER.modifiedLevel, 'debugX', false);

        Office.context.document.settings.saveAsync(function (asyncResult) {
            if (asyncResult.status === Office.AsyncResultStatus.Failed) {
                ETD.AFO.message('Data and settings save failed. Error: ' + asyncResult.error.message, 'error', true);
            }
        });

        ETD.SER.modifiedLevel = 0;
    }
};

ETD.SER.deserialize = function () { // cp. ETD.SERUWP.deserialize ()

    var obj /*:object*/, inx /*:int*/,
        data /*:array*/, dataX /*:array*/,
        chartDataStr /*:string*/, chartData; /*:object*/

    if (!ETD.INIT.isOfficeAddin()) {
        return;
    }

    // version
    obj = Office.context.document.settings.get('version');
    if (obj && obj.version === ETD.AFO.VERS[0]) { // version '1.4.0.0'
        // obj.timestamp - e.g., '150712-2106'

        return ETD.DESER14.deserialize();
    }

    // reset message, table, chart
    ETD.AFO.message('', 'info', true, 'm-14');
    ETD.TABLE.release();
    ETD.CHART.release();

    ETD.IMPORT.setDataHeader(undefined);
    ETD.TABLE.data = undefined;

    // deserialize data
    inx = 0;
    data = [];
    while ((dataX = Office.context.document.settings.get(ETD.SER.getPartName(inx++))) === true) {
        if ($.isArray(dataX)) {
            data = data.concat(dataX);
        }
    }
    if (data.length > 0) {
        ETD.TABLE.data = data;
    }

    // chart data
    chartDataStr = Office.context.document.settings.get('chartdata');
    chartData = JSON.parse(chartDataStr); // cp. ETD.SER.serializeChartData ()
    ETD.SER.deserializeChartData(chartData, undefined, 'excel-doc', false, false); // bKeepLayout=false, ignoreAddonOffer = false
};

ETD.SER.serializeChartData = function (mode /*:string*/) {

    var headerData /*:object*/, uiData /*:object*/, xmlStr /*:object*/,
        resObj /*:object*/, resStr; /*:string*/
    //oVarsInUse, sRowIdNewName, oRegExpr

    if (mode !== ETD.SER.mode['csv-file'] && mode !== ETD.SER.mode['csv-winapp-store'] && mode !== ETD.SER.mode['excel-doc']) {
        return null;
    }

    // header data
    headerData = ETD.SER.serializeHeaderData(mode);

    // data from ui controls
    uiData = ETD.SER.UI2UIData();

    // style; encode xml string; without encoding errors occur in excel online version;
    xmlStr = {
        name: ETD.STYLE.xmlStr.name,
        xmlstr: encodeURIComponent(ETD.STYLE.xmlStr.xmlstr),
        selections: encodeURIComponent(ETD.STYLE.xmlStr.selections)
    };

    // stringify
    resObj = {
        layout: ETD.LAYOUTER.layouter.getLayout(),
        header: headerData.header,
        uidata: { checkbox: uiData.checkbox, textbox: uiData.textbox, select: uiData.select },
        plotinfo: ETD.STRUCTS.PLOTS,
        plotzorder: ETD.CHART.plotOrder,
        style: xmlStr,
        params: {
            sortedvariable: ETD.TABLE.sortedByVariable,
            sortedincreasing: ETD.TABLE.sortedInIncreasingOrder,
            searchapplied: ETD.TABLE.searchApplied,
            columnselectionwidth: ETD.TABLE.colSelectionWidth
        },
        version: ETD.AFO.VERSION,
        timestamp: ETD.AFO.TIMESTAMP
    };

    // stringify
    resStr = JSON.stringify(resObj);

    // exporting to csv file: if row id is exported, find new name for the variable and replace it
    // changed: row id is never exported; it can not be selected as a chart variable;
    /*
    if (mode !== ETD.SER.mode['csv-file']) {
        oVarsInUse = headerData.variables;
        if (oVarsInUse[ETD.TABLE.rowIDVar]) {

            // find a new variable name for row id; the reason: if the serialized data is imported, row id is added;
            // the new row id is different from the current row id if there is an active search;
            for (idx = 1; ; idx++) {
                sRowIdNewName = ETD.TABLE.rowIDVar + '_' + idx; // e.g., 'svgware_row_id_1'
                if (!oVarsInUse[sRowIdNewName]) {
                    break;
                }
            }

            // set new variable name for row id
            oRegExpr = new RegExp('\\b' + ETD.TABLE.rowIDVar + '\\b', 'mg');
            resStr = resStr.replace(oRegExpr, sRowIdNewName);
        }
    } */

    return resStr;
};

ETD.SER.deserializeChartData = function (chartData /*:object*/, fileName /*:string*/, mode /*:string*/, keepLayout /*:boolean*/, ignoreAddonOffer /*:boolean*/) {
    // ignoreAddonOffer - if true, the link for purhasing add-on (in Style folder) is not displayed, eg., the folder remains closed;

    // mode - 'csv-file', 'excel-doc'

    var UPP = ETD.UPP,
        reason /*:string*/, varStrcts /*:object*/, xmlStr /*:string*/, styleSels /*:object*/, order /*:object*/,
        colSelectWidth /*:int*/, searchApplied /*:boolean*/,
        toLocStorage; /*:boolean*/

    // release table and chart
    ETD.TABLE.release();
    ETD.CHART.release();

    if (!chartData || typeof chartData !== 'object') {
        return;
    }

    if (mode === 'csv-file') {
        reason = 'deserialize-csv';
    } else if (mode === 'excel-doc') {
        reason = 'deserialize-excel';
    } else {
        return;
    }

    // set layout unless it is set in the configuration file or keepLayout is true
    if (keepLayout) {
        ETD.VALID.layoutFromConfig = true;
    }
    if (chartData.layout && !ETD.VALID.layoutFromConfig && !ETD.TABLE.initd) {
        ETD.AFO.setLayouter(chartData.layout.left, chartData.layout.top);
        ETD.AFO.resize();
    }
    ETD.VALID.layoutFromConfig = undefined;

    // header
    varStrcts = ETD.SER.serializedData2VarStructs(chartData.header);
    ETD.IMPORT.setDataHeader(varStrcts.header2);

    // uidata
    if (chartData.uidata) {
        ETD.SER.UIData2UI(chartData.uidata.checkbox, chartData.uidata.textbox, chartData.uidata.select,
            chartData.version, mode);
    }

    // plotinfo
    ETD.STRUCTS.PLOTS = chartData.plotinfo;

    // z-order of plots; it may be changed in ETD.STYLE.processStyleHtml ();
    ETD.CHART.plotOrder = chartData.plotzorder;

    // style
    if (chartData.style) {

        // reset style menu
        ETD.AFO.resetStyleMenu();

        xmlStr = chartData.style.xmlstr;

        // in version 1.7.0.0 (ETD.AFO.VERS[1]), the xml-format style string is sometimes encoded
        // (with encodeURIComponent) and sometimes it is not encoded;
        // (the idea was that the string is encoded in office add-in; now it is encoded always;)
        // search for '<', if it is not found, decode the string;
        if (xmlStr.substr(0, 1000).indexOf('<') < 0) {
            xmlStr = decodeURIComponent(xmlStr);
        }

        // selections made in the style editor
        if (typeof chartData.style.selections === 'string' && chartData.style.selections !== 'undefined') {
            styleSels = JSON.parse(decodeURIComponent(chartData.style.selections));
        } else {
            styleSels = null;
        }

        // apply style
        toLocStorage = false; // 180408 change: do not add style to the storage and style menu if it comes from a data file;
        // only styles imported with a style file are stored;
        // note: also available is 'chartData.style.name';
        ETD.STYLE.processStyleHtml(null, xmlStr, undefined, toLocStorage, { table: false, chart: false, styleeditor: true }, // deserializing
            false, ignoreAddonOffer, styleSels);
    }

    // update the table
    colSelectWidth = 200 * UPP;
    searchApplied = false;
    if (chartData.params) {
        order = { variable: chartData.params.sortedvariable, increasing: chartData.params.sortedincreasing };
        colSelectWidth = chartData.params.columnselectionwidth;
        searchApplied = chartData.params.searchapplied;
    }
    ETD.TABLE.create({
        columns: varStrcts.columns,
        columnSelectionWidth: colSelectWidth,
        order: order
    }, {
            filename: fileName,
            reason: reason,
            searchapplied: searchApplied
        });
};

ETD.SER.UI2UIData = function () {

    var uiDataCB /*:array*/ = [], uiDataTB /*:array*/ = [], uiDataSel /*:array*/ = [], uiData /*:object*/, prop; /*:boolean*/

    // checkboxes
    $('[type=checkbox]').each(function () {
        uiData = { id: $(this).attr('id') };
        prop = $(this).prop('checked');
        if (prop) {
            uiData.checked = prop;
        }
        prop = $(this).prop('disabled');
        if (prop) {
            uiData.disabled = prop;
        }
        uiDataCB.push(uiData);
    });
    // checkbox with id 'idHideChartControls' has been replaced with buttons
    uiData = { id: 'idHideChartControls' };
    if (!ETD.AFO.chartCntrlsVisible) {
        uiData.checked = true;
    }
    uiDataCB.push(uiData);
    ETD.AFO.message('a' + (!uiData.checked ? 1 : 0), 'debugX', false);

    // textboxes
    $('[type=text]').each(function () {
        uiDataTB.push({ id: $(this).attr('id'), value: $(this).val() });
    });

    // drop-down menus
    $('select:not(.cnStyleEditorSel)').each(function () { // exclude select controls in the style editor; an alternative:
        // $('select').not('.cnStyleEditorSel')
        uiDataSel.push({
            id: $(this).attr('id'), value: $(this).val(), text: $(this).find('option').filter(':selected').text()
        });
    });

    return { checkbox: uiDataCB, textbox: uiDataTB, select: uiDataSel };
};

ETD.SER.UIData2UI = function (uiDataCB /*:array*/, uiDataTB /*:array*/, uiDataSel /*:array*/, version /*:string*/, mode /*:string*/) {

    var uiData /*:object*/, oUIC, chartCntrlsVis /*:boolean*/, inx; /*:int*/

    if (!(mode === 'csv-file' || mode === 'excel-doc')) {
        return;
    }

    // prepare cotrols which depend on data set
    ETD.AFO.updateDataDependentMenus();

    // checkboxes;
    // special processing for id 'idHideChartControls': this checkbox has been replaced with +/- buttons;
    chartCntrlsVis = true;
    if ($.isArray(uiDataCB)) {

        for (inx = 0; inx < uiDataCB.length; inx++) {
            uiData = uiDataCB[inx];
            if (uiData.id === 'idRemoveStyle') {
                continue;
            }
            oUIC = $('#' + uiData.id);
            oUIC.prop('checked', !!uiData.checked);
            oUIC.prop('disabled', !!uiData.disabled);
            if (uiData.id === 'idHideChartControls') {
                chartCntrlsVis = !uiData.checked;
            }
        }
    }

    // visibility of the chart controls
    if (!ETD.INIT.isOfficeAddin()) {
        if (!ETD.TABLE.initd) {
            ETD.CHART.hideShowChartControls(!chartCntrlsVis);
        }
    } else { // office add-in
        ETD.CHART.hideShowChartControls(!chartCntrlsVis);
    }

    // textboxes
    if ($.isArray(uiDataTB)) {

        for (inx = 0; inx < uiDataTB.length; inx++) {
            uiData = uiDataTB[inx];
            $('#' + uiData.id).val(uiData.value);
        }
    }

    // drop-down menus
    if ($.isArray(uiDataSel)) {

        for (inx = 0; inx < uiDataSel.length; inx++) {

            uiData = uiDataSel[inx];
            if (typeof uiData.id !== 'string' || uiData.id === '') {
                continue;
            }
            ETD.COMP.chartVarSelection(version, uiData);

            // do not set the menu of data selection and the menu of style selection
            // because the url-s in the menus may not correspond to the deserialized data
            if (uiData.id === 'idSelectData' || uiData.id === 'idSelectStyle' ||
                uiData.id === 'idTouchFriendlyMode' || // these settings are controlled by ETD.UWP.settings
                uiData.id === 'idGraphicalView' ||
                uiData.id === 'idColumnsInScrolling' ||
                uiData.id === 'idMaxDataSymbolCount' ||
                uiData.id === 'idMaxInfotipItemCount' ||
                uiData.id === 'idChangeableZOrder' ||
                uiData.id === 'idSortChartThumbnails') { // in winapp

                continue;
            }

            $('#' + uiData.id).val(uiData.value);
        }
    }

    // store plot range
    ETD.AFO.plotRangeInx = ETD.AFO.getCurrentPlotRange().range;
};

ETD.SER.serializeHeaderData = function (mode /*:string*/) {

    var varsInUse /*:object*/ = {}, header /*:array*/ = [], inx /*:int*/,
        plot /*:object*/, column /*:object*/, inclCol; /*:boolean*/

    if (mode !== ETD.SER.mode['csv-file'] && mode !== ETD.SER.mode['csv-winapp-store'] &&
        mode !== ETD.SER.mode['excel-doc'] && mode !== ETD.SER.mode['excel-worksheet']) {

        return null;
    }

    // find all variables which are currently displayed in the table or in the chart

    // variables in the chart
    if (ETD.STRUCTS.PLOTS && $.isArray(ETD.STRUCTS.PLOTS.plots)) {
        varsInUse[ETD.STRUCTS.PLOTS.xvar] = true;
        for (inx = 0; inx < ETD.STRUCTS.PLOTS.plots.length; inx++) {
            plot = ETD.STRUCTS.PLOTS.plots[inx];
            if (plot && plot.yvar !== '') {
                varsInUse[plot.yvar] = true;
            }
        }
    }

    // iterate over all variables, add those which are displayed in the table
    if ($.isArray(ETD.STRUCTS.COLS)) {
        for (inx = 0; inx < ETD.STRUCTS.COLS.length; inx++) {

            column = ETD.STRUCTS.COLS[inx];

            // do not export row no and row id;
            // row id should be still exported if it is visible in the table or in the chart because the id would be lost otherwise;
            // row no removed from varsInUse below; special handling of the row id in ETD.SER.serializeChartData ();

            // modified:
            // do not add row id; if row id would be selected for x-axis and rows are filtered with search,
            // the row id should be serialized; in this case, after deserializing, there would be 2 variables of row id (old and new);
            // this would cause confusing situations;

            if (mode === ETD.SER.mode['csv-file'] || mode === ETD.SER.mode['csv-winapp-store'] || mode === ETD.SER.mode['excel-doc']) {
                if (column.variable === ETD.TABLE.rowNoVar || column.variable === ETD.TABLE.rowIDVar) {
                    delete varsInUse[column.variable];
                    continue;
                }
            }

            // add column info
            if (mode === ETD.SER.mode['csv-file'] || mode === ETD.SER.mode['excel-worksheet']) {
                inclCol = column.show || !!varsInUse[column.variable];
            } else { // serializing for an excel doc, include the column regardless of whether or not
                // it is shown in the table or used in the chart
                inclCol = true;
            }
            if (inclCol) {
                header[header.length] = {
                    variable: column.variable,
                    text: column.headertext,
                    showintable: !!column.show,
                    rect: column.rect
                };
                varsInUse[column.variable] = true;
            }
        }
    }

    return { header: header, variables: varsInUse };
};

ETD.SER.serializedData2VarStructs = function (header /*:array*/) {

    var col /*:object*/, header2 /*:array*/, columns /*:array*/, inx;

    header2 = [];
    columns = [];
    if ($.isArray(header)) {

        for (inx = 0; inx < header.length; inx++) {
            col = header[inx];
            header2[header2.length] = { variable: col.variable, text: col.text };
            columns[columns.length] = { variable: col.variable, headertext: col.text, show: col.showintable, rect: col.rect };
        }
    }
    return { header2: header2, columns: columns };
};

ETD.SER.setModified = function (level /*:int*/) {
    // level = 1 - modified status: modified if ETD.GEN.isOfficeAddinOnline () returns false;
    // level = 2 - modified status: modified (unconditional);

    if (level === 1 || level === 2) {
        if (ETD.SER.modifiedLevel === 1 || ETD.SER.modifiedLevel === 2) {
            ETD.SER.modifiedLevel = Math.max(ETD.SER.modifiedLevel, level);
        } else {
            ETD.SER.modifiedLevel = level;
        }
    }
};

ETD.SER.getPartName = function (partIndex /*:int*/) {
    return 'data-' + partIndex;
};


// deserialize excel doc with etd ver 1.4

ETD.DESER14 = {
};

ETD.DESER14.deserialize = function () {

    var version /*:string*/ = ETD.AFO.VERS[0], // version '1.4.0.0'
        data /*:array*/, arr /*:array*/, obj /*:object*/,
        uiDataCB /*:array*/, uiDataTB /*:array*/, uiDataSel /*:array*/,
        map /*:object*/,
        columns /*:array*/, colSelW /*:int*/,
        idx; /*:int*/

    // header
    arr = Office.context.document.settings.get('header');
    if ($.isArray(arr) && arr.length > 0 && typeof arr[0] === 'string') {
        ETD.IMPORT.setDataHeader(ETD.TABLE.makeHeader2Struct(arr)); // convert outdated header structure
    }

    // data
    idx = 0;
    data = [];
    while ((arr = Office.context.document.settings.get(ETD.SER.getPartName(idx++))) === true) {
        if ($.isArray(arr)) {
            data = data.concat(arr);
        }
    }
    if (data.length > 0) {
        ETD.TABLE.data = data;
    }

    // checkboxes, textboxes, drop-down menus
    uiDataCB = Office.context.document.settings.get('checkbox');
    uiDataTB = Office.context.document.settings.get('textbox');
    uiDataSel = Office.context.document.settings.get('select');
    // some id-s have been changed; correct the id-s;
    map = {
        'idYAxisP2': 'idYAxis1', 'idYAxisP3': 'idYAxis2', 'idYAxisP4': 'idYAxis3',
        'idVariable1': 'idVariable0', 'idVariable2': 'idVariable1',
        'idVariable3': 'idVariable2', 'idVariable4': 'idVariable3'
    };
    if ($.isArray(uiDataSel)) {
        for (idx = 0; idx < uiDataSel.length; idx++) {
            if (map[uiDataSel[idx].id]) {
                uiDataSel[idx].id = map[uiDataSel[idx].id];
            }
        }
    }
    // row id can not be selected as a plot variable (if version > 1.4); replace with row no;
    if ($.isArray(uiDataSel)) {
        for (idx = 0; idx < uiDataSel.length; idx++) {
            if (uiDataSel[idx].value === ETD.TABLE.rowIDVar &&
                (uiDataSel[idx].id === 'idVariable0' || uiDataSel[idx].id === 'idVariable1' || // new id-s, changed above
                uiDataSel[idx].id === 'idVariable2' || uiDataSel[idx].id === 'idVariable3')) {

                uiDataSel[idx].value = ETD.TABLE.rowNoVar;
            }
        }
    }
    // set selected plot range (the select control was not available in ver 1.4)
    uiDataSel.push({ id: 'idSelectPlots', value: '1' });
    // ui control for switching to the graphical view of the table:
    // in version 1.4 it was a checkbox, now a select control
    $.each(uiDataCB, function (index, oUIC) {
        if (oUIC.id === 'idGraphicalView') {
            uiDataSel.push({
                id: 'idGraphicalView',
                value: oUIC.checked ? '1' : '0'
            });
            return false; // break the loop
        }
    });
    // apply to ui controls
    ETD.SER.UIData2UI(uiDataCB, uiDataTB, uiDataSel, version, 'excel-doc');

    // layout
    obj = Office.context.document.settings.get('layout');
    if (obj) {
        ETD.AFO.setLayouter(obj.left, obj.top);
    }
    ETD.AFO.resize();

    // table columns
    obj = Office.context.document.settings.get('tableLayout');
    if (obj) {
        columns = obj.columns;
        colSelW = obj.columnSelectionWidth;
    }

    // apply default style of version 1.4
    $.ajax({
        url: 'home/custom/etd-style-02.js', // default style for version 1.4
        cache: false,
        dataType: 'script',
        success: function (data, textStatus, jqXHR) {

            // process the style
            ETD.STYLE.processStyleHtml(null, window.STYLE, undefined, false, { table: false, chart: false, styleeditor: true }, true, false);

            // create table, chart
            if ($.isArray(ETD.TABLE.data) && $.isArray(ETD.STRUCTS.HEADER)) {

                ETD.CHART.hideShowChartControls(!ETD.AFO.chartCntrlsVisible);

                ETD.TABLE.create({ // deserialize
                    columns: columns,
                    columnSelectionWidth: colSelW
                }, {
                    reason: 'deserialize-excel',
                    searchapplied: $('#idSearchString').val() === '' ? false : true // not supported in ver 1.4
                });
            } else {
                ETD.AFO.release();
                ETD.AFO.message('Error: File import failed.', 'error', true);
            }
        },
        error: function (jqXHR, textStatus, errorThrown) {

            ETD.AFO.message('Error in loading a style file.', 'error', true);

            ETD.IMPORT.setDataHeader(undefined);
            ETD.TABLE.data = undefined;
        },
        timeout: 60000 // in milliseconds
    });
};


// Ensure Excel documents with a previous version of the app are loadable.

ETD.COMP = {};

// In select controls for chart variables, the option value
// was set to the column header text; now it is set to the variable name.
ETD.COMP.chartVarSelection = function (version /*:string*/, uiChartData /*:object*/) {

    var colSelParents /*:array*/, idx;

    if (version !== ETD.AFO.VERS[0] || !$.isArray(ETD.STRUCTS.HEADER)) {
        return;
    }

    colSelParents = ['idVariable0', 'idVariable1', 'idVariable2', 'idVariable3'];
    if (typeof colSelParents.indexOf !== 'function' || colSelParents.indexOf(uiChartData.id) < 0) {
        return;
    }

    for (idx = 0; idx < ETD.STRUCTS.HEADER.length; idx++) {
        if (uiChartData.value === ETD.STRUCTS.HEADER[idx].text) {
            uiChartData.value = ETD.STRUCTS.HEADER[idx].variable;
        }
    }
};


ETD.IMPORT = {
};

/*
==== 'Import Data' button ====
ETD.IMPORT.onSelectDataCsvDataJs
    ETD.IMPORT.processDataJs                                                   +
    ETD.IMPORT.processDataCsv                                                            +
          
==== 'Import Configuration' button ====
ETD.IMPORT.processDataJsConfigJs                 +
        ETD.IMPORT.processDataJs                                               +
        ETD.AFO.onNewData                                                                          +

==== 'Import Style' button ====
ETD.STYLE.processStyleHtml                                 +
    ETD.AFO.onNewData                                                                              +

==== drag and drop ====
ETD.IMPORT.onDropDataCsvDataJsConfigJsStyleHtml
    ETD.IMPORT.processDataJsConfigJs             +
            ETD.AFO.onNewData                                                                      +
            ETD.IMPORT.processDataJs                                           +
    ETD.STYLE.processStyleHtml                             +
        ETD.AFO.onNewData                                                                          +
    ETD.IMPORT.processDataCsv                                                            +

==== drop down menu for selecting data ====
ETD.IMPORT.onMenuDataCsvDataJs
    ETD.IMPORT.processDataJs                                                   +
    ETD.IMPORT.processDataCsv                                                            +

==== drop down menu for selecting style ====
ETD.STYLE.processStyleHtml                                 +
    ETD.AFO.onNewData                                                                              +

ETD.IMPORT.loadConfigJsAndInit

*/

// Selecting data with the 'Import Data' button.
ETD.IMPORT.onSelectDataCsvDataJs = function (event, ignoreAddonOffer) {
    // event.table.contents - contents of the file;
    // event.table.filename - filename;
    // ignoreAddonOffer - if true, the link for purhasing add-on (in Style folder) is not displayed, eg., the folder remains closed;

    var contents /*:string*/, fileName /*:string*/, withHeader /*:boolean*/, getData; /*:function*/

    contents = event.table.contents;
    fileName = event.table.filename;

    // test if a javascript file
    if (ETD.IMPORT.isJavaScript(fileName)) { // js-file

        // reset data objects
        ETD.IMPORT.setDataHeader(undefined);
        ETD.TABLE.data = undefined;

        getData = new Function('HEADER', 'DATA', contents + 'return { header: HEADER, data: DATA };');
        ETD.IMPORT.processDataJs(false, getData(), fileName);

    } else { // expecting a csv data file

        withHeader = $('#idWithHeader').is(':checked');
        ETD.IMPORT.processDataCsv(contents, fileName, withHeader, ignoreAddonOffer);
    }
};

// Process javascript data file.
ETD.IMPORT.processDataJs = function (keepDataMenu /*:boolean*/, params /*:object*/, fileName /*:string*/) {

    // reset message, table, chart
    ETD.AFO.onNewData(true, true, false, !keepDataMenu, false, 'new-data'); // new js data file

    // test header, data
    params = params || {};
    if (!(typeof params.header === 'object' && $.isArray(params.header) &&
        (typeof params.data === 'string' || typeof params.data === 'object' && $.isArray(params.data)))) {

        ETD.AFO.release();
        ETD.AFO.message('Error: Wrong data file format.', 'error', true);
        return;
    }

    // loaded data is an array of json objects, or
    // loaded data is a js string

    // onready callback for the csv parser
    function onPapaParseReady(results) {

        var rawData /*:array*/, colCnt /*:int*/, rowCnt /*:int*/, row /*:int*/, col /*:int*/,
            item /*:object*/, member; /*:string*/

        ETD.AFO.message('', 'info', true, 'm-09');

        rawData = results.data[0];

        // column count, row count
        colCnt = ETD.STRUCTS.HEADER.length;
        rowCnt = Math.floor(rawData.length / colCnt);

        // load example data, create table;

        ETD.TABLE.data = [];

        for (row = 0; row < rowCnt; row++) {
            item = {};
            for (col = 0; col < colCnt; col++) {
                member = rawData[row * colCnt + col].trim();
                if (member === '') { // ignore leading and trailing white spaces and empty strings
                    continue;
                }
                item[ETD.TABLE.getDefaultVarName(col).name] = member;
            }
            ETD.TABLE.data[ETD.TABLE.data.length] = item;
        }

        // update the table
        ETD.TABLE.create(null, { // select example data
            filename: fileName,
            reason: 'new-data'
        });

    } // ##################################################################################


    // header
    if ($.isArray(params.header) && params.header.length > 0) {
        if (typeof params.header[0] === 'object') {
            ETD.IMPORT.setDataHeader(params.header);
        } else if (typeof params.header[0] === 'string') {
            ETD.IMPORT.setDataHeader(ETD.TABLE.makeHeader2Struct(params.header));
        }
    }

    // data
    if (typeof params.data === 'string') { // a csv string; call the csv parser;
        ETD.GEN.papaparse([params.data], 0, undefined, onPapaParseReady);
    } else if ($.isArray(params.data)) { // an array of json objects;

        ETD.AFO.message('', 'info', true, 'm-10');

        ETD.TABLE.data = params.data;

        // update the table
        ETD.TABLE.create(null, { // select example data
            filename: fileName,
            reason: 'new-data'
        });
    }
};

// Process a comma-separated value (CSV) data file.
ETD.IMPORT.processDataCsv = function (contents /*:string*/, fileName /*:string*/, withHeader /*:boolean*/, ignoreAddonOffer /*:boolean*/) {
    // contents - contents of a CSV file;
    // ignoreAddonOffer - if true, the link for purhasing add-on (in Style folder) is not displayed, eg., the folder remains closed;

    var CHUNK_SIZE = 2 * 1024 * 1024,
        header /*:array*/, aData /*:array*/ = [], chartData /*:object*/, variables /*:array*/,
        colCnt /*:int*/ = 0,
        regExp, match,
        chartDataStr /*:string*/,
        findInx /*:int*/, findInxPrev /*:int*/,
        contAr /*:array*/, cont /*:string*/,
        inx; /*:int*/

    function processLine(results, parser) {

        var dataItem /*:object*/, inx /*:int*/, value; /*:string*/

        // ignore empty lines
        if (results.data.length === 1 && results.data[0].trim() === '') {
            // test: a comment line followed by an empty line;
            return;
        }

        // get the header
        if (!header) {
            if (withHeader) {
                header = results.data;
                for (inx = 0; inx < header.length; inx++) {
                    if (typeof header[inx] === 'string') {
                        header[inx] = header[inx].trim();
                        if (header[inx] === '') {
                            header[inx] = ETD.TABLE.getDefaultVarName(inx).headertext;
                        }
                        // remove surrounding "-marks
                        if (header[inx][0] === '"' && header[inx].slice(-1) === '"') {
                            header[inx] = header[inx].slice(1, -1);
                        }
                    }
                }
                return;
            } else {
                header = [];
            }
        }

        // get the data
        colCnt = Math.max(colCnt, results.data.length);
        variables = variables || [];
        while (variables.length < colCnt) {
            variables[variables.length] = ETD.TABLE.getDefaultVarName(variables.length).name;
        }
        dataItem = {};
        for (inx = 0; inx < results.data.length; inx++) {
            value = results.data[inx].trim();
            // remove surrounding "-marks
            if (value[0] === '"' && value.slice(-1) === '"') {
                value = value.slice(1, -1);
            }
            if (value !== '') { // ignore leading and trailing white spaces and empty strings
                dataItem[variables[inx]] = value;
            }
        }
        // add data item to the array; ignore empty items;
        if (Object.keys(dataItem).length > 0) {
            aData[aData.length] = dataItem;
        }
    }

    function onReady() { // 'Import Data' or drag-and-drop a csv file

        ETD.TABLE.data = aData;

        // update the table and chart
        if (!chartData) {

            ETD.IMPORT.setDataHeader(ETD.TABLE.makeHeader2Struct(header, colCnt));
            ETD.TABLE.create(null, { // process text file
                filename: fileName,
                reason: 'new-data'
            });
        } else {

            ETD.SER.deserializeChartData(chartData, fileName, 'csv-file', false, ignoreAddonOffer); // bKeepLayout = false
        }

        // reset message
        ETD.AFO.message('', 'info', true, 'm-11');
    }
    // ############################################################################################

    // reset message
    ETD.AFO.message('', 'info', true, 'm-12');

    // if the data file is empty or almost empty, an error handler may not be called;
    // however, if ETD.AFO.release () is called here, the chart is not recreated after successful import of a csv data file;
    //ETD.AFO.release();

    if (contents.trim() === '') {
        return;
    }

    // find the chart data string
    findInx = contents.substr(0, 1000).search(ETD.SER.chartdatabegin);
    if (findInx >= 0) {
        regExp = new RegExp(ETD.SER.chartdatabegin + '(.*)' + ETD.SER.chartdataend, 'im');
        match = contents.match(regExp);
        if (match) {
            chartDataStr = match[1];
        }
    }

    // parse the chart data string
    if (chartDataStr) {
        chartData = JSON.parse(chartDataStr); // cp. ETD.SER.serializeChartData ()
        variables = [];
        if ($.isArray(chartData.header)) {
            for (inx = 0; inx < chartData.header.length; inx++) {
                variables[variables.length] = chartData.header[inx].variable;
            }
        }
    }

    // split the text into chunks;
    // in ETD.AFO (excel) this works better for large files
    // (say, with some hundred thousand lines and about 10 columns);
    contAr = [];
    findInxPrev = 0;
    while (true) {

        findInx = contents.indexOf('\n', findInxPrev + CHUNK_SIZE);
        if (findInx >= 0) {
            contAr.push(contents.substring(findInxPrev, findInx));
            findInxPrev = findInx;
        } else {
            cont = contents.substring(findInxPrev).trim();
            if (cont !== '') {
                contAr.push(cont);
            }
            break;
        }
    }

    contents = '';
    /* dbg
    var iTotalL = 0;
    for (var inx = 0; inx < contAr.length; inx++) {
        iTotalL += contAr[inx].length;
    } */

    ETD.IMPORT.setDataHeader(undefined);
    ETD.TABLE.data = undefined;

    // call the parser recursively
    ETD.GEN.papaparse(contAr, 0, processLine, onReady);
};

// Process a dropped file. It may be a CSV data file, a javascript data file, or a custom script.
ETD.IMPORT.onDropDataCsvDataJsConfigJsStyleHtml = function (event) {
    // event.table.contents - contents of the dropped file;
    // event.table.filename - name of the dropped file;

    var contents /*:string*/, fileName /*:string*/, withHeader; /*:boolean*/

    // make sure the style editor is closed;
    // the logic of the style editor does not support dropping files while it is open;
    ETD.UWP.showStyleEditor(false);

    contents = event.table.contents;
    fileName = event.table.filename;

    if (typeof contents !== 'string' || typeof fileName !== 'string') {
        ETD.AFO.message('Error: File import failed.', 'error', true);
        return;
    }

    // find file type, process
    if (ETD.IMPORT.isHTML(fileName)) { // html style file

        ETD.STYLE.processStyleHtml(null, contents, fileName, true, { table: true, chart: true, styleeditor: true }, // html file dropped
            false, false); // isInitialStyle, ignoreAddonOffer

        // the parameter ignoreAddonOffer above is ignored, open the Style folder
        if (ETD.GEN.isUnivWinPlatApp() && ETD.GEN.isFeatureLimitedVer()) {
            ETD.AFO.openStyleFolderOnly();
        }
    } else if (ETD.IMPORT.isJavaScript(fileName)) { // js file (data js (2 versions) or config js file)

        // reset data selection menu
        $('#idSelectData').val('');

        ETD.IMPORT.processDataJsConfigJs(contents, fileName, false);

    } else { // expecting csv data file

        // reset data selection menu
        $('#idSelectData').val('');
        withHeader = $('#idWithHeader').is(':checked');
        ETD.IMPORT.processDataCsv(contents, fileName, withHeader, false);
    }
};

// Process a javascript data file or a custom script.
ETD.IMPORT.processDataJsConfigJs = function (code /*:string*/, fileName /*:string*/, isNewConfig /*:boolean*/) {

    var getConfigOrData /*:function*/, configOrData;

    getConfigOrData = new Function('CONFIG', 'HEADER', 'DATA', code + 'return { config: CONFIG, header: HEADER, data: DATA };');
    configOrData = getConfigOrData();

    if (isNewConfig || configOrData.config) {

        if (ETD.GEN.isFeatureLimitedVer()) {
            if (ETD.GEN.isUnivWinPlatApp()) {

                ETD.AFO.message('Customizing with a script is locked. The add-on will unlock the feature.', 'error', true); // (use the link in the folder "Style")

                // close all input folders except for Style where the add-on can be purchased
                ETD.AFO.openStyleFolderOnly();
            } else {
                ETD.AFO.message('Customizing with a script is not supported in the limited version of ExploreTheData.', 'error', true);
            }
            return;
        }

        if (ETD.VALID.validateConfig(configOrData.config)) {

            ETD.AFO.onNewData(false, false, true, true, true, 'new-config'); // new config file

            // store new config
            ETD.UWP.putItem(ETD.IDB.getItemID('config'), configOrData.config, true); // json type
        }
    } else {

        ETD.IMPORT.processDataJs(false, configOrData, fileName);
    }
};

ETD.IMPORT.onMenuDataCsvDataJs = function (src /*:string*/) {

    var msg /*:string*/, withHeader /*:boolean*/ = $('#idWithHeader').is(':checked');

    ETD.AFO.message('Loading...', 'info', true);

    // load data, create table
    if (ETD.IMPORT.isJavaScript(src)) { // javascript data file

        // reset data objects
        ETD.IMPORT.setDataHeader(undefined);
        ETD.TABLE.data = undefined;

        // get and process the script
        $.ajax({
            url: src,
            cache: false,
            dataType: 'script',
            success: function (data, textStatus, jqXHR) { // data undefined
                ETD.IMPORT.processDataJs(true, { header: HEADER, data: DATA }, undefined);
            },
            error: function (jqXHR, textStatus, errorThrown) {
                ETD.AFO.release();
                if (typeof errorThrown === 'string' && errorThrown !== '' && errorThrown.toLowerCase() !== 'error') {
                    msg = 'Error in loading JavaScript data file "' + src + '" (' + errorThrown + ').';
                } else {
                    msg = 'Error in loading JavaScript data file "' + src + '".';
                }
                // check internet connection
                if (ETD.UWP.detectInternetConnection() === 0) {
                    msg += ' Check internet connection or try again later.';
                }

                ETD.AFO.message(msg, 'error', true);

            },
            complete: function () {
                setTimeout(function () {
                    // reset temp layout flag
                    ETD.VALID.layoutFromConfig = undefined;
                }, 1000);
            },
            timeout: 60000 // in milliseconds
        });
    } else { // csv data file (cross-domain requests fail)

        // get and process the csv file
        $.ajax({
            url: src,
            cache: false,
            dataType: 'text',
            success: function (data) {
                ETD.IMPORT.processDataCsv(data, undefined, withHeader, false);
            },
            error: function (jqXHR, textStatus, errorThrown) {
                ETD.AFO.release();
                if (typeof errorThrown === 'string' && errorThrown !== '') {
                    msg = 'Error in loading CSV data file "' + src + '" (' + errorThrown + ').';
                } else {
                    msg = 'Error in loading CSV data file "' + src + '".';
                }
                // check internet connection
                if (ETD.UWP.detectInternetConnection() === 0) {
                    msg += ' Check internet connection or try again later.';
                }

                ETD.AFO.message(msg, 'error', true);
            },
            complete: function () {
                setTimeout(function () {
                    // reset temp layout flag
                    ETD.VALID.layoutFromConfig = undefined;
                }, 1000);
            },
            timeout: 60000 // in milliseconds
        });
    }
};

// Load a configuration javascript if requested with the url, and initialize the app.
ETD.IMPORT.loadConfigJsAndInit = function () {

    // load style index file, delete unreferenced style files, load style editor selections, and initialize
    function procStyleAndInit() {

        // load style editor selections
        ETD.UWP.getItem(ETD.IDB.getItemID('style_editor')).then(
            function (result) {
                if (typeof result === 'string') {
                    try {
                        ETD.STED.selections = JSON.parse(result);
                    } catch (ex) {
                        ETD.STED.selections = {};
                    }
                }
                return Promise.resolve();
            },
            function () {
                ETD.STED.selections = {};
                return Promise.resolve();
            }).then(

                // load style index file
                function () {
                    return ETD.UWP.getItem(ETD.IDB.getItemID('style_index'));
                }).then(
                    function (result) {
                        if (typeof result === 'string') {
                            try {
                                result = JSON.parse(result);
                            } catch (ex) {
                                result = [];
                            }
                        }
                        if (!$.isArray(result)) {
                            result = [];
                        }
                        return result;
                    },
                    function (error) {
                        return Promise.resolve([]);
                    }).then(

                        // delete unreferenced style files and delete unnecessary objects in the style editor selections
                        function (styleitems) {

                            var map; /*:map*/

                            ETD.STYLE.storedStyleItems = styleitems;

                            // delete unreferenced style files
                            map = {}; // map of style-related files that must be preserved
                            map[ETD.IDB.getItemID('style_index')] = true;
                            map[ETD.IDB.getItemID('style_editor')] = true;
                            $.each(ETD.STYLE.storedStyleItems, function (index, item) {
                                if (item.removed !== ETD.STYLE.REMOVED_STATUS_2) {
                                    map[item.id] = true;
                                }
                            });
                            ETD.UWP.collectCarbage('^style_', map); // assuming that the style files begin with 'style_'

                            // delete unnecessary objects in ETD.STED.selections, save the file
                            map = {}; // map of style titles that must be preserved as keys in the object of style editor selections (ETD.STED.selections);
                            // note that the default style may be absent after importing a configuration file;
                            map[ETD.AFO.defaultStyleTitle] = true;
                            $.each(ETD.STYLE.storedStyleItems, function (index, item) {
                                if (item.removed !== ETD.STYLE.REMOVED_STATUS_2) {
                                    map[item.title] = true;
                                }
                            });
                            Object.keys(ETD.STED.selections).forEach(function (key) {
                                if (!map.hasOwnProperty(key)) {
                                    ETD.AFO.message('Deleting key from style editor selections: "' + key + '".', 'info', false, '');
                                    delete ETD.STED.selections[key];
                                }
                            });
                            ETD.UWP.putItem(ETD.IDB.getItemID('style_editor'), ETD.STED.selections, true); // json type
                            ETD.AFO.message('Style editor keys: ' + Object.keys(ETD.STED.selections), 'info', false);

                            // deserialize settings
                            return ETD.UWP.deserSettings();

                        }).then(

                            // init
                            function () {
                                ETD.AFO.init();
                            },
                            function () {
                                ETD.AFO.init();
                            });
    }

    var queryParams /*:object*/ = $.getQueryParameters(), url; /*:string*/

    // find configuration script url in the query parameters
    if (queryParams && typeof queryParams['etd-config'] === 'string') {
        url = queryParams['etd-config'];
        ETD.AFO.message('Loading configuration script "' + url + '"', 'info', false);
        $.getScript(url, function () {
            if (ETD.VALID.validateConfig()) {
                ETD.AFO.init();
                return;
            }
        });
    } else if (ETD.VALID.validateConfig()) {

        // async loading of style index (only in uwp app), then init
        if (!ETD.GEN.isUnivWinPlatApp()) { // not in univ win platform
            ETD.AFO.init();

        } else { // univ win platform
            // load and apply config script (if available), initialize;
            // note: finally() is not supported in edge;
            ETD.UWP.getItem(ETD.IDB.getItemID('config')).then(

                function (conf) {

                    // load and apply config script
                    try {
                        // parse config
                        if (typeof conf === 'string') {
                            conf = JSON.parse(conf);
                        }
                        // prevent loading default data
                        if (conf && conf.data && $.isArray(conf.data.items)) {
                            $.each(conf.data.items, function (index, item /*:object*/) {
                                if (item['default']) {
                                    item['default'] = false;
                                }
                            });
                        }
                        // validate config, store in ETD.CONFIG
                        if (conf) {
                            ETD.VALID.validateConfig(conf);
                        }
                    } catch (ex) {
                        // empty
                    }
                    procStyleAndInit();
                },
                function () {
                    procStyleAndInit();
                }
            );
        }
    }
};

// Test if the filename refers to a javascript file.
ETD.IMPORT.isJavaScript = function (fileName /*:string*/) {
    if (typeof fileName !== 'string') {
        return false;
    }
    return fileName.search(/.js$/i) >= 0;
};

// Test if the filename refers to a html file.
ETD.IMPORT.isHTML = function (fileName /*:string*/) {
    if (typeof fileName !== 'string') {
        return false;
    }
    return fileName.search(/(.html|.htm)$/i) >= 0;
};

// Test if the filename refers to a json file.
ETD.IMPORT.isJSON = function (fileName /*:string*/) {
    if (typeof fileName !== 'string') {
        return false;
    }
    return fileName.search(/.json$/i) >= 0;
};

ETD.IMPORT.setDataHeader = function (header /*:array*/) {

    ETD.STRUCTS.HEADER = header;
};


ETD.STYLE = {
    xmlStr: { name: undefined, xmlstr: undefined, selections: undefined }, // for serializing
    defPlotCols: [ // default plot colors
        'DarkBlue', 'DarkCyan', 'DarkRed',
        'DarkOrange', 'DarkSlateGray', 'RoyalBlue',
        'DarkOliveGreen', 'SaddleBrown', 'OrangeRed',
        'DimGray', 'CornflowerBlue', 'Green',
        'DarkGoldenrod', 'DarkKhaki', 'SlateGray'],
    defCol: 'silver',
    general: undefined,
    storedStyleItems: undefined, // live copy of the stored array style_index.json, in use if ETD.GEN.isUnivWinPlatApp() returns true;
    // [{ id:, title:, removed: },...] (removed: 0 - default, 1 - marked to be removed, 2 - removed from the drop down menu)
    REMOVED_STATUS_0: 0,
    REMOVED_STATUS_1: 1,
    REMOVED_STATUS_2: 2,

    resizable: 'resizable',

    // the style editor
    styleEditorData: null // see ETD.STED.reset (), ETD.STED.initStyleEditor () and the call in ETD.STYLE.processStyleHtml ()
    //{
    //    id: undefined,
    //    title: undefined,
    //    style: undefined, // entire style source, see change event handler for cnStyleEditorSel
    //    selections: undefined,
    //    $chartDefs: undefined,
    //    $tableDefs: undefined
    //}
};

ETD.STYLE.processStyleHtml = function (xml /*:object*/, htmlStr /*:string*/, styleName /*:string*/, storeStyle /*:boolean*/,
    update /*:map*/, isInitialStyle /*:boolean*/, ignoreAddonOffer /*:boolean*/, styleEditorSels /*:object*/) {

    // update - { table: /*:boolean*/, chart: /*:boolean*/, styleeditor: /*:boolean*/ }
    // ignoreAddonOffer - if true, the link for purhasing add-on (in Style folder) is not displayed, eg., the folder remains closed;

    // opening the Style folder is annoying
    ignoreAddonOffer = true;

    // converting the style:
    // 1. convert from jQuery xml document to string
    //    encodeURIComponent(ETD.GEN.serializeToString($xml[0]).replace(/\s+/mg, ' '));
    // 2. convert from string to jQuery xml document
    //    $($.parseXML(decodeURIComponent(htmlStrEnc)))

    var $xml, $chartDefs, $tableDefs, htmlStrEnc, htmlstr2, $xml4Srch;

    // check if feature limited version or full version
    if (!isInitialStyle && ETD.GEN.isFeatureLimitedVer()) {
        if (ETD.GEN.isUnivWinPlatApp()) {

            ETD.AFO.message('Styling is not enabled. The add-on will unlock the feature.', 'error', true); // (use the link in the folder "Style")

            // close all input folders except for Style where the add-on can be purchased
            if (!ignoreAddonOffer) {
                ETD.AFO.openStyleFolderOnly();
            }
        } else {
            ETD.AFO.message('Styling is not supported in the limited version of ExploreTheData.', 'error', true);
        }
        return;
    }

    // exactly one of xml or htmlStr must be defined
    if ((!xml || htmlStr) && (xml || !htmlStr)) {
        ETD.AFO.message('Error in processing the style: Exactly one of xml or htmlStr must be defined.', 'error', false);
        return;
    }

    $xml = $(xml || $.parseXML(htmlStr));
    if (typeof htmlStr !== 'string' || htmlStr.trim() === '') {
        htmlStr = ETD.GEN.serializeToString($xml[0]).replace(/\s+/mg, ' ');
    }
    htmlStrEnc = encodeURIComponent(htmlStr);

    // workaround for ie (can't find items in the parsed xml document;
    // the issue appears in ie-11 with jQuery-3.4.1, does not occur with jQuery-3.3.1;)
    if (ETD.GEN.isIE()) {
        htmlstr2 = htmlStr.slice(htmlStr.search(/<html/gi));
        $xml4Srch = $($.parseXML('<wrapper>' + htmlstr2 + '</wrapper>'));
    } else {
        $xml4Srch = $xml;
    }

    // find defs element for the table and chart
    $chartDefs = $xml.find('#chartDefs');
    if ($chartDefs.length !== 1 || $chartDefs.prop('tagName') !== 'defs') {
        ETD.AFO.message('SVG defs element with id="chartDefs" not found in the style file.', 'error', true);
        return;
    }
    $tableDefs = $xml.find('#tableDefs');
    if ($tableDefs.length !== 1 || $tableDefs.prop('tagName') !== 'defs') {
        ETD.AFO.message('SVG defs element with id="tableDefs" not found in the style file.', 'error', true);
        return;
    }

    // init the style editor and continue
    if (update.styleeditor) {
        ETD.UWP.initStyleEditor({
            id: ETD.IDB.getItemID('style_new'),
            title: styleName,
            style: htmlStrEnc,
            $chartDefs: $chartDefs,
            $tableDefs: $tableDefs
        });
    }
    ETD.STYLE.processStyleHtmlImpl($xml, $xml4Srch, $chartDefs, $tableDefs, htmlStr, styleName, storeStyle, update, styleEditorSels);
};

ETD.STYLE.processStyleHtmlImpl = function ($xml, $xml4Srch, $chartDefs, $tableDefs, htmlStr /*:string*/,
    styleName /*:string*/, storeStyle /*:boolean*/, update /*:map*/, styleEditorSels /*:object*/) {

    // update - { table: /*:boolean*/, chart: /*:boolean*/ }

    // ================
    function procDefItem(item) {

        var result, key, keyLC;

        result = {};
        for (key in item) {
            keyLC = key.toLowerCase();
            if (keyLC === 'tagname' || keyLC === 'id') {
                continue;
            } else if (keyLC === 'x' || keyLC === 'y' || keyLC === 'width' || keyLC === 'height' || keyLC === 'rx' || keyLC === 'ry'
                || keyLC === 'stroke-width' || keyLC === 'stroke-opacity' || keyLC === 'fill-opacity') {
                result[keyLC] = parseFloat(item[key]);
            } else {
                result[keyLC] = item[key];
            }
        }
        return result;
    }

    function cloneObject(object) {

        var result, idx, key;

        if (typeof object !== 'object' || !object) {
            return object;
        }

        if ($.isArray(object)) { // an array
            result = [];
            for (idx = 0; idx < object.length; idx++) {
                result.push(cloneObject(object[idx]));
            }
            return result;
        } else { // an object
            result = {};
            key = undefined;
            for (key in object) {
                result[key] = cloneObject(object[key]);
            }
        }
        return result;
    }

    function getChartColor(styleItem /*:object*/) {

        if (typeof styleItem !== 'object' || !styleItem) {
            return undefined;
        }
        if (styleItem.fill && styleItem.fill !== 'none') {
            return styleItem.fill;
        }
        if (styleItem.stroke && styleItem.stroke !== 'none') {
            return styleItem.stroke;
        }
    } // ================

    var UPP = ETD.UPP, // 10 units = 1 px
        locStorageItem /*:string*/,
        defs /*:string*/, $plot,
        chartStyle /*:object*/, tableStyle /*:object*/, generalStyle /*:object*/,
        plotInx /*:int*/, plotNo /*:int*/,
        styleItem /*:object*/, color /*:string*/,
        plot2Errbar, plotCols /*:array*/,
        withSymbol /*:boolean*/, withLine /*:boolean*/, withArea /*:boolean*/,
        idTD /*:string*/, stedPath /*:string*/,
        defItem /*:object*/, idItem /*:string*/, tag /*:string*/,
        length /*:number*/, width /*:number*/, padding /*:number*/, margin /*:number*/,
        catInx /*:int*/, cat /*:string*/,
        matches /*:array*/, index;

    // find a name for the local storage item; if present, remove the existing item from the local storage;
    // if processing succeeds, the item is strored below;
    // remove all items:
    //window['localStorage'].clear();
    if (typeof styleName === 'string') {
        locStorageItem = 'style:' + styleName.trim().replace(/.htm[l]$/i, ''); // remove styleName extension
    } else {
        //styleName = 'Imported style.html'; // commented out 181102
        locStorageItem = 'style:Imported style';
    }
    if (storeStyle && ETD.GEN.storageAvailable('localStorage')) {
        window['localStorage'].removeItem(locStorageItem);
    }

    // style editor selections
    if (!styleEditorSels) {
        if (ETD.STYLE.styleEditorData) {
            styleEditorSels = ETD.STYLE.styleEditorData.selections;
        }
    }
    if (!styleEditorSels) {
        styleEditorSels = {};
    }

    // process style items
    try {

        // chart style
        chartStyle = {};
        defs = '';
        $.each(['rect', 'line', 'linearGradient', 'filter'], function (indexInArray, value) {
            $chartDefs.find(value).each(function (indexInArray2, value2) {
                defs += ETD.GEN.serializeToString($(value2).get(0));
            });
        });
        if (defs !== '') {
            chartStyle['defs'] = { xml: '<defs>' + defs + '</defs>' };
        }

        // plot style items ('curve1', 'curve2', 'curve3',...)
        plot2Errbar = {};
        plotCols = [];
        for (plotInx = 0; plotInx < ETD.CHART.maxNumberOfPlots; plotInx++) { // loop over plots

            plotNo = plotInx + 1;
            styleItem = null;

            // default plot color (specified below)
            plotCols[plotInx] = ETD.STYLE.defPlotCols[plotInx];

            // find tbody element of the plot
            $plot = $xml4Srch.find('#plot-' + plotNo);
            if ($plot.length === 0) {
                if (!ETD.GEN.isUnivWinPlatApp()) {
                    continue; // style items for the plot are not found, default style is used
                } else { // the default style may be modified in the style editor
                }
            } else if ($plot.length > 1) {
                ETD.AFO.message('Multiple elements found with the selector "#plot-' + plotNo + '" while processing the style file.', 'warning', true);
                continue;
            }

            // data symbol
            idTD = '.plot-symbol';
            stedPath = 'plot-' + plotNo + '-plot-symbol'; // path in the style editor
            defItem = ETD.VALID.getDefItemAttrs($plot, idTD, $chartDefs, styleEditorSels[stedPath]);
            if (defItem) {
                tag = defItem['tagName'].toLowerCase();
                if (tag === 'rect' || tag === 'circle' || tag === 'ellipse' || tag === 'polygon' || tag === 'image') {
                    styleItem = styleItem || {};
                    styleItem[tag] = procDefItem(defItem);
                }
            }

            // line plot
            idTD = '.plot-line';
            stedPath = 'plot-' + plotNo + '-plot-line'; // path in the style editor
            defItem = ETD.VALID.getDefItemAttrs($plot, idTD, $chartDefs, styleEditorSels[stedPath]);
            if (defItem) {
                tag = defItem['tagName'].toLowerCase();
                if (tag === 'path') {
                    styleItem = styleItem || {};
                    styleItem['path'] = procDefItem(defItem);
                }
            }

            // area plot
            idTD = '.plot-area';
            stedPath = 'plot-' + plotNo + '-plot-area'; // path in the style editor
            defItem = ETD.VALID.getDefItemAttrs($plot, idTD, $chartDefs, styleEditorSels[stedPath]);
            if (defItem) {
                if (typeof defItem === 'object') {
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'polygon') {
                        styleItem = styleItem || {};
                        styleItem['area'] = procDefItem(defItem);
                    }
                } else if (typeof defItem === 'string') {
                    styleItem = styleItem || {};
                    styleItem['area'] = {
                        'fill': defItem, 'fill-opacity': '1', 'stroke': 'none', 'shape-rendering': 'geometricPrecision'
                    };
                }
            }

            // unresolved data
            // unresolved data could be defined in the style table:
            //<tr>
            //    <td>Unresolved data</td>
            //    <td><span>id="rect" or color (fill)</span></td> <!-- acceptable values -->
            //        <td class='plot-unresolved'>id = "plotUnresolved-1"</td> <!-- changeable value, unchangeable class name -->
            //</tr>
            // however, for the sake of simplicity, the item is removed from the style table and the unresolved data style is defined with the
            // characteristic color (below)
            idTD = '.plot-unresolved';
            defItem = ETD.VALID.getDefItemAttrs($plot, idTD, $chartDefs);
            if (defItem) {
                if (typeof defItem === 'object') {
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'rect') {
                        styleItem = styleItem || {};
                        styleItem['unresolvedData'] = procDefItem(defItem);
                    }
                } else if (typeof defItem === 'string') {
                    styleItem = styleItem || {};
                    styleItem['unresolvedData'] = {
                        'fill': defItem, 'fill-opacity': '1', 'stroke': 'none', 'shape-rendering': 'geometricPrecision'
                    };
                }
            }

            // error bar
            idTD = '.plot-errorbar';
            stedPath = 'plot-' + plotNo + '-plot-errorbar'; // path in the style editor
            defItem = ETD.VALID.getDefItemAttrs($plot, idTD, $chartDefs, styleEditorSels[stedPath]);
            if (defItem) {
                if (typeof defItem === 'object') {
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'line') {
                        plot2Errbar[plotInx] = procDefItem(defItem);
                    }
                }
            }

            // characteristic color
            color = undefined;
            // characteristic color defined in the table
            idTD = '.plot-color';
            defItem = ETD.VALID.getDefItemAttrs($plot, idTD);
            if (defItem) {
                if (typeof defItem === 'string') {
                    color = defItem;
                }
            }
            // instead, find the characteristic color from symbol or line plot
            if (!color && styleItem) {
                color = getChartColor(styleItem.rect) || getChartColor(styleItem.circle) || getChartColor(styleItem.ellipse) || getChartColor(styleItem.polygon) ||
                    getChartColor(styleItem.path); // line plot
            }
            if (color) {
                plotCols[plotInx] = color; // characteristic color
                if (!styleItem['unresolvedData']) { // unresolved data
                    styleItem['unresolvedData'] = {
                        'fill': color, 'fill-opacity': '0.2', 'stroke': 'none', 'shape-rendering': 'crispEdges'
                    };
                }
            }

            if (styleItem) {
                chartStyle['curve' + plotNo] = styleItem;
            }
        }

        // axis title font ('axisTitleX', 'axisTitleY1', 'axisTitleY2', 'axisTitleY3')
        // scale font ('scaleX', 'scaleY1', 'scaleY2', 'scaleY3')
        $.each([
            { td: 'chart-axis-title', items: ['axisTitleX', 'axisTitleY1', 'axisTitleY2', 'axisTitleY3'] },
            { td: 'chart-axis-title-x', items: ['axisTitleX'] },
            { td: 'chart-axis-title-y1', items: ['axisTitleY1'] },
            { td: 'chart-axis-title-y2', items: ['axisTitleY2'] },
            { td: 'chart-axis-title-y3', items: ['axisTitleY3'] },
            { td: 'chart-scale', items: ['scaleX', 'scaleY1', 'scaleY2', 'scaleY3'] },
            { td: 'chart-scale-x', items: ['scaleX'] },
            { td: 'chart-scale-y1', items: ['scaleY1'] },
            { td: 'chart-scale-y2', items: ['scaleY2'] },
            { td: 'chart-scale-y3', items: ['scaleY3'] },
            { td: 'chart-legend-text', items: ['legendText'] }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $chartDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'text') {
                        defItem = procDefItem(defItem);
                        $.each(value.items, function (indexInArray2, value2) {
                            chartStyle[value2] = { 'text': defItem };
                        });
                    }
                } else if (typeof defItem === 'string' && defItem.toLowerCase() === 'none') {
                    $.each(value.items, function (indexInArray2, value2) {
                        chartStyle[value2] = null;
                    });
                }
            });

        // vertical gridlines, horizontal gridlines
        $.each([
            { td: 'chart-vertical-gridline', items: ['gridlinesVertical', 'gridlinesVertical2'] },
            { td: 'chart-vertical-gridline-2', items: ['gridlinesVertical2'] },
            { td: 'chart-horizontal-gridline', items: ['gridlinesHorizontal', 'gridlinesHorizontal2'] },
            { td: 'chart-horizontal-gridline-2', items: ['gridlinesHorizontal2'] }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $chartDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    idItem = defItem.id;
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'line') {
                        defItem = procDefItem(defItem);
                        $.each(value.items, function (indexInArray2, value2) {
                            chartStyle[value2] = { 'use': { 'href': '#' + idItem } };
                        });
                    }
                } else if (typeof defItem === 'string' && defItem.toLowerCase() === 'none') {
                    $.each(value.items, function (indexInArray2, value2) {
                        chartStyle[value2] = null;
                    });
                }
            });

        // tick marks
        for (catInx = 1; catInx <= 3; catInx++) {

            cat = '';
            if (catInx >= 2) {
                cat += catInx;
            }

            $.each([
                { td: 'chart-ticks-' + catInx, items: ['ticksBottom' + cat, 'ticksLeft' + cat, 'ticksTop' + cat, 'ticksRight' + cat] },
                { td: 'chart-ticks-bottom-' + catInx, items: ['ticksBottom' + cat] },
                { td: 'chart-ticks-left-' + catInx, items: ['ticksLeft' + cat] },
                { td: 'chart-ticks-top-' + catInx, items: ['ticksTop' + cat] },
                { td: 'chart-ticks-right-' + catInx, items: ['ticksRight' + cat] }],

                function (indexInArray, value) {
                    defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $chartDefs, styleEditorSels[value['td']]);
                    if (typeof defItem === 'object') {
                        idItem = defItem.id;
                        tag = defItem['tagName'].toLowerCase();
                        if (tag === 'line') {
                            defItem = procDefItem(defItem);
                            $.each(value.items, function (indexInArray2, value2) {
                                chartStyle[value2] = { 'use': { 'href': '#' + idItem } };
                            });
                        }
                    } else if (typeof defItem === 'string' && defItem.toLowerCase() === 'none') {
                        $.each(value.items, function (indexInArray2, value2) {
                            chartStyle[value2] = null;
                        });
                    }
                });

            // length of tick marks, outside;
            // length of tick marks, inside;
            $.each([
                { td: 'chart-ticks-length-outside-' + catInx, items: ['ticksBottom' + cat, 'ticksLeft' + cat, 'ticksTop' + cat, 'ticksRight' + cat], subitem: 'lengthOut' },
                { td: 'chart-ticks-bottom-length-outside-' + catInx, items: ['ticksBottom' + cat], subitem: 'lengthOut' },
                { td: 'chart-ticks-left-length-outside-' + catInx, items: ['ticksLeft' + cat], subitem: 'lengthOut' },
                { td: 'chart-ticks-top-length-outside-' + catInx, items: ['ticksTop' + cat], subitem: 'lengthOut' },
                { td: 'chart-ticks-right-length-outside-' + catInx, items: ['ticksRight' + cat], subitem: 'lengthOut' },
                { td: 'chart-ticks-length-inside-' + catInx, items: ['ticksBottom' + cat, 'ticksLeft' + cat, 'ticksTop' + cat, 'ticksRight' + cat], subitem: 'lengthIn' },
                { td: 'chart-ticks-bottom-length-inside-' + catInx, items: ['ticksBottom' + cat], subitem: 'lengthIn' },
                { td: 'chart-ticks-left-length-inside-' + catInx, items: ['ticksLeft' + cat], subitem: 'lengthIn' },
                { td: 'chart-ticks-top-length-inside-' + catInx, items: ['ticksTop' + cat], subitem: 'lengthIn' },
                { td: 'chart-ticks-right-length-inside-' + catInx, items: ['ticksRight' + cat], subitem: 'lengthIn' }],

                function (indexInArray, value) {
                    length = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], null, styleEditorSels[value['td']]);
                    if (typeof length === 'string') {
                        length = length.replace('px', '').trim();
                        length = parseFloat(length);
                        if (!isNaN(length)) {
                            $.each(value.items, function (indexInArray2, value2) {
                                if (chartStyle[value2]) { // the object should be defined when defining the tick mark style (above);
                                    // if the object is not defined, ignore the tick marks length;
                                    chartStyle[value2][value.subitem] = UPP * length;
                                }
                            });
                        }
                    }
                });
        }

        // scrollbar
        $.each([
            { td: 'chart-scrollbar-track', items: ['track'] },
            { td: 'chart-scrollbar-thumb', items: ['thumb'] }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $chartDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    idItem = defItem.id;
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'rect') {
                        defItem = procDefItem(defItem);
                        $.each(value.items, function (indexInArray2, value2) {
                            if (!chartStyle['scrollbar']) {
                                chartStyle['scrollbar'] = {};
                            }
                            chartStyle['scrollbar'][value2] = { 'use': { 'href': '#' + idItem } };
                        });
                    }
                }
            });
        // scrollbar width
        $.each([
            { td: 'chart-scrollbar-width', items: ['scrollbar'], subitem: 'scrollbar-width-nontouchdevice' },
            { td: 'chart-scrollbar-width-touchdevice', items: ['scrollbar'], subitem: 'scrollbar-width-touchdevice' }],

            function (indexInArray, value) {
                width = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], null, styleEditorSels[value['td']]);
                if (typeof width === 'string') {
                    width = parseFloat(width);
                    if (!isNaN(width)) {
                        $.each(value.items, function (indexInArray2, value2) {
                            if (chartStyle[value2]) {
                                chartStyle[value2][value.subitem] = UPP * width;
                            }
                        });
                    }
                }
            });

        // chart area, plot area
        $.each([
            { td: 'chart-area', items: ['chartArea'] },
            { td: 'plot-area', items: ['plotArea'] }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $chartDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    idItem = defItem.id;
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'rect') {
                        defItem = procDefItem(defItem);
                        $.each(value.items, function (indexInArray2, value2) {
                            chartStyle[value2] = { 'use': { 'href': '#' + idItem } };
                        });
                    }
                }
            });

        // plot area bottom, left, top or right border line style
        $.each([
            { td: 'plot-area-bottom', items: ['plotAreaBottom'] },
            { td: 'plot-area-left', items: ['plotAreaLeft'] },
            { td: 'plot-area-top', items: ['plotAreaTop'] },
            { td: 'plot-area-right', items: ['plotAreaRight'] }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $chartDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    idItem = defItem.id;
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'line') {
                        defItem = procDefItem(defItem);
                        $.each(value.items, function (indexInArray2, value2) {
                            chartStyle[value2] = { 'use': { 'href': '#' + idItem } };
                        });
                    }
                } else if (typeof defItem === 'string' && defItem.toLowerCase() === 'none') {
                    $.each(value.items, function (indexInArray2, value2) {
                        chartStyle[value2] = null;
                    });
                }
            });

        // plot area padding
        $.each([
            { td: 'plot-area-padding-bottom', items: ['bottom'] },
            { td: 'plot-area-padding-left', items: ['left'] },
            { td: 'plot-area-padding-top', items: ['top'] },
            { td: 'plot-area-padding-right', items: ['right'] }],

            function (indexInArray, value) {
                padding = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], null, styleEditorSels[value['td']]);
                if (typeof padding === 'string') {
                    padding = padding.replace('px', '').trim();
                    padding = parseFloat(padding);
                    if (!isNaN(padding)) {
                        $.each(value.items, function (indexInArray2, value2) {
                            if (!chartStyle['plotAreaPadding']) {
                                chartStyle['plotAreaPadding'] = { left: 0, top: 0, right: 0, bottom: 0 };
                            }
                            chartStyle['plotAreaPadding'][value2] = UPP * padding;
                        });
                    }
                }
            });

        // plot area margin; only bottom margin is in use;
        $.each([
            { td: 'plot-area-margin-bottom', items: ['bottom'] },
            { td: 'plot-area-margin-left', items: ['left'] },
            { td: 'plot-area-margin-top', items: ['top'] },
            { td: 'plot-area-margin-right', items: ['right'] }],

            function (indexInArray, value) {
                margin = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], null, styleEditorSels[value['td']]);
                if (typeof margin === 'string') {
                    margin = margin.replace('px', '').trim();
                    margin = parseFloat(margin);
                    if (!isNaN(margin)) {
                        $.each(value.items, function (indexInArray2, value2) {
                            if (!chartStyle['plotAreaMargin']) {
                                chartStyle['plotAreaMargin'] = { left: undefined, top: undefined, right: undefined, bottom: undefined };
                            }
                            chartStyle['plotAreaMargin'][value2] = UPP * margin;
                        });
                    }
                }
            });

        // processing indicator
        // Note that also supported is:
        //    tableStyle['processingIndicator']['indicator'] = [null | image], e.g.,
        //    tableStyle['processingIndicator']['indicator'] = { image: { href:'lib/res/processing-indicator-1.gif', width: 40, height: 40 } }
        $.each([
            { td: 'chart-processing-indicator', items: ['processingIndicator'] }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $chartDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    idItem = defItem.id;
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'rect') {
                        defItem = procDefItem(defItem);
                        $.each(value.items, function (indexInArray2, value2) {
                            if (!chartStyle[value2]) {
                                chartStyle[value2] = {};
                            }
                            chartStyle[value2]['cover'] = { 'use': { 'href': '#' + idItem } };
                        });
                    }
                } else if (typeof defItem === 'string' && defItem.toLowerCase() === 'none') {
                    $.each(value.items, function (indexInArray2, value2) {
                        chartStyle[value2] = null;
                    });
                }
            });

        // table style
        tableStyle = {};
        defs = '';
        $.each(['rect', 'line', 'linearGradient', 'filter'], function (indexInArray, value) {
            $tableDefs.find(value).each(function (indexInArray2, value2) {
                defs += ETD.GEN.serializeToString($(value2).get(0)) + '\n';
            });
        });
        if (defs !== '') {
            tableStyle['defs'] = { xml: '<defs>' + defs + '</defs>' };
        }

        // Note that also supported is:
        //    tableStyle['processingIndicator']['indicator'] = [null | image], e.g.,
        //    tableStyle['processingIndicator']['indicator'] = { image: { href:'lib/res/processing-indicator-1.gif', width: 40, height: 40 } }

        // multiple style items
        $.each([
            { td: 'table-background', items: ['tableBackground'], allowed: { rect: true } },
            { td: 'table-column-highlight', items: ['columnHighlight'], allowed: { rect: true } },
            { td: 'table-row-highlight', items: ['rowHighlight'], allowed: { rect: true } },
            { td: 'table-row-selection', items: ['rowSelection'], allowed: { rect: true } },
            { td: 'table-text-highlight', items: ['textHighlight'], allowed: { rect: true } },
            { td: 'table-draggable-splitter', items: ['dragElement'], allowed: { rect: true } },
            { td: 'table-processing-indicator', items: ['processingIndicator'], subitem: 'cover', allowed: { rect: true, none: true } },
            { td: 'table-truncated-text', items: ['truncatedTextMark'], allowed: { circle: true, none: true } },
            { td: 'table-header-text', items: ['headerText'], allowed: { text: true } },
            { td: 'table-body-text', items: ['bodyText'], allowed: { text: true } },
            { td: 'table-vertical-gridline', items: ['gridlinesVertical'], allowed: { line: true } },
            { td: 'table-horizontal-gridline', items: ['gridlinesHorizontal'], allowed: { line: true } },
            { td: 'table-splitter', items: ['splitter'], allowed: { line: true } },
            { td: 'table-graphical-view-highlight', items: ['intervalHighlight'], allowed: { line: true } }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $tableDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    tag = defItem['tagName'].toLowerCase();
                    if (value.allowed[tag]) {
                        defItem = procDefItem(defItem);
                        $.each(value.items, function (indexInArray2, value2) {
                            if (typeof value.subitem !== 'string') {
                                tableStyle[value2] = {};
                                tableStyle[value2][tag] = defItem;
                            } else {
                                tableStyle[value2] = {};
                                tableStyle[value2][value.subitem] = {};
                                tableStyle[value2][value.subitem][tag] = defItem;
                            }
                        });
                    }
                } else if (typeof defItem === 'string' && defItem.toLowerCase() === 'none' && value.allowed['none']) {
                    $.each(value.items, function (indexInArray2, value2) {
                        if (typeof value.subitem !== 'string') {
                            tableStyle[value2] = null;
                        } else {
                            tableStyle[value2] = {};
                            tableStyle[value2][value.subitem] = null;
                        }
                    });
                }
            });

        // style items supporting an arrary of 2 items
        $.each([
            { td: 'table-column-background-1', items: ['columnBackground'], allowed: { rect: true } },
            { td: 'table-column-background-2', items: ['columnBackground'], allowed: { rect: true } },
            { td: 'table-header-background-1', items: ['headerBackground'], allowed: { rect: true } },
            { td: 'table-header-background-2', items: ['headerBackground'], allowed: { rect: true } },
            { td: 'table-row-background-1', items: ['rowBackground'], allowed: { rect: true } },
            { td: 'table-row-background-2', items: ['rowBackground'], allowed: { rect: true } },
            { td: 'table-graphical-view-1', items: ['previewPlot'], allowed: { polygon: true } },
            { td: 'table-graphical-view-2', items: ['previewPlot'], allowed: { polygon: true } }],

            function (indexInArray, value) {

                // index of the item
                matches = value['td'].match(/-([0-9]+$)/i);
                index = 0;
                if (matches && matches.length >= 2) {
                    index = parseInt(matches[1]) - 1; // convert to 0-based index
                }

                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $tableDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    tag = defItem['tagName'].toLowerCase();
                    if (value.allowed[tag]) {
                        defItem = procDefItem(defItem);
                        $.each(value.items, function (indexInArray2, value2) {
                            tableStyle[value2] = tableStyle[value2] || { items: [] };
                            while (index + 1 > tableStyle[value2].items.length) {
                                tableStyle[value2]['items'].push({});
                                tableStyle[value2]['items'][tableStyle[value2]['items'].length - 1][tag] = defItem;
                            }
                        });
                    }
                }
            });

        // header cell padding; body cell padding;
        $.each([
            { td: 'table-header-padding-bottom', items: ['headerCellPadding'], subitem: 'bottom' },
            { td: 'table-header-padding-left', items: ['headerCellPadding'], subitem: 'left' },
            { td: 'table-header-padding-top', items: ['headerCellPadding'], subitem: 'top' },
            //{ td: 'table-header-padding-right', items: ['headerCellPadding'], subitem: 'right' }, // not in use
            { td: 'table-body-padding-bottom', items: ['cellPadding'], subitem: 'bottom' },
            { td: 'table-body-padding-left', items: ['cellPadding'], subitem: 'left' },
            { td: 'table-body-padding-top', items: ['cellPadding'], subitem: 'top' },
            { td: 'table-body-padding-right', items: ['cellPadding'], subitem: 'right' }],

            function (indexInArray, value) {
                padding = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], null, styleEditorSels[value['td']]);
                if (typeof padding === 'string') {
                    padding = parseFloat(padding);
                    if (!isNaN(padding)) {
                        $.each(value.items, function (indexInArray2, value2) {
                            if (!tableStyle[value2]) {
                                tableStyle[value2] = { left: 0, top: 0, right: 0, bottom: 0 };
                            }
                            tableStyle[value2][value.subitem] = UPP * padding;
                        });
                    }
                }
            });

        // scrollbar
        $.each([
            { td: 'table-scrollbar-track', items: ['scrollbar'], subitem: 'track' },
            { td: 'table-scrollbar-thumb', items: ['scrollbar'], subitem: 'thumb' }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $tableDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    idItem = defItem.id;
                    tag = defItem['tagName'].toLowerCase();
                    if (tag === 'rect') {
                        defItem = procDefItem(defItem);
                        $.each(value.items, function (indexInArray2, value2) {
                            if (!tableStyle[value2]) {
                                tableStyle[value2] = {};
                            }
                            tableStyle[value2][value.subitem] = { 'use': { 'href': '#' + idItem } };
                        });
                    }
                }
            });
        // scrollbar width
        $.each([
            { td: 'table-scrollbar-width', items: ['scrollbar'], subitem: 'scrollbar-width-nontouchdevice' },
            { td: 'table-scrollbar-width-touchdevice', items: ['scrollbar'], subitem: 'scrollbar-width-touchdevice' }],

            function (indexInArray, value) {
                width = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], null, styleEditorSels[value['td']]);
                if (typeof width === 'string') {
                    width = parseFloat(width);
                    if (!isNaN(width)) {
                        $.each(value.items, function (indexInArray2, value2) {
                            if (tableStyle[value2]) {
                                tableStyle[value2][value.subitem] = UPP * width;
                            }
                        });
                    }
                }
            });

        // general style
        generalStyle = { 'plotColors': plotCols, 'skin': ETD.STYLE.getDefaultSkinColors() };
        $.each([
            { td: 'skin-background-color', items: ['backgroundColor'] },
            { td: 'skin-background-color-2', items: ['backgroundColor2'] },
            { td: 'skin-text-color', items: ['textColor'] },
            { td: 'skin-text-color-2', items: ['textColor2'] },
            { td: 'skin-text-color-3', items: ['textColorTopLink'] }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td']);
                if (typeof defItem === 'string' && defItem !== 'default' && defItem !== 'none') {
                    $.each(value.items, function (indexInArray2, value2) {
                        generalStyle['skin'][value2] = defItem;
                    });
                }
            });

        // chart width and height, in pixels; if defined, the size of the chart is fixed;
        // this may be useful for exporting the chart in the SVG format;
        $.each([
            { td: 'chart-width', subitem: 'chartWidth' },
            { td: 'chart-height', subitem: 'chartHeight' }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], null, styleEditorSels[value['td']]);
                if (typeof defItem === 'string') {

                    generalStyle[value.subitem] = undefined;
                    if (defItem === ETD.STYLE.resizable) {
                        generalStyle[value.subitem] = ''; // meaning 'resizable'
                    } else {
                        var fX = defItem;
                        fX = fX.replace('px', '').trim();
                        fX = parseFloat(fX);
                        if (!isNaN(fX)) {
                            generalStyle[value.subitem] = fX;
                        }
                    }
                }
            });

        // selected data mark (circles around the selected data in the chart);
        // fill of the data symbols at the mouse location (the number of data symbols which are changed at the mouse location
        // depends on the value selected in the drop down menu 'Maximum number of items in the infotip');
        $.each([
            { td: 'chart-selected-data-mark', subitem: 'selectedDataCircle', allowed: { circle: true, none: true } },
            { td: 'chart-hot-data-fill', subitem: 'nearestDataFill', allowed: { rect: true, none: true } }],

            function (indexInArray, value) {
                defItem = ETD.VALID.getDefItemAttrs($xml4Srch, value['td'], $chartDefs, styleEditorSels[value['td']]);
                if (typeof defItem === 'object') {
                    tag = defItem['tagName'].toLowerCase();
                    if (value.allowed[tag]) {
                        defItem = procDefItem(defItem);
                        generalStyle[value.subitem] = defItem; // data structure differs from the others above (tag is missing)
                    }
                } else if (typeof defItem === 'string' && defItem.toLowerCase() === 'none' && value.allowed['none']) {
                    generalStyle[value.subitem] = null;
                }
            });

        // chart type - a string optionally set in the style file, may be used in the chart.ondraw callback
        generalStyle['chartType'] = '';
        defItem = ETD.VALID.getDefItemAttrs($xml4Srch, 'chart-type');
        if (typeof defItem === 'string') {
            generalStyle['chartType'] = defItem;
        }

        // hide web page header;
        // this item is not shown in the example style files;
        // better to control the visibility of page header from the configuration file;
        generalStyle['hideHeader'] = 0;
        defItem = ETD.VALID.getDefItemAttrs($xml4Srch, 'skin-hide-header');
        if (typeof defItem === 'string') {
            generalStyle['skin']['hideHeader'] = defItem;
        }

        // validate style
        ETD.VALID.validateStyle(chartStyle, tableStyle, generalStyle);
        ETD.STYLE.general = generalStyle;

        // helper: is an errorbar plot
        ETD.STYLE.isErrorbarPlot = function (iPlotIndex) {
            return !!plot2Errbar[iPlotIndex];
        };

        // helper: get the chart type
        ETD.STYLE.getChartType = function () {
            return generalStyle['chartType'];
        };

        // chart style callback
        ETD.STYLE.chart = function (plots /*:array*/) {
            // plots -- array prepared in ETD.CHART.collectInfoAndCreate();
            // cp. ETD.STRUCTS.PLOTS.plots;

            var touchDevice = ETD.AFO.touchFriendlyMode,
                style, styleItem,
                columns /*:array*/, color /*:string*/,
                plotInx, plotNo, plot /*:object*/,
                variable /*:string*/, iE, key /*:string*/,
                plotNo2ZIndex /*:map*/,
                newPlotOrder /*:array*/, mergedPlotOrder; /*:array*/

            // clone the style object
            style = cloneObject(chartStyle);

            // modify style settings which depend on ui controls (curve style, plot area padding)

            // curves (plots)
            plotNo2ZIndex = {};
            for (plotInx = 0; plotInx < Math.min(ETD.STRUCTS.PLOTS.plots.length, ETD.CHART.maxNumberOfPlots); plotInx++) { // loop over plots

                plotNo = plotInx + 1;
                plot = ETD.STRUCTS.PLOTS.plots[plotInx];
                if (!plot) {
                    continue;
                }

                withSymbol = plot.symbol;
                withLine = plot.line;
                withArea = plot.area;

                styleItem = style['curve' + plotNo] || {};

                columns = ETD.STYLE.defPlotCols;
                if (plotInx < columns.length) {
                    color = columns[plotInx];
                } else {
                    color = 'black';
                }

                if (withSymbol) {
                    if (!(styleItem.rect || styleItem.circle || styleItem.ellipse || styleItem.polygon || styleItem.image)) {
                        styleItem['circle'] = { 'r': 2.5 * UPP, 'stroke': color, 'stroke-width': UPP, 'stroke-opacity': '0.8', 'fill': color, 'fill-opacity': 0.4, 'shape-rendering': 'geometricPrecision', 'pointer-events': 'visible' };
                    }
                    if (!styleItem.unresolvedData) {
                        styleItem['unresolvedData'] = { 'fill': color, 'fill-opacity': '0.2', 'shape-rendering': 'crispEdges' };
                    }
                } else {
                    delete styleItem['rect'];
                    delete styleItem['circle'];
                    delete styleItem['ellipse'];
                    delete styleItem['polygon'];
                    delete styleItem['image'];
                    delete styleItem['unresolvedData'];
                }
                if (withLine) {
                    if (!styleItem.path) {
                        styleItem['path'] = { 'stroke': color, 'stroke-width': UPP, 'fill': 'none', 'shape-rendering': 'geometricPrecision' };
                    }
                } else {
                    delete styleItem['path'];
                }
                if (withArea) {
                    if (!styleItem.area) {
                        styleItem['area'] = { 'fill': color, 'fill-opacity': '0.25' };
                    }
                } else {
                    delete styleItem['area'];
                }

                style['curve' + plotNo] = styleItem;

                // store preliminary info on the plot order
                if (typeof ETD.STRUCTS.PLOTS.xvar === 'string' && ETD.STRUCTS.PLOTS.xvar !== '' &&
                    typeof plot.yvar === 'string' && plot.yvar !== '' && (withSymbol || withLine || withArea)) {

                    plotNo2ZIndex[plotNo] = 3 * plotNo; // 3 - leaving room for the order numbers of the error bar plots
                }
            }


            // error bars
            $.each(plot2Errbar, function (plotInx /*:int*/, errBar /*:object*/) {

                plotInx = parseInt(plotInx);
                plotNo = plotInx + 1;

                // if the plot is not defined, do not add the error bars to the next 2 plots
                if (!($.isArray(plots) && plots.length >= plotInx + 1 && typeof plots[plotInx] === 'object' && plots[plotInx])) {
                    return true;
                }
                if (isNaN(plotNo2ZIndex[plotNo])) {
                    return true;
                }

                // style object of the plot
                styleItem = style['curve' + plotNo];

                // variable name to which the error bars of the 2 next plots are drawn
                variable = plots[plotInx].y1 || plots[plotInx].y2 || plots[plotInx].y3;

                // add the bar style to the style object of the next 2 plots
                for (iE = 1; iE <= 2; iE++) {

                    if (isNaN(plotNo2ZIndex[plotNo + iE])) {
                        continue;
                    }

                    styleItem = style['curve' + (plotNo + iE)];
                    if (!styleItem) {
                        continue;
                    }
                    styleItem['bar'] = { toVariable: variable, line: errBar };
                    style['curve' + (plotNo + iE)] = styleItem;

                    // make sure the z-index of the plots of the error bars is smaller than that of the main plot
                    plotNo2ZIndex[plotNo + iE] = plotNo2ZIndex[plotNo] - iE;
                }
            });

            // find the order of plots by merging previous plot order with the info collected above

            // new plot order (without input from the previous plot order)
            newPlotOrder = [];
            for (key in plotNo2ZIndex) {
                plotNo = parseInt(key);
                newPlotOrder.push({ plotno: plotNo, zindicator: plotNo2ZIndex[key] });
            }
            newPlotOrder.sort(function (oP1, oP2) {
                return oP1.zindicator - oP2.zindicator; // increasing order
            });
            $.each(newPlotOrder, function (index, obj) {
                newPlotOrder[index] = obj.plotno;
            });
            // newPlotOrder - a new plot order without input from the previous plot order

            // merge newPlotOrder with the previous plot order ETD.CHART.plotOrder

            // get the previoius plot order as an array (probably always an array)
            if (typeof ETD.CHART.plotOrder === 'string') {
                ETD.CHART.plotOrder = ETD.CHART.plotOrder.split(',');
            }
            ETD.CHART.plotOrder = ETD.CHART.plotOrder || [];
            // add new plots in the same order as they appeared in the previous order
            mergedPlotOrder = [];
            $.each(ETD.CHART.plotOrder, function (inderx, plotno) {
                if ($.isNumeric(plotNo2ZIndex[plotno])) {
                    mergedPlotOrder.push(plotno);
                }
            });
            // add new plots that are not yet added
            $.each(newPlotOrder, function (index, plotno) {
                if (mergedPlotOrder.indexOf(plotno) >= 0) { // already present
                    return true;
                }
                mergedPlotOrder.push(plotno);
            });
            ETD.CHART.plotOrder = mergedPlotOrder;

            // plot area padding
            if (style['plotAreaPadding']) {
                if (!$('#idPaddingX').prop('checked')) {
                    style['plotAreaPadding'].left = 0;
                    style['plotAreaPadding'].right = 0;
                }
                if (!$('#idPaddingY').prop('checked')) {
                    style['plotAreaPadding'].bottom = 0;
                    style['plotAreaPadding'].top = 0;
                }
            }

            // scrollbar width
            style['scrollbar']['width'] = !touchDevice ? style['scrollbar']['scrollbar-width-nontouchdevice'] :
                style['scrollbar']['scrollbar-width-touchdevice'];
            delete style['scrollbar']['scrollbar-width-nontouchdevice'];
            delete style['scrollbar']['scrollbar-width-touchdevice'];

            style['touchFriendlyStyle'] = touchDevice;

            return style;
        };

        // table style callback
        ETD.STYLE.table = function () {

            var touchDevice /*:boolean*/ = ETD.AFO.touchFriendlyMode,
                style; /*:object*/

            // clone the style object
            style = cloneObject(tableStyle);

            // table margin
            style['tableMargin'] = { 'left': 10, 'top': 20, 'right': 20, 'bottom': 30 };

            // scrollbar width
            style['scrollbar']['width'] = !touchDevice ? style['scrollbar']['scrollbar-width-nontouchdevice'] :
                style['scrollbar']['scrollbar-width-touchdevice'];
            delete style['scrollbar']['scrollbar-width-nontouchdevice'];
            delete style['scrollbar']['scrollbar-width-touchdevice'];

            style['touchFriendlyStyle'] = touchDevice;

            return style;
        };

        // apply style
        $('.cnColors1').css({ 'background-color': generalStyle['skin']['backgroundColor'] });
        $('.cnColors2').css({ 'background-color': generalStyle['skin']['backgroundColor2'] });
        $('.cnColors1').css({ 'color': generalStyle['skin']['textColor'] });
        $('.cnColors1 a').css({ 'color': generalStyle['skin']['textColor'] });
        $('.cnColors2').css({ 'color': generalStyle['skin']['textColor2'] });
        if (!ETD.GEN.isUnivWinPlatApp()) {
            $('.cnMessageBox').css({ 'background-color': generalStyle['skin']['backgroundColor2'] });
        } else {
            $('.cnMessageBox').css({ 'background-color': 'white' });
        }
        // main links on the top pane (ExploreTheData, Help)
        $('#idTop').find('a').css({ 'color': generalStyle['skin']['textColor2'] });
        $('#idTop').find('span').css({ 'color': generalStyle['skin']['textColor2'] });
        $('#idTop').css({ 'display': !generalStyle['skin']['hideHeader'] ? 'block' : 'none' });
        $('.cnHeadBtnTxtSel').css({ 'border-bottom': '2px solid ' + generalStyle['skin']['textColor2'] });
        $('.cnTopLink').find('a').css({ 'color': generalStyle['skin']['textColorTopLink'] });
        $('#idLegend01C').css({ 'border': 'solid 2px', 'border-color': generalStyle['skin']['backgroundColor'] });

        if (ETD.INIT.isOfficeAddin()) {
            $('body').css({ 'visibility': 'visible' });
            $('table#idTopLayoutImpExp').css({ 'visibility': 'visible' });
            $('table#idTopLayoutStyle').css({ 'visibility': 'visible' });
            $('table#idTopLayoutAxes').css({ 'visibility': 'visible' });
            $('table#idTopLayoutSettings').css({ 'visibility': 'visible' });
        }

        // update
        if (update.table && ETD.TABLE.exists()) { // update table and chart
            SVGware.table.draw(ETD.TABLE.id, { data: null, config: null, style: ETD.STYLE.table() }, {
                reason: update.chart ? 'new-style' : 'new-table-style'
            });
        } else if (update.chart) { // update chart
            ETD.AFO.resize(); // resize as the style may specify the chart dimensions
            ETD.CHART.update(); // in ETD.STYLE.processStyleHtmlImpl;
        }

        // keep the style string and selections made in the style editor (for serializing)
        ETD.STYLE.xmlStr = {
            name: styleName,
            xmlstr: ETD.GEN.serializeToString($xml[0]).replace(/\s+/mg, ' '),
            selections: JSON.stringify(styleEditorSels) // selections made in the style editor
        };

        // store the style in the local storage or in the uwp app's storage
        (function () {

            var styleid, styleitems;

            if (storeStyle && ETD.CONFIG.settings.useLocalStorageForStyle) {

                // store style
                if (!ETD.GEN.isUnivWinPlatApp()) { // not in uwp app

                    // store style to local storage;
                    // 181123: considered storing encoded text in the local storage;
                    // however, because in the win app it is better to store original text content without encoding, do the same here;
                    if (ETD.GEN.storageAvailable('localStorage')) {
                        window['localStorage'].setItem(locStorageItem, htmlStr);
                        // update style menu
                        ETD.AFO.initStyleMenu('localstorage:' + locStorageItem);
                    }

                } else { // uwp app

                    if (ETD.STYLE.styleEditorData.id) {

                        styleid = ETD.STYLE.styleEditorData.id;

                        ETD.UWP.putItem(styleid, htmlStr);

                        // update style index
                        styleitems = ETD.STYLE.storedStyleItems || [];
                        styleitems = $.grep(styleitems, function (item, index) { // remove items with the same name
                            return item.title !== styleName;
                        });
                        // add new item
                        styleitems.push({ id: styleid, title: styleName });
                        // store
                        ETD.UWP.putItem(ETD.IDB.getItemID('style_index'), styleitems, true); // json type
                        ETD.STYLE.storedStyleItems = styleitems;
                        // update style menu
                        ETD.AFO.initStyleMenu('appdir:' + styleid);
                    }
                }
            }
        })();

        // reset message
        ETD.AFO.message('', 'info', true, 'm-08');
    } catch (oEx) {

        // update style menu because the local storage item was removed
        ETD.AFO.initStyleMenu();

        ETD.AFO.message('Error: Failed to parse the style file.', 'error', true);
    }
};

ETD.STYLE.getDefaultSkinColors = function () {

    var genStyle = { skin: {} };

    if (ETD.INIT.isOfficeAddin()) { // set default values

        // excel
        genStyle['skin']['backgroundColor'] = '#439467'; // 'skin-background-color' in style file; #439467 - secondary color for excel     'skin-background-color'
        genStyle['skin']['backgroundColor2'] = '#d3f0e0'; // 'skin-background-color-2' in style file; #d3f0e0 - light color for excel
        genStyle['skin']['textColorTopLink'] = '#217346'; // 'skin-background-color-3' in style file;

        // powerpoint
        if (ETD.GEN.isOfficeAddinHostPowerPoint()) {
            // some colors measured from powerpoint screenshot: #a92c1a, #b8462b, #fbcdb6
            genStyle['skin']['backgroundColor'] = '#b8462b'; // 'skin-background-color' in style file;
            genStyle['skin']['backgroundColor2'] = '#fbcdb6'; // 'skin-background-color-2' in style file;
            genStyle['skin']['textColorTopLink'] = '#a92c1a'; // 'skin-background-color-3' in style file;
        }

        genStyle['skin']['textColor'] = 'white'; // 'skin-text-color' in style file

    } else if (ETD.GEN.isUnivWinPlatApp()) {

        // universal windows platform (win 10) app
        genStyle['skin']['backgroundColor'] = '#0080ff';
        genStyle['skin']['backgroundColor2'] = '#ceecf5';
        genStyle['skin']['textColorTopLink'] = '#217346';

        genStyle['skin']['textColor'] = '#ffffff';

    } else {
        genStyle['skin']['backgroundColor'] = '#a9c3cf'; // 'skin-background-color' in style file;
        genStyle['skin']['backgroundColor2'] = '#dde7ec'; // 'skin-background-color-2' in style file;
        genStyle['skin']['textColor'] = '#414d4b'; // '#4d5b58'; // 'skin-text-color' in style file;
    }

    genStyle['skin']['textColor2'] = '#414d4b'; // '#4d5b58'; // 'skin-text-color-2' in style file;

    return genStyle['skin'];
};


ETD.EVT = {};

ETD.EVT.addReadDataEventHandler = function () {

    // 'Read Data' button
    $('#idReadData').click(function (event) {

        // reset message, table, chart
        ETD.AFO.onNewData(true, true, false, true, false, 'new-data'); // 'Read Data' button

        // try to read selected data
        Office.context.document.getSelectedDataAsync(
            'matrix',
            //{ valueFormat: Office.ValueFormat.Unformatted },
            { valueFormat: Office.ValueFormat.Formatted },
            function (asyncResult) {

                var withHeader /*:boolean*/,
                    colCnt /*:int*/, iRow /*:int*/, iCol /*:int*/,
                    item /*:object*/, member; /*:string*/

                withHeader = $('#idWithHeader2').prop('checked');

                if (asyncResult.status === 'failed') {
                    ETD.AFO.release();
                    ETD.AFO.message('Error: ' + asyncResult.error.message, 'error', true);
                } else {
                    if (withHeader) {
                        ETD.IMPORT.setDataHeader(ETD.TABLE.makeHeader2Struct(asyncResult.value[0]));
                    } else {
                        ETD.IMPORT.setDataHeader(ETD.TABLE.makeHeader2Struct(null, asyncResult.value[0].length));
                    }
                    ETD.TABLE.data = [];
                    colCnt = asyncResult.value[0].length;

                    for (iRow = withHeader ? 1 : 0; iRow < asyncResult.value.length; iRow++) {
                        item = {};
                        for (iCol = 0; iCol < colCnt; iCol++) {
                            member = asyncResult.value[iRow][iCol];
                            if (typeof member === 'string') {
                                member = member.trim();
                                if (member === '') { // ignore leading and trailing white spaces and empty strings
                                    continue;
                                }
                            }
                            item[ETD.TABLE.getDefaultVarName(iCol).name] = member;
                        }
                        ETD.TABLE.data[ETD.TABLE.data.length] = item;
                    }

                    if (ETD.TABLE.data.length === 0) {
                        ETD.AFO.release();
                        ETD.AFO.message('Error: The requested data set is too small.', 'error', true);
                        return;
                    }

                    // update the table
                    ETD.TABLE.create(null, {
                        reason: 'new-data'
                    }); // read data from excel
                }
            });
    });
};

ETD.EVT.addWriteDataEventHandler = function () {

    // 'Write Data' button
    $('#idWriteData').click(function (event) {

        var data /*:array*/, exportAllRows; /*:boolean*/

        ETD.AFO.message('', 'info', true, 'm-01');

        exportAllRows = $('#idExportAllRows2').prop('checked');
        data = ETD.TABLE.exportX(ETD.SER.mode['excel-worksheet'], !exportAllRows);
        if (!$.isArray(data)) {
            ETD.AFO.message('The set operation failed because there is no data available in the table.', 'error', true);
            return;
        }

        Office.context.document.setSelectedDataAsync(
            data, { coercionType: Office.CoercionType.Matrix },
            function (asyncResult) {
                var oError = asyncResult.error;
                if (asyncResult.status === Office.AsyncResultStatus.Failed) {
                    ETD.AFO.message(oError.name + ': ' + oError.message, 'error', true);
                }
            });
    });
};

ETD.EVT.addImportDataEventHandler = function () {

    // 'Import Data' button
    $('#idImportData').click(function (event) {
        $('#jfilestyle-1').trigger('click');
    });
    $('#jfilestyle-1').bind('change', function (event) {

        var fileReader, files, filename /*:string*/, contents; /*:string*/

        // if the value of the input control is an empty string, return immediately; this is a workaround for ie: below the value is set to
        // an empty string to ensure the event fires even if the same file is selected multiple times;
        if ($('#jfilestyle-1').val() === '') {
            return;
        }

        // reset message, table, chart
        ETD.AFO.onNewData(true, true, false, true, false, 'new-data'); // 'Import Data' button

        try {
            fileReader = new FileReader(); // FileReader API not supported in <ie-10, <safari-6
            fileReader.addEventListener('loadend', function (event) {

                // event.target - FileReader
                try {

                    var oError = event.target.error;
                    if (oError) {

                        ETD.AFO.release();

                        // an error occurs sometimes in chrome/ios with the error code error.NOT_FOUND_ERR;
                        // error codes:
                        //   error.NOT_FOUND_ERR    1
                        //   error.SECURITY_ERR     2
                        //   error.ABORT_ERR        3
                        //   error.NOT_READABLE_ERR 4
                        //   error.ENCODING_ERR     5
                        ETD.AFO.message('Error: The data import failed (error code ' + oError.code + ').', 'error', true);
                        return;
                    }

                    // contents of the file
                    contents = event.target.result;

                    // reset the value of the file selector, otherwise the event is not fired when selecting the same file next time
                    $('#jfilestyle-1').val('');

                    if (!contents) { // onedrive fails sometimes
                        throw "data import failed";
                    }

                    ETD.IMPORT.onSelectDataCsvDataJs({
                        table: {
                            contents: contents, // contents of the file
                            filename: filename // filename
                        }
                    }, false); // ignoreAddonOffer
                } catch (oEx) {
                    ETD.AFO.release();
                    ETD.AFO.message('Error: Data import failed.', 'error', true);
                }
            }, false);

            files = event.target.files; // FileList object
            filename = files[0].name;
            fileReader.readAsText(files[0]);
        } catch (oEx) {
            ETD.AFO.release();
            ETD.AFO.message('Error: Data import failed.', 'error', true);
        }
    });
};

ETD.EVT.addExportCSVEventHandler = function () {

    // 'Export CSV' button
    $('#idExportCSV').click(function (event) {

        var withChartInfo /*:boolean*/, exportAllRows /*:boolean*/,
            contents /*:string*/, type; /*:string*/

        ETD.AFO.message('', 'info', true, 'm-02');

        exportAllRows = $('#idExportAllRows').prop('checked');
        withChartInfo = $('#idWithOptions').prop('checked');
        contents = ETD.TABLE.exportX(ETD.SER.mode['csv-file'], !exportAllRows, withChartInfo);

        if (!ETD.GEN.isUnivWinPlatApp() || typeof Windows === 'undefined') { // not in univ win platform

            // open 'Save as' dialog and export to a file
            type = 'text/plain';
            if (typeof document.characterSet === 'string') {
                type += ';charset=' + document.characterSet;
            }

            try {
                if (typeof saveAs !== 'undefined') {
                    saveAs(new Blob([contents], { type: type }), 'table.csv');
                    // waiting indicator remains (firefox; probably a firefox issue);
                } else { // ie9
                    ETD.GEN.saveAsIE9(contents, 'table.txt');
                }
            } catch (oEx) {
                // empty
            }

        } else { // univ win platform
            ETD.UWP.exportTextFile(contents, ['.csv'], 'table');
        }
    });
};

ETD.EVT.addExportChartEventHandler = function () {

    // 'Export Chart' button
    $('#idExportSVG').click(function (event) {

        var saveSVG /*:boolean*/, openSVG /*:boolean*/, savePNG /*:boolean*/,
            svg /*:string*/, type /*:string*/,
            width /*:int*/, height /*:int*/,
            domImg, domCnv, context;

        ETD.AFO.message('', 'info', true, 'm-03');

        if (!ETD.CHART.exists()) {
            ETD.AFO.message('Error: The export failed because the chart does not exist.', 'error', true);
            return;
        }

        // chart export options
        saveSVG = $('#idSaveSVG').prop('checked');
        openSVG = $('#idOpenSVG').prop('checked');
        savePNG = $('#idSavePNG').prop('checked');
        if (!(saveSVG || openSVG || savePNG)) { // here in excel AFO
            saveSVG = true;
            $('#idSaveSVG').prop('checked', true);
        }

        // get svg string
        svg = ETD.GEN.getSVG(ETD.CHART.id);
        if (typeof svg !== 'string' || svg === '') {
            ETD.AFO.message('Error: Chart export failed.', 'error', true);
            return;
        }

        // open 'Save as' dialog and export to a svg-file
        if (saveSVG) {

            if (!ETD.GEN.isUnivWinPlatApp() || typeof Windows === 'undefined') { // not in univ win platform

                type = 'text/plain';
                if (typeof document.characterSet === 'string') {
                    type += ';charset=' + document.characterSet;
                }

                try {
                    if (typeof saveAs !== 'undefined') {
                        saveAs(new Blob([svg], { type: type }), 'chart.svg');
                    } else { // ie9
                        ETD.GEN.saveAsIE9(svg, 'chart.svg');
                    }
                } catch (oEx) {
                    ETD.AFO.message('Error: Chart export failed.', 'error', true);
                }
            } else { // univ win platform
                ETD.UWP.exportTextFile(svg, ['.svg'], 'chart');
            }
        }

        // open window with svg chart
        if (openSVG) {
            window.open('data:image/svg+xml;base64,' + window.btoa(unescape(encodeURIComponent(svg))));
        }

        // create and save binary image
        if (savePNG) {

            width = $('#' + ETD.CHART.id).width();
            height = $('#' + ETD.CHART.id).height();

            // exported chart as image
            domImg = $('#idImg').get(0);
            $(domImg).css({ 'width': width, 'height': height });
            $(domImg).attr('src', 'data:image/svg+xml;base64,' + window.btoa(unescape(encodeURIComponent(svg))));

            // canvas
            domCnv = $('#idCnv').get(0);
            domCnv.width = width; // set canvas dimensions for testing
            domCnv.height = height;
            context = domCnv.getContext('2d');
            if (context) {
                setTimeout(function () { // seems that it may take some time before the context is ready
                    // draw the image
                    context.drawImage(domImg, 0, 0);
                    // save the canvas
                    try {
                        domCnv.toBlob(function (blob) {
                            saveAs(blob, 'chart.png');
                            $(domImg).css({ 'width': 0, 'height': 0 });
                        });
                    } catch (oEx) {
                        ETD.AFO.message('Error: Exporting chart as a binary image failed.', 'error', true); // e.g., ie, safari (win)
                    }
                }, 100);
            }
        }
    });
};

ETD.EVT.addSelectDataEventHandler = function () {

    // data selected in the drop down menu
    $('#idSelectData').change(function (event) {

        var val;

        // reset message, table, chart
        ETD.AFO.onNewData(true, true, false, false, false, 'new-data'); // select data from drop down menu

        val = $(this).val();
        if (val === '') {
            return;
        }

        // get the data file, process
        ETD.IMPORT.onMenuDataCsvDataJs(val);
    });
};

ETD.EVT.addImportConfigEventHandler = function () {

    // 'Import Configuration' button
    $('#idImportConfig').click(function (event) {
        $('#jfilestyle-0').trigger('click');
    });
    $('#jfilestyle-0').bind('change', function (event) {

        var fileReader, dataTransfer, files, contents /*:string*/, fileName; /*:string*/

        // if the value of the input control is an empty string, return immediately; this is a workaround for ie: below the value is set to
        // an empty string to ensure the event fires even if the same file is selected multiple times;
        if ($('#jfilestyle-0').val() === '') {
            return;
        }

        // reset message
        ETD.AFO.message('', 'info', true, 'm-04');

        event.preventDefault();

        try {
            fileReader = new FileReader(); // FileReader API not supported in <ie-10, <safari-6
            fileReader.addEventListener('loadend', function (event) {

                // event.target - FileReader
                try {

                    var oError = event.target.error;
                    if (oError) {

                        // an error occurs sometimes in chrome/ios with the error code error.NOT_FOUND_ERR;
                        // error codes:
                        //   error.NOT_FOUND_ERR    1
                        //   error.SECURITY_ERR     2
                        //   error.ABORT_ERR        3
                        //   error.NOT_READABLE_ERR 4
                        //   error.ENCODING_ERR     5
                        ETD.AFO.message('Error: The script import failed (error code ' + oError.code + ').', 'error', true);
                        return;
                    }

                    // contents of the file
                    contents = event.target.result;

                    // reset the value of the file selector, otherwise the event is not fired when selecting the same file next time
                    $('#jfilestyle-0').val('');

                    if (!contents) { // onedrive fails sometimes
                        throw "script import failed";
                    }

                    ETD.IMPORT.processDataJsConfigJs(contents, fileName, true);
                } catch (oEx) {
                    ETD.AFO.message('Script import failed.', 'error', true);
                }
            }, false);

            dataTransfer = event.dataTransfer; // DataTransfer object
            if (dataTransfer) { // drag and drop a file into a target container
                files = dataTransfer.files; // FileList object
            } else { // opening a csv file with file selector
                files = event.target.files; // FileList object
            }
            if (!files || files.length <= 0) {
                return;
            }
            fileName = files[0].name;
            fileReader.readAsText(files[0]);

        } catch (oEx) {
            ETD.AFO.message('Script import failed.', 'error', true);
        }
    });
};

ETD.EVT.addSelectStyleEventHandler = function () {

    // style selected in the drop down menu
    $('#idSelectStyle').change(function (event) {

        var val, txt, stylename /*:string*/, style, valAr,
            updateMenu /*:boolean*/, storedStyleItems; /*:array*/

        // reset message
        ETD.AFO.message('', 'info', true, 'm-05');

        val = $(this).val();
        txt = $(this).find('option').filter(':selected').text();

        // get the style, process
        if (val === '') { // 'Select style' menu item
        } else if (val.match(/^appdir:/)) { // load from the uwp app directory or indexed db

            stylename = val.replace(/^appdir:/, '');
            ETD.UWP.getItem(stylename).then(
                function (result) {

                    // process the style file;
                    // use the option text (which is displayed in the menu) as the style name
                    ETD.STYLE.processStyleHtml(null, result, txt, false, { table: true, chart: true, styleeditor: true }, false, false); // selecting style from uwp app's storage
                },
                function (error) {

                    var val = $(event.target).find('option').filter(':selected').val();

                    // remove the invalid item from the array of style items
                    ETD.STYLE.storedStyleItems = $.grep(ETD.STYLE.storedStyleItems, function (item, index) { // remove items with the same name
                        return item.id !== stylename;
                    });

                    // store the array of style items
                    ETD.UWP.putItem(ETD.IDB.getItemID('style_index'), ETD.STYLE.storedStyleItems, true); // json type

                    // remove the invalid item from the menu, reset selection
                    $('#idSelectStyle').find('option[value="' + val + '"]').remove();
                    $(event.target).find('option[value=""]').attr('selected', 'selected').change();

                    // display error msg
                    ETD.AFO.message('Error: Failed to load the style. (' + error.toString().trim() + ')', 'error', true);
                });
        } else if (val.match(/^localstorage:/)) { // load from the local storage

            if (ETD.GEN.storageAvailable('localStorage')) {
                val = val.replace(/^localstorage:/, '').trim(); // e.g., 'style:etd-style-02.html'
                style = window['localStorage'].getItem(val);
                // decode and parse the style;
                // 181123: considered storing encoded text in the local storage;
                // however, because in the win app it is better to store original text content without encoding, do the same here;
                if (style.substr(0, 1000).indexOf('<') < 0) {
                    style = decodeURIComponent(style);
                }
                style = $.parseXML(style);
                stylename = val.replace(/^style:/i, '');
                ETD.STYLE.processStyleHtml(style, undefined, stylename, false, { table: true, chart: true, styleeditor: true }, false, false); // selecting style from the local storage
            }
        } else { // ajax call

            ETD.AFO.message('Loading...', 'info', true);

            $.ajax({
                url: val,
                cache: false,
                dataType: 'xml',
                success: function (data, textStatus, jqXHR) {
                    // get filename from url
                    valAr = val.replace(/\\/g, '/').split('/');
                    if ($.isArray(valAr) && valAr.length > 0) {
                        stylename = valAr[valAr.length - 1];
                    }

                    // process the style;
                    // pass the text of the selected option instead of the filename (stylename), because the text is more relevant to the user;
                    ETD.STYLE.processStyleHtml(data, undefined, txt, false, { table: true, chart: true, styleeditor: true }, false, false); // selecting style from drop down menu
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    if (typeof errorThrown === 'string' && errorThrown !== '') {
                        ETD.AFO.message('Error in loading HTML style file "' + val + '" (' + errorThrown + ').', 'error', true);
                    } else {
                        ETD.AFO.message('Error in loading HTML style file "' + val + '".', 'error', true);
                    }
                },
                timeout: 60000 // in milliseconds
            });
        }

        // check if a style item should be removed, store the style index
        if (val !== '') { // if val is an empty string ('Select style' menu item),
            // do not remove the style item marked for removal
            updateMenu = false;
            storedStyleItems = [];
            $.each(ETD.STYLE.storedStyleItems, function (index, item) {
                if (item.removed === ETD.STYLE.REMOVED_STATUS_2) { // the style item has been removed but still recoverable so far;
                    // from now on it is not recoverable;
                } else {
                    if (item.removed === ETD.STYLE.REMOVED_STATUS_1 && val !== 'appdir:' + item.id) {
                        item.removed = ETD.STYLE.REMOVED_STATUS_2;
                        updateMenu = true;
                    }
                    storedStyleItems.push(item);
                }
            });
            ETD.STYLE.storedStyleItems = storedStyleItems;
            ETD.UWP.putItem(ETD.IDB.getItemID('style_index'), ETD.STYLE.storedStyleItems, true); // json type
        }

        // update style menu
        if (updateMenu) {
            ETD.AFO.initStyleMenu();
        }

        // 'Remove style' checkbox
        ETD.EVT.setRemoveStyleRecoverStyle(val);

    }).on('focus', function () {
    });
};

ETD.EVT.addRemoveStyleEventHandler = function () {

    $('#idRemoveStyle').change(function (event) {

        var value = $('#idSelectStyle').val();

        if ($(event.target).prop('checked')) {

            // mark the style item for removal
            $.each(ETD.STYLE.storedStyleItems, function (index, item) {
                if (value === 'appdir:' + item.id) { // style item in the uwp app directory or indexed db

                    item.removed = ETD.STYLE.REMOVED_STATUS_1; // style item marked for removal

                    ETD.AFO.message('The current style is removed after a new style is selected from the drop-down menu.', 'info', true);
                } else {
                    item.removed = ETD.STYLE.REMOVED_STATUS_0;
                }
            });
        } else {

            // clear the removed attribute for all style items
            $.each(ETD.STYLE.storedStyleItems, function (index, item) {
                item.removed = ETD.STYLE.REMOVED_STATUS_0;
            });
            ETD.AFO.message('', 'info', true);
        }
    });

    // display message about removing style items
    $('#idRemoveStyleCont').click(function () {
        if (!ETD.GEN.isFeatureLimitedVer() && $('#idRemoveStyle').prop('disabled')) {
            var value = $('#idSelectStyle').val();
            if (value.match(/^appdir:/)) { // style items in the uwp app directory or indexed db
            } else if (value === '') { // 'Select style' option
                ETD.AFO.message('Only imported styles can be removed.', 'info', true);
            } else { // style item specified in the configuration file and loaded with ajax
                ETD.AFO.message('Styles defined in the configuration file cannot be removed.', 'info', true);
            }
        }
    });
};

ETD.EVT.setRemoveStyleRecoverStyle = function (value) {

    var stylename; /*:string*/

    value = value || $('#idSelectStyle').val() || '';

    // set 'Remove style' checkbox
    if (value.match(/^appdir:/)) { // load from the uwp app directory or indexed db
        $('#idRemoveStyle').prop('checked', false).prop('disabled', false);
        $('#idRemoveStyleCont').css({ visibility: 'hidden' });
    } else { // eg., empty value ('Select style'), or style defined in the configuration file
        $('#idRemoveStyle').prop('checked', false).prop('disabled', true);
        $('#idRemoveStyleCont').css({ visibility: 'visible' });
    }

    // set 'Recover style' link
    $.each(ETD.STYLE.storedStyleItems, function (index, item) {
        if (item.removed === ETD.STYLE.REMOVED_STATUS_2) { // style item removed
            stylename = item.title;
            return false; // break
        }
    });
    if (stylename) {
        $('#idRecoverStyle').html('<a>Recover "' + stylename + '"</a>');
        $('#idRecoverStyle').click(function (event) {

            $.each(ETD.STYLE.storedStyleItems, function (index, item) {
                if (item.removed === ETD.STYLE.REMOVED_STATUS_2) { // style item removed
                    item.removed = ETD.STYLE.REMOVED_STATUS_0;
                    return false; // break
                }
            });
            ETD.AFO.initStyleMenu();
        });
    } else {
        $('#idRecoverStyle').html('');
    }
};

ETD.EVT.addImportStyleEventHandler = function () {

    // 'Import Style' button
    $('#idImportStyle').click(function (event) {
        $('#jfilestyle-2').trigger('click');
    });
    $('#jfilestyle-2').bind('change', function (event) {

        var fileReader, dataTransfer, files,
            filename /*:string*/, contents; /*:string*/

        // if the value of the input control is an empty string, return immediately; this is a workaround for ie: below the value is set to
        // an empty string to ensure the event fires even if the same file is selected multiple times;
        if ($('#jfilestyle-2').val() === '') {
            return;
        }

        // reset message
        ETD.AFO.message('', 'info', true, 'm-06'); // excel: may overwrite the error message below

        event.preventDefault();

        try {
            fileReader = new FileReader(); // FileReader API not supported in <ie-10, <safari-6
            fileReader.addEventListener('loadend', function (event) {

                // event.target - FileReader
                try {

                    var oError = event.target.error;
                    if (oError) {

                        // an error occurs sometimes in chrome/ios with the error code error.NOT_FOUND_ERR;
                        // error codes:
                        //   error.NOT_FOUND_ERR    1
                        //   error.SECURITY_ERR     2
                        //   error.ABORT_ERR        3
                        //   error.NOT_READABLE_ERR 4
                        //   error.ENCODING_ERR     5
                        ETD.AFO.message('Error: The style import failed (error code ' + oError.code + ').', 'error', true);
                        return;
                    }

                    // contents of the file
                    contents = event.target.result;

                    // reset the value of the file selector, otherwise the event is not fired when selecting the same file next time
                    $('#jfilestyle-2').val('');

                    if (!contents) { // onedrive fails sometimes
                        throw "style import failed";
                    }

                    // event.target - FileReader
                    ETD.STYLE.processStyleHtml(null, contents, filename, true, { table: true, chart: true, styleeditor: true }, false, false); // 'Import Style' button
                } catch (oEx) {
                    ETD.AFO.message('Error: Style import failed.', 'error', true);
                }
            }, false);

            dataTransfer = event.dataTransfer; // DataTransfer object
            if (dataTransfer) { // drag and drop a file into a target container
                files = dataTransfer.files; // FileList object
            } else { // opening a csv file with file selector
                files = event.target.files; // FileList object
            }
            if (!files || files.length <= 0) {
                return;
            }
            filename = files[0].name;
            fileReader.readAsText(files[0]);
        } catch (oEx) {
            ETD.AFO.message('Error: Style import failed.', 'error', true);
        }
    });
};

ETD.EVT.addStyleEditorEventHandlers = function () {

    $('#idSelStyleEditorSctn').change(function (event) {
        var val = $(this).val();
        if (val === 'style4chart') {
            $('#idStyle4Table').closest('tr').css('display', 'none');
            $('#idStyle4Chart').closest('tr').css('display', 'table-row');
            ETD.UWP.showSvgDefs('chartDefs');
        } else if (val === 'style4table') {
            $('#idStyle4Chart').closest('tr').css('display', 'none');
            $('#idStyle4Table').closest('tr').css('display', 'table-row');
            ETD.UWP.showSvgDefs('tableDefs');
        }
    });

    // open style editor
    $('#idOpenStyleEditor').click(function (event) {

        // reset message
        ETD.AFO.message('', 'info', true);

        ETD.UWP.showStyleEditor(true);
    });

    // close style editor
    $('#idStyleEditorOK').click(function (event) {
        ETD.UWP.showStyleEditor(false);
    });
};

ETD.EVT.addHideShowChartControlsEventHandlers = function () {

    // hide chart controls
    $('#idHideChartUI')
        .click(function (event) {
            ETD.CHART.hideShowChartControls(true);
            ETD.SER.setModified(2); // hide chart controls
            ETD.SER.serialize({ save: true }); // click: hide chart controls
        })
        .bind('touchstart', function (event) {
            event.preventDefault();
            ETD.CHART.hideShowChartControls(true);
            ETD.SER.setModified(2); // hide chart controls
            ETD.SER.serialize({ save: true }); // touchstart: hide chart controls
        });

    // show chart controls
    $('#idShowChartUI')
        .click(function (event) {
            ETD.CHART.hideShowChartControls(false);
            ETD.SER.setModified(2); // show chart controls
            ETD.SER.serialize({ save: true }); // click: show chart controls
        })
        .bind('touchstart', function (event) {
            event.preventDefault();
            ETD.CHART.hideShowChartControls(false);
            ETD.SER.setModified(2); // show chart controls
            ETD.SER.serialize({ save: true }); // touchstart: show chart controls
        });
};

ETD.EVT.addChangePlotRangeEventHandler = function () {

    // a range of plots selected in the drop down menu
    $('#idSelectPlots').val(ETD.AFO.plotRangeInx);
    $('#idSelectPlots').change(function (event) {

        var selectAxis /*:array*/, selectVar /*:array*/, checkType /*:array*/,
            plotRange /*:object*/, plotRangeInx /*:int*/, plots /*:array*/, plot /*:object*/, plotInx /*:int*/,
            inx /*:int*/, inx2; /*:int*/

        // id-s of ui controls
        selectAxis = ['#idYAxis1', '#idYAxis2', '#idYAxis3'];
        selectVar = ['#idVariable1', '#idVariable2', '#idVariable3'];
        checkType = [{ key: 'symbol', val: '#idSymbolPlot' }, { key: 'line', val: '#idLinePlot' }, { key: 'area', val: '#idAreaPlot' }];

        // range of plots
        plotRangeInx = ETD.AFO.plotRangeInx; // 1,2,3,4,5

        // x-axis variable
        ETD.STRUCTS.PLOTS.xvar = $('#idVariable0').val();
        ETD.STRUCTS.PLOTS.xtxt = $('#idVariable0').find('option').filter(':selected').text();

        // get info for the range of plots from ui
        plots = ETD.STRUCTS.PLOTS.plots;
        for (inx = 0; inx < selectAxis.length; inx++) { // over select controls for selecting the axes and variables

            plotInx = 3 * (plotRangeInx - 1) + inx; // 0,1,2 if plotRangeInx is 1; 3,4,5 if plotRangeInx is 2;
            plot = {};

            // y-axis, y-variable
            plot.yscale = $(selectAxis[inx]).val();
            plot.yvar = $(selectVar[inx]).val();
            plot.ytxt = $(selectVar[inx]).find('option').filter(':selected').text();

            // symbol plot, line plot, area plot
            for (inx2 = 0; inx2 < checkType.length; inx2++) {
                plot[checkType[inx2].key] = $(checkType[inx2].val + (inx + 1)).prop('checked');
            }

            // add the plot object
            while (plots.length <= plotInx) {
                plots[plots.length] = null;
            }
            plots[plotInx] = plot;
        }

        // new range of plots
        plotRange = ETD.AFO.getCurrentPlotRange();
        plotRangeInx = plotRange.range; // 1,2,3,4,5
        ETD.AFO.plotRangeInx = plotRangeInx;

        // display info for the new range of plots
        for (inx = 0; inx < selectAxis.length; inx++) { // over select controls for selecting the axes and variables

            plotInx = plotRange.firstplot + inx; // 0,1,2 if plotRangeInx is 1; 3,4,5 if plotRangeInx is 2;

            if (plotInx > plots.length || !plots[plotInx]) { // set default values

                $(selectAxis[inx]).val('y1');
                $(selectVar[inx]).val('');
            } else {

                plot = plots[plotInx];

                // y-axis, y-variable
                $(selectAxis[inx]).val(plot.yscale);
                $(selectVar[inx]).val(plot.yvar);

                // symbol plot, line plot, area plot
                for (inx2 = 0; inx2 < checkType.length; inx2++) {
                    $(checkType[inx2].val + (inx + 1)).prop('checked', !!plot[checkType[inx2].key]);
                }
            }
        }
        ETD.STRUCTS.PLOTS.plots = plots;
    });
};

ETD.EVT.addDropEventHandler = function () {

    // drop-event for the container
    if (typeof FileReader !== 'undefined') { // FileReader API not supported in <ie-10, <safari-6

        $('body').on('dragenter', function (event) {
            event.preventDefault();
            event.stopPropagation();
        });
        $('body').on('dragover', function (event) {
            event.preventDefault();
            event.stopPropagation();
            event.originalEvent.dataTransfer.dropEffect = 'copy';
        });
        $('body').on('drop', function (event) {

            var oFileReader, oDataTransfer, oFiles,
                sFilename;

            event.preventDefault();
            event.stopPropagation();

            // make sure the style editor is closed;
            // the logic of the style editor does not support dropping files while it is open;
            if (ETD.UWP.isStyleEditorOpen()) {
                ETD.STED.showStyleEditor(false);
            }

            try {
                oFileReader = new FileReader();
                oFileReader.addEventListener('loadend', function (event) {
                    try {
                        // oDataTransfer.files.length is 0 after loading the file in chrome
                        ETD.IMPORT.onDropDataCsvDataJsConfigJsStyleHtml({
                            table: {
                                contents: event.target.result,
                                filename: sFilename
                            }
                        });
                    } catch (oEx) {
                        ETD.AFO.release();
                        ETD.AFO.message('Error: File import failed.', 'error', true);
                    }
                }, false);

                oDataTransfer = event.originalEvent.dataTransfer;
                oFiles = oDataTransfer.files; // FileList object
                if (oFiles.length === 0) { // occurs when dragging an image on the page; also occurs in ie and excel
                    // if the file begins with the BOM byte sequence, ie., after exporting from ms edge;
                    ETD.AFO.release();
                    ETD.AFO.message('Error: File import failed.', 'error', true);
                    return;
                }
                sFilename = oFiles[0].name;
                oFileReader.readAsText(oFiles[0]); // filereader.readAsText(blob[, encoding])

            } catch (oEx) {
                ETD.AFO.release();
                ETD.AFO.message('Error: File import failed.', 'error', true);
            }
        });
    }
};

ETD.EVT.addAxesFolderEventHandlers = function () {

    // the table of 'Axis Titles and Scales':
    // set change- event handler for all controls, and
    // set keydown-event handler

    // set change-event handler for all controls
    $('#idTopLayoutAxes').change(function (event) {

        // ms edge: change event not fired after changing the input and pressing the "enter" key
        // https://developer.microsoft.com/en-us/microsoft-edge/platform/issues/15181565/
        // check the current status of the bug

        // if changing an axis title, clear the corresponding checkbox 'Automatic'
        if ($(event.target).attr('id') === 'idAxisTitle-x') {
            $('#idAxisTitleAuto-x').prop('checked', false);
        } else if ($(event.target).attr('id') === 'idAxisTitle-y1') {
            $('#idAxisTitleAuto-y1').prop('checked', false);
        } else if ($(event.target).attr('id') === 'idAxisTitle-y2') {
            $('#idAxisTitleAuto-y2').prop('checked', false);
        } else if ($(event.target).attr('id') === 'idAxisTitle-y3') {
            $('#idAxisTitleAuto-y3').prop('checked', false);
        }

        // serialize
        ETD.SER.setModified(2); // ui controls in the table 'Axis Titles and Scales'

        // update the chart
        ETD.CHART.update(); // ui controls in the table 'Chart Titles and Scales'
    });

    /* // set keydown-event handler and prevent default action, otherwise wrong event handler is called in ie9, ie10
    $('#idTopLayoutAxes').keydown(function (event) {

        var keyCode;

        if (typeof event.which !== 'undefined') {
            keyCode = event.which;
        } else { // ie8
            keyCode = event.keyCode;
        }

        if (keyCode == 13) { // enter
            // prevent default, otherwise wrong event handler called in ie9, ie10
            event.preventDefault();
        }
    }); */
};

ETD.EVT.addSearchEventHandlers = function () {

    $('#idSearch').click(function (event) {
        ETD.TABLE.search();
    });

    $('#idCaseSensitive, #idWholeWord, #idSearchMode, #idSearchColumns').change(function () {
        if (ETD.GEN.isSearchApplied()) {
            ETD.TABLE.search();
        }
    });
};

ETD.EVT.addChartRelatedEventHandlers = function () {

    // change-event handler for multiple controls;
    // the event is also bound to child select-elements;
    $('#idMaxDataSymbolCount, \
        #idYAxis1, #idYAxis2, #idYAxis3, \
        #idVariable0, #idVariable1, #idVariable2, #idVariable3, \
        #idLogX, #idLogY, \
        #idMoreTicksGridV, #idMoreTicksGridH, \
        #idPaddingX, #idPaddingY, \
        #idSymbolPlot1, #idLinePlot1, #idAreaPlot1, \
        #idSymbolPlot2, #idLinePlot2, #idAreaPlot2, \
        #idSymbolPlot3, #idLinePlot3, #idAreaPlot3').change(function (event) {

            if ($(event.target).attr('id') === 'idMaxDataSymbolCount') {
                ETD.UWP.serSettings({ 'idMaxDataSymbolCount': $(this).val() });
            }
            ETD.SER.setModified(2); // ui controls above the chart and others
            ETD.CHART.update(); // ui controls above the chart and others
        });
};

// Validate configuration.

ETD.VALID = {
    layoutFromConfig /*:boolean*/: undefined // temporary flag set if config file defines layout
};

ETD.CONFIG = {
    data: {},
    style: {},
    settings: {},
    operations: {}
};

ETD.VALID.validateConfig = function (config /*:object*/) {

    var conf /*:object*/, maxTRSFC; /*:int*/

    conf = config || window.CONFIG;
    if ('CONFIG' in window) {
        //delete window.CONFIG;
    }

    if (typeof conf !== 'object' || !conf) {
        ETD.AFO.message('Error: Configuration script must define CONFIG object.', 'error', true);
        return false;
    }

    // data
    if (conf.data && $.isArray(conf.data.items)) {
        ETD.CONFIG.data.items = conf.data.items;
    } else {
        ETD.CONFIG.data.items = [];
    }

    // style
    if (conf.style && $.isArray(conf.style.items)) {
        ETD.CONFIG.style.items = conf.style.items;
    } else {
        ETD.CONFIG.style.items = [];
    }

    // settings
    if (conf.settings) {

        // initial layout
        if ($.isNumeric(conf.settings.layoutLeft) || $.isNumeric(conf.settings.layoutTop)) {
            ETD.AFO.setLayouter(conf.settings.layoutLeft, conf.settings.layoutTop);
            if (ETD.VALID.hasDefaultData()) {
                ETD.VALID.layoutFromConfig = true;
            }
        } else {
            ETD.VALID.layoutFromConfig = false;
        }

        // use local storage to store style files
        ETD.CONFIG.settings.useLocalStorageForStyle = !!conf.settings.useLocalStorageForStyle;
        if (!ETD.CONFIG.settings.useLocalStorageForStyle && ETD.GEN.storageAvailable('localStorage')) { // remove all from local storage (so far only style items are stored there)
            window['localStorage'].clear();
        }

        // maximum number of table rows selected by clicking on the chart
        maxTRSFC = parseInt(conf.settings.maxTableRowsSelectedFromChart);
        if (isNaN(maxTRSFC) || maxTRSFC < 0) {
            maxTRSFC = 1;
        }
        ETD.CONFIG.settings.maxTableRowsSelectedFromChart = maxTRSFC;
    }

    // operations
    if (conf.operations) {
        if ($.isArray(conf.operations.items)) {
            ETD.CONFIG.operations.items = conf.operations.items;
        }
        if (typeof conf.operations.calculate === 'function') {
            ETD.CONFIG.operations.calculate = conf.operations.calculate;
        }
    }

    // custom callback for drawing on the chart
    if (conf.chart && typeof conf.chart.ondraw === 'function') {
        ETD.CONFIG.onDrawChart = conf.chart.ondraw;
    }

    return true;
};

// In the xml document, find an element by its id.
// If its text follows pattern
//   id = "idDefEl",
// find the element by its id and return its attributes.
ETD.VALID.getDefItemAttrs = function ($xml, idTblCell, $defs, /*stedPath*/ styleEdtrSel /*:string*/) {
    // overrides - selections made in the style editor

    var $el, cellTxt,
        regEx, match,
        result /*:object*/,
        idDefEl, $defEl;

    cellTxt = styleEdtrSel;

    if (typeof cellTxt === 'undefined' || cellTxt === ETD.STED.defaultTxt) { // value not found in the overrides object, or default option

        // find the element by id
        if (typeof idTblCell !== 'string' || idTblCell.length < 4) {
            return undefined;
        }
        if (idTblCell[0] !== '#' && idTblCell[0] !== '.') {
            idTblCell = '#' + idTblCell;
        }
        $el = $xml.find(idTblCell);
        if ($el.length === 0) {
            return undefined;
        } else if ($el.length > 1) {
            ETD.AFO.message('Multiple elements found with the selector "' + idTblCell + '" while processing the style file.', 'warning', true);
            return undefined;
        }
        cellTxt = $el.text().trim() || ''; // find the custom table cell and text
    }

    // in the text of the element, search for pattern
    //   id = "idXXXX"
    regEx = new RegExp('^\\s*id\\s*=\\s*(["|\'])([\\w|-]+)\\1'); // matching, e.g., id = "idXXXX"
    match = cellTxt.match(regEx);
    if (match && match.length >= 3) {
        result = {};
        idDefEl = match[2];
        $defEl = $defs.find('#' + idDefEl);
        if ($defEl.length === 0) {
            ETD.AFO.message('SVG element with id="' + idDefEl + '" not found in the style file (searching in the defs element with id="' + $defs.attr('id') + '").', 'warning', true);
            return undefined;
        }
        result['tagName'] = $defEl.prop('tagName');
        $defEl.each(function () {
            $.each(this.attributes, function (i, attrib) {
                result[attrib.name] = attrib.value;
            });
        });
        return result;
    } else {
        if (cellTxt === '') {
            cellTxt = 'none';
        }
        return cellTxt;
    }
};

ETD.VALID.validateStyle = function (chartStyle /*:object*/, tableStyle /*:object*/, generalStyle /*:object*/) {

    var isInIframe /*:boolean*/ = ETD.GEN.isIframe();

    if (Object.keys(chartStyle).length === 0 || Object.keys(tableStyle).length === 0) {
        ETD.AFO.message('Error: Invalid chart or table style object.', 'error', true);
        return;
    }

    // plot colors
    generalStyle.plotColors = generalStyle.plotColors || [];
    while (generalStyle.plotColors.length < ETD.CHART.maxNumberOfPlots) {
        generalStyle.plotColors.push(ETD.STYLE.defCol);
    }

    // chart scrollbar
    chartStyle['scrollbar'] = chartStyle['scrollbar'] || {};
    if (!$.isNumeric(chartStyle['scrollbar']['scrollbar-width-nontouchdevice'])) {
        chartStyle['scrollbar']['scrollbar-width-nontouchdevice'] = 160;
    }
    if (!$.isNumeric(chartStyle['scrollbar']['scrollbar-width-touchdevice'])) {
        chartStyle['scrollbar']['scrollbar-width-touchdevice'] = 320;
    }

    // table scrollbar
    tableStyle['scrollbar'] = tableStyle['scrollbar'] || {};
    if (!$.isNumeric(tableStyle['scrollbar']['scrollbar-width-nontouchdevice'])) {
        tableStyle['scrollbar']['scrollbar-width-nontouchdevice'] = 160;
    }
    if (!$.isNumeric(tableStyle['scrollbar']['scrollbar-width-touchdevice'])) {
        tableStyle['scrollbar']['scrollbar-width-touchdevice'] = 320;
    }

    // skin items;
    // default values of generalStyle['skin'] color items in ETD.STYLE.processStyleHtml ();
    if (!generalStyle['skin']['hideHeader']) {
        generalStyle['skin']['hideHeader'] = 0;
    }
    if (isInIframe) {
        generalStyle['skin']['hideHeader'] = 1;
    }
};

ETD.VALID.hasDefaultData = function () {

    var url; /*:string*/

    if (ETD.CONFIG.data && $.isArray(ETD.CONFIG.data.items)) {
        $.each(ETD.CONFIG.data.items, function (index, item /*:object*/) {
            if (typeof item.url === 'string' && item['default']) {
                url = item.url;
                return false;
            }
        });
    }
    return url;
};


ETD.SELECTOR = {

    ABOUT: 'www.ExploreTheData.com - Data selector',

    MODE: {
        dragging: 0, // an area is selected by dragging;
        clicking: 1, // an area is selected with two clicks;
        menu: 2  // an area is selected by using a custom context menu;
    }
};

/*
 * ETD.SELECTOR.create ()
 * Create data selector object.
 */
ETD.SELECTOR.create = function (params /*:object*/) {

    params = params || {};

    var method /*:string*/, // method of selecting, see below
        onchange /*:function*/, // callback, called if the selection changes
        rect /*:object*/ = null, // an object of type { x:, y:, width:, height: } or null
        x, y,
        mousePosition = undefined, // location of the last click event
        mousePositionPending = undefined, // in case of context menu, temporary storage of mousePosition, before
            // a click on the Select button
        domRect = undefined, // svg rect-element representing the selected area, or null
        idTimer = undefined;

    method = params.method; // one of ETD.SELECTOR.MODE.dragging, ETD.SELECTOR.MODE.clicking, ETD.SELECTOR.MODE.menu
    if (method !== ETD.SELECTOR.MODE.clicking && method !== ETD.SELECTOR.MODE.menu) {
        method = ETD.SELECTOR.MODE.dragging;
    }

    if (typeof params.onchange === 'function') {
        onchange = params.onchange;
    } else {
        onchange = function () { };
    }

    // Find the selected area.
    function findArea(pos0 /*:object*/, pos1 /*:object*/, plotArea /*:object*/, allowReverseScales /*:boolean*/) {
        // pos0 - the location of the first mouseDown event, an object of type {x:, y: };
        // pos1 - the location of the second mouseDown event, an object of type {x:, y: };
        // plotArea - the plot area, an object of type { x:, y:, width:, height: };
        // allowReverseScales - if true, allow scale values in reverse order, depending on the direction of selecting;

        var x0 /*:int*/, y0 /*:int*/, x1 /*:int*/, y1; /*:int*/

        if (!pos0 || !pos1) {
            return null;
        }

        x0 = Math.min(Math.max(pos0.x, plotArea.x), plotArea.x + plotArea.width);
        y0 = Math.min(Math.max(pos0.y, plotArea.y), plotArea.y + plotArea.height);
        x1 = Math.min(Math.max(pos1.x, plotArea.x), plotArea.x + plotArea.width);
        y1 = Math.min(Math.max(pos1.y, plotArea.y), plotArea.y + plotArea.height);

        if (!allowReverseScales) {
            return {
                x: Math.min(x0, x1), y: Math.min(y0, y1),
                width: Math.abs(x0 - x1), height: Math.abs(y0 - y1)
            };
        } else {
            return { x: x0, y: y1, width: x1 - x0, height: y0 - y1 };
        }
    }


    // Mouse event processing.
    function onMouseEventImpl(event /*:object*/, domGCallback) {

        var UPP = ETD.UPP, // 1 pixel corresponds to 10 units
            selectorStatus /*:int*/,
            selectButton; /*:boolean*/

        // find out whether the data selector must be displayed or not
        selectorStatus = 0;
        // 0 - selector not visible;
        // 1 - width and height of the selector is 0, do not display;
        // 2 - display the selector;
        // 3 - remove the selector;

        if ((event.type === 'mousedown' || event.type === 'touchstart') &&
            method === ETD.SELECTOR.MODE.dragging) { // the mousedown event

            selectorStatus = 1;
        }

        if (event.type === 'click' || event.type === 'touchstart') {

            if (method === ETD.SELECTOR.MODE.clicking) {

                // check if mousePosition is available
                if (mousePosition) {

                    // if mousePosition is available, the selected area is defined by
                    //    mousePosition
                    // and the current position
                    //   event.position

                    // find the selected area from two points
                    rect = findArea(mousePosition, event.position, event.plotArea, params.allow_reverse);

                    // check if the width/height > 0
                    if (rect.width === 0 && rect.height === 0) { // the width and height of selector is 0, do not display
                        selectorStatus = 1;
                    } else { // display the selector
                        selectorStatus = 2;
                    }
                } else {
                    mousePosition = { x: event.position.x, y: event.position.y };
                }

            } else if (method === ETD.SELECTOR.MODE.menu) {

                // check if the event occurred on the Select menu button;
                selectButton = ETD.GEN.isDescendantOf(event.target, '^idCommandSelect', '');

                // two cases: the target is the Select button or not
                if (!selectButton) {
                    mousePositionPending = { x: event.position.x, y: event.position.y };
                } else { // click on the Select button of the context menu

                    // check if mousePosition is available
                    if (!mousePosition) {
                        mousePosition = mousePositionPending;
                    } else {
                        // find the selected area from two points
                        rect = findArea(mousePosition, mousePositionPending, event.plotArea, params.allow_reverse);

                        // check if the width/height > 0
                        if (rect.width === 0 && rect.height === 0) { // the width and height of the selector is 0, do not display
                            selectorStatus = 1;
                        } else { // display the selector
                            selectorStatus = 2;
                        }
                    }

                    mousePositionPending = null;
                }
            }
        }

        if (event.type === 'mousemove' || event.type === 'touchmove') { // the mousemove event

            if (method === ETD.SELECTOR.MODE.dragging) {

                if (ETD.GEN.isInRect(event.mousedownPosition, event.plotArea)) {
                    // event.mousedownPosition is defined only if dragging (with the mouse left button down);

                    selectorStatus = 1;
                    rect = findArea(event.mousedownPosition, event.position, event.plotArea, params.allow_reverse);
                    if (rect) { // display the selector
                        selectorStatus = 2;
                    }
                }
            }
        }

        if (event.type === 'mouseup' || event.type === 'mouseout' || event.type === 'touchend') {

            if (method === ETD.SELECTOR.MODE.dragging) {
                selectorStatus = 3;
                onChangeRect();
            }
        }

        // Update the selector.
        domGCallback.style.cursor = 'auto';
        if (selectorStatus === 2) { // display the selector;

            domGCallback.style.cursor = 'crosshair';

            // create rect-element
            $(domRect).remove(); // remove old rect
            domRect = ETD.GEN.createElement('rect', domGCallback);

            // draw the rectangle
            x = ETD.GEN.correctCoordinate(Math.min(rect.x, rect.x + rect.width), UPP);
            y = ETD.GEN.correctCoordinate(Math.min(rect.y, rect.y + rect.height), UPP);
            ETD.GEN.setAttributes(domRect, {
                x: x,
                width: ETD.GEN.correctCoordinate(x + Math.abs(rect.width), UPP) - x,
                y: y,
                height: ETD.GEN.correctCoordinate(y + Math.abs(rect.height), UPP) - y,
                fill: 'silver', 'fill-opacity': 0.5,
                stroke: 'navy', 'stroke-opacity': 1,
                'stroke-width': UPP,
                'shape-rendering': 'crispEdges'
            });

            // reset mousePosition, otherwise the end point of the tracker is also used
            // as the start point of the next tracker
            mousePosition = null;

            // wait and remove the selector
            if (method === ETD.SELECTOR.MODE.clicking || method === ETD.SELECTOR.MODE.menu) {
                resetImpl(1000);
                onChangeRect();
            }

        } else if (selectorStatus === 3) { // remove the selector
            resetImpl(0);
        }

        return true;
    }

    function onChangeRect() {
        onchange();
    }

    // Remove the selector.
    function resetImpl(delay /*:int*/) {

        delay = parseInt(delay);
        if (isNaN(delay)) {
            delay = 0;
        }

        clearTimeout(idTimer);
        idTimer = setTimeout(function () {
            if (domRect && domRect.parentNode) {
                domRect.parentNode.removeChild(domRect);
            }
            domRect = null;
            if (rect) {
                rect = null;
                onChangeRect();
            }
            rect = null;
            mousePosition = null;
            mousePositionPending = null;

        }, delay);
    }


    // The public interface of the data selector.
    return {
        // mouse event processing
        onMouseEvent: function (event, domGCallback) {
            return onMouseEventImpl(event, domGCallback);
        },
        // reset the selected area
        reset: function (delay /*:int*/) {
            resetImpl(delay);
        },
        // return true if mousedown position (one of two points to define the area) is available
        getPoint: function () {
            return !!mousePosition;
        },
        // get the current selected area (an object of type { x:, y:, width:, height: })
        getRect: function () {
            if (rect) {
                return { x: rect.x, y: rect.y, width: rect.width, height: rect.height };
            } else {
                return null;
            }
        }
    };
};
 // suppress warning from the python script

})();
